type token =
  | SPEC of (Lexing.position * string)
  | DECL of (Logic_ptree.decl list)
  | CODE_ANNOT of (Logic_ptree.code_annot * Cabs.cabsloc)
  | LOOP_ANNOT of (Logic_ptree.code_annot list * Cabs.cabsloc)
  | ATTRIBUTE_ANNOT of (string * Cabs.cabsloc)
  | CUSTOM_ANNOT of (Logic_ptree.custom_tree  * string * Cabs.cabsloc)
  | IDENT of (string)
  | CST_CHAR of (int64 list * Cabs.cabsloc)
  | CST_WCHAR of (int64 list * Cabs.cabsloc)
  | CST_INT of (string * Cabs.cabsloc)
  | CST_FLOAT of (string * Cabs.cabsloc)
  | NAMED_TYPE of (string)
  | CST_STRING of (int64 list * Cabs.cabsloc)
  | CST_WSTRING of (int64 list * Cabs.cabsloc)
  | EOF
  | BOOL of (Cabs.cabsloc)
  | CHAR of (Cabs.cabsloc)
  | INT of (Cabs.cabsloc)
  | DOUBLE of (Cabs.cabsloc)
  | FLOAT of (Cabs.cabsloc)
  | VOID of (Cabs.cabsloc)
  | INT64 of (Cabs.cabsloc)
  | ENUM of (Cabs.cabsloc)
  | STRUCT of (Cabs.cabsloc)
  | TYPEDEF of (Cabs.cabsloc)
  | UNION of (Cabs.cabsloc)
  | SIGNED of (Cabs.cabsloc)
  | UNSIGNED of (Cabs.cabsloc)
  | LONG of (Cabs.cabsloc)
  | SHORT of (Cabs.cabsloc)
  | VOLATILE of (Cabs.cabsloc)
  | EXTERN of (Cabs.cabsloc)
  | STATIC of (Cabs.cabsloc)
  | CONST of (Cabs.cabsloc)
  | RESTRICT of (Cabs.cabsloc)
  | AUTO of (Cabs.cabsloc)
  | REGISTER of (Cabs.cabsloc)
  | THREAD of (Cabs.cabsloc)
  | SIZEOF of (Cabs.cabsloc)
  | ALIGNOF of (Cabs.cabsloc)
  | EQ
  | PLUS_EQ
  | MINUS_EQ
  | STAR_EQ
  | SLASH_EQ
  | PERCENT_EQ
  | AND_EQ
  | PIPE_EQ
  | CIRC_EQ
  | INF_INF_EQ
  | SUP_SUP_EQ
  | ARROW
  | DOT
  | EQ_EQ
  | EXCLAM_EQ
  | INF
  | SUP
  | INF_EQ
  | SUP_EQ
  | PLUS of (Cabs.cabsloc)
  | MINUS of (Cabs.cabsloc)
  | STAR of (Cabs.cabsloc)
  | SLASH
  | PERCENT
  | TILDE of (Cabs.cabsloc)
  | AND of (Cabs.cabsloc)
  | PIPE
  | CIRC
  | EXCLAM of (Cabs.cabsloc)
  | AND_AND of (Cabs.cabsloc)
  | PIPE_PIPE
  | INF_INF
  | SUP_SUP
  | PLUS_PLUS of (Cabs.cabsloc)
  | MINUS_MINUS of (Cabs.cabsloc)
  | RPAREN
  | LPAREN of (Cabs.cabsloc)
  | RBRACE of (Cabs.cabsloc)
  | LBRACE of (Cabs.cabsloc)
  | LBRACKET
  | RBRACKET
  | COLON
  | COLON2
  | SEMICOLON of (Cabs.cabsloc)
  | COMMA
  | ELLIPSIS
  | QUEST
  | BREAK of (Cabs.cabsloc)
  | CONTINUE of (Cabs.cabsloc)
  | GOTO of (Cabs.cabsloc)
  | RETURN of (Cabs.cabsloc)
  | SWITCH of (Cabs.cabsloc)
  | CASE of (Cabs.cabsloc)
  | DEFAULT of (Cabs.cabsloc)
  | WHILE of (Cabs.cabsloc)
  | DO of (Cabs.cabsloc)
  | FOR of (Cabs.cabsloc)
  | IF of (Cabs.cabsloc)
  | TRY of (Cabs.cabsloc)
  | EXCEPT of (Cabs.cabsloc)
  | FINALLY of (Cabs.cabsloc)
  | ELSE
  | ATTRIBUTE of (Cabs.cabsloc)
  | INLINE of (Cabs.cabsloc)
  | ASM of (Cabs.cabsloc)
  | TYPEOF of (Cabs.cabsloc)
  | FUNCTION__ of (Cabs.cabsloc)
  | PRETTY_FUNCTION__ of (Cabs.cabsloc)
  | LABEL__
  | BUILTIN_VA_ARG of (Cabs.cabsloc)
  | BLOCKATTRIBUTE
  | BUILTIN_TYPES_COMPAT of (Cabs.cabsloc)
  | BUILTIN_OFFSETOF of (Cabs.cabsloc)
  | DECLSPEC of (Cabs.cabsloc)
  | MSASM of (string * Cabs.cabsloc)
  | MSATTR of (string * Cabs.cabsloc)
  | PRAGMA_LINE of (string * Cabs.cabsloc)
  | PRAGMA of (Cabs.cabsloc)
  | PRAGMA_EOL
  | LGHOST
  | RGHOST

open Parsing;;
let _ = parse_error;;
# 50 "src/kernel_internals/parsing/cparser.mly"

open Cabs
open Cabshelper
(* This function is used by the parsing engine generated by Ocamlyacc itself,
   and requires a string as argument. *)
let parse_error msg = Errorloc.parse_error "%s" msg

(*
** Expression building
*)
let smooth_expression lst =
  match lst with
    [] -> { expr_loc = cabslu; expr_node = NOTHING }
  | [expr] -> expr
  | _ ->
      let beg_loc = fst (List.hd lst).expr_loc in
      let end_loc = snd (Extlib.last lst).expr_loc in
      { expr_loc = (beg_loc,end_loc); expr_node = COMMA (lst) }

(* To be called only inside a grammar rule. *)
let make_expr e =
  { expr_loc = symbol_start_pos (), symbol_end_pos ();
    expr_node = e }

let currentFunctionName = ref "<outside any function>"

exception NoProto

(* Go through all the parameter names and mark them as identifiers *)
let rec findProto = function
    PROTO (d, args, _) when isJUSTBASE d ->
      List.iter (fun (_, (an, _, _, _)) -> !Lexerhack.add_identifier an) args
  | PROTO (d, _, _) -> findProto d
  | PARENTYPE (_, d, _) -> findProto d
  | PTR (_, d) -> findProto d
  | ARRAY (d, _, _) -> findProto d
  | _ -> raise NoProto

and isJUSTBASE = function
    JUSTBASE -> true
  | PARENTYPE (_, d, _) -> isJUSTBASE d
  | _ -> false

let announceFunctionName ((n, decl, _, _):name) =
  !Lexerhack.add_identifier n;
  (* Start a context that includes the parameter names and the whole body.
   * Will pop when we finish parsing the function body *)
  !Lexerhack.push_context ();
  (try findProto decl
   with NoProto ->
     Errorloc.parse_error "Cannot find the prototype in a function definition");
  currentFunctionName := n

let check_funspec_abrupt_clauses fname spec =
  List.iter
    (fun bhv ->
      List.iter
	(function
	| (Cil_types.Normal | Cil_types.Exits),_ -> ()
	| (Cil_types.Breaks | Cil_types.Continues | Cil_types.Returns),
          {Logic_ptree.lexpr_loc = (loc,_)} ->
          Errorloc.parse_error ~source:loc
            "Specification of function %s can only contain ensures or \
                 exits post-conditions" fname)
	bhv.Logic_ptree.b_post_cond)
    spec.Logic_ptree.spec_behavior

let applyPointer (ptspecs: attribute list list) (dt: decl_type)
       : decl_type =
  (* Outer specification first *)
  let rec loop = function
      [] -> dt
    | attrs :: rest -> PTR(attrs, loop rest)
  in
  loop ptspecs

let doDeclaration logic_spec (loc: cabsloc) (specs: spec_elem list) (nl: init_name list)  =
  if isTypedef specs then begin
    (* Tell the lexer about the new type names *)
    List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_type n) nl;
    TYPEDEF ((specs, List.map (fun (n, _) -> n) nl), loc)
  end else
    if nl = [] then
      ONLYTYPEDEF (specs, loc)
    else begin
      (* Tell the lexer about the new variable names *)
      List.iter (fun ((n, _, _, _), _) -> !Lexerhack.add_identifier n) nl;
      !Lexerhack.push_context ();
      List.iter
        (fun ((_,t,_,_),_) ->
           try findProto t with NoProto -> ())
        nl;
      let logic_spec =
        match logic_spec with
        | None -> None
        | Some (loc, _ as ls) -> begin
            try
              let (loc',spec) = Logic_lexer.spec ls in
              let name =
                match nl with
                | [ (n,_,_,_),_ ] -> n
                | _ -> "unknown function"
              in
              check_funspec_abrupt_clauses name spec;
              Some (spec, (loc, loc'))
            with exn when Kernel.ContinueOnAnnotError.get () ->
              Kernel.debug ~source:loc "Skipping annotation: %s"
                (Printexc.to_string exn);
              None
          end
      in
      !Lexerhack.pop_context ();
      DECDEF (logic_spec, (specs, nl), loc)
    end


let doFunctionDef spec (loc: cabsloc)
                  (lend: cabsloc)
                  (specs: spec_elem list)
                  (n: name)
                  (b: block) : definition =
  let fname = (specs, n) in
  let name = match n with (n,_,_,_) -> n in
  Extlib.may (fun (spec, _) -> check_funspec_abrupt_clauses name spec) spec;
  FUNDEF (spec, fname, b, loc, lend)

let doOldParDecl (names: string list)
                 ((pardefs: name_group list), (isva: bool))
    : single_name list * bool =
  let findOneName n =
    (* Search in pardefs for the definition for this parameter *)
    let rec loopGroups = function
        [] -> ([SpecType Tint], (n, JUSTBASE, [], cabslu))
      | (specs, names) :: restgroups ->
          let rec loopNames = function
              [] -> loopGroups restgroups
            | ((n',_, _, _) as sn) :: _ when n' = n -> (specs, sn)
            | _ :: restnames -> loopNames restnames
          in
          loopNames names
    in
    loopGroups pardefs
  in
  let args = List.map findOneName names in
  (args, isva)

let int64_to_char value =
  if (Int64.compare value (Int64.of_int 255) > 0) ||
    (Int64.compare value Int64.zero < 0) then
    Errorloc.parse_error "integral literal 0x%Lx too big" value
  else
    Char.chr (Int64.to_int value)

(* takes a not-nul-terminated list, and converts it to a string. *)
let rec intlist_to_string (str: int64 list):string =
  match str with
    [] -> ""  (* add nul-termination *)
  | value::rest ->
      let this_char = int64_to_char value in
      (String.make 1 this_char) ^ (intlist_to_string rest)

let fst3 (result, _, _) = result
let trd3 (_, _, result) = result

let fourth4 (_,_,_,result) = result

(*
   transform:  __builtin_offsetof(type, member)
   into     :  (size_t) (&(type * ) 0)->member
 *)

let sizeofType () =
  let findSpecifier name =
    let convert_one_specifier s =
      if s = "int" then Cabs.Tint
      else if s = "unsigned" then Cabs.Tunsigned
      else if s = "long" then Cabs.Tlong
      else if s = "short" then Cabs.Tshort
      else if s = "char" then Cabs.Tchar
      else
        Kernel.fatal
          ~current:true
          "initCIL: cannot find the right specifier for type %s" name
    in
    let add_one_specifier s acc =
      (Cabs.SpecType (convert_one_specifier s)) :: acc
    in
    let specs = Str.split (Str.regexp " +") name in
    List.fold_right add_one_specifier specs []
  in
  findSpecifier Cil.theMachine.Cil.theMachine.Cil_types.size_t


let transformOffsetOf (speclist, dtype) member =
  let mk_expr e = { expr_loc = member.expr_loc; expr_node = e } in
  let rec addPointer = function
    | JUSTBASE ->
	PTR([], JUSTBASE)
    | PARENTYPE (attrs1, dtype, attrs2) ->
	PARENTYPE (attrs1, addPointer dtype, attrs2)
    | ARRAY (dtype, attrs, expr) ->
	ARRAY (addPointer dtype, attrs, expr)
    | PTR (attrs, dtype) ->
	PTR (attrs, addPointer dtype)
    | PROTO (dtype, names, variadic) ->
	PROTO (addPointer dtype, names, variadic)
  in
  let nullType = (speclist, addPointer dtype) in
  let nullExpr = mk_expr (CONSTANT (CONST_INT "0")) in
  let castExpr = mk_expr (CAST (nullType, SINGLE_INIT nullExpr)) in

  let rec replaceBase e =
    let node = match e.expr_node with
      | VARIABLE field ->
	  MEMBEROFPTR (castExpr, field)
      | MEMBEROF (base, field) ->
	  MEMBEROF (replaceBase base, field)
      | INDEX (base, index) ->
	  INDEX (replaceBase base, index)
      | _ ->
	Errorloc.parse_error "malformed offset expression in __builtin_offsetof"
    in { e with expr_node = node }
  in
  let memberExpr = replaceBase member in
  let addrExpr = { memberExpr with expr_node = UNARY (ADDROF, memberExpr)} in
  let sizeofType = sizeofType(), JUSTBASE in
  { addrExpr with expr_node = CAST (sizeofType, SINGLE_INIT addrExpr)}

let no_ghost_stmt s = {stmt_ghost = false ; stmt_node = s}

let no_ghost = List.map no_ghost_stmt

let in_ghost =
  let ghost_me = object
    inherit Cabsvisit.nopCabsVisitor
    method! vstmt s =
      s.stmt_ghost <- true;
      Cil.DoChildren
  end
  in
  List.map
    (fun s -> ignore (Cabsvisit.visitCabsStatement ghost_me s); s)

let in_block l =
  match l with
      [] -> no_ghost_stmt (NOP cabslu)
    | [s] -> s
    | _::_ ->
        no_ghost_stmt (BLOCK ({ blabels = []; battrs = []; bstmts = l},
                              get_statementloc (List.hd l),
                              get_statementloc (Extlib.last l)))

# 380 "src/kernel_internals/parsing/cparser.ml"
let yytransl_const = [|
    0 (* EOF *);
  296 (* EQ *);
  297 (* PLUS_EQ *);
  298 (* MINUS_EQ *);
  299 (* STAR_EQ *);
  300 (* SLASH_EQ *);
  301 (* PERCENT_EQ *);
  302 (* AND_EQ *);
  303 (* PIPE_EQ *);
  304 (* CIRC_EQ *);
  305 (* INF_INF_EQ *);
  306 (* SUP_SUP_EQ *);
  307 (* ARROW *);
  308 (* DOT *);
  309 (* EQ_EQ *);
  310 (* EXCLAM_EQ *);
  311 (* INF *);
  312 (* SUP *);
  313 (* INF_EQ *);
  314 (* SUP_EQ *);
  318 (* SLASH *);
  319 (* PERCENT *);
  322 (* PIPE *);
  323 (* CIRC *);
  326 (* PIPE_PIPE *);
  327 (* INF_INF *);
  328 (* SUP_SUP *);
  331 (* RPAREN *);
  335 (* LBRACKET *);
  336 (* RBRACKET *);
  337 (* COLON *);
  338 (* COLON2 *);
  340 (* COMMA *);
  341 (* ELLIPSIS *);
  342 (* QUEST *);
  357 (* ELSE *);
  364 (* LABEL__ *);
  366 (* BLOCKATTRIBUTE *);
  374 (* PRAGMA_EOL *);
  375 (* LGHOST *);
  376 (* RGHOST *);
    0|]

let yytransl_block = [|
  257 (* SPEC *);
  258 (* DECL *);
  259 (* CODE_ANNOT *);
  260 (* LOOP_ANNOT *);
  261 (* ATTRIBUTE_ANNOT *);
  262 (* CUSTOM_ANNOT *);
  263 (* IDENT *);
  264 (* CST_CHAR *);
  265 (* CST_WCHAR *);
  266 (* CST_INT *);
  267 (* CST_FLOAT *);
  268 (* NAMED_TYPE *);
  269 (* CST_STRING *);
  270 (* CST_WSTRING *);
  271 (* BOOL *);
  272 (* CHAR *);
  273 (* INT *);
  274 (* DOUBLE *);
  275 (* FLOAT *);
  276 (* VOID *);
  277 (* INT64 *);
  278 (* ENUM *);
  279 (* STRUCT *);
  280 (* TYPEDEF *);
  281 (* UNION *);
  282 (* SIGNED *);
  283 (* UNSIGNED *);
  284 (* LONG *);
  285 (* SHORT *);
  286 (* VOLATILE *);
  287 (* EXTERN *);
  288 (* STATIC *);
  289 (* CONST *);
  290 (* RESTRICT *);
  291 (* AUTO *);
  292 (* REGISTER *);
  293 (* THREAD *);
  294 (* SIZEOF *);
  295 (* ALIGNOF *);
  315 (* PLUS *);
  316 (* MINUS *);
  317 (* STAR *);
  320 (* TILDE *);
  321 (* AND *);
  324 (* EXCLAM *);
  325 (* AND_AND *);
  329 (* PLUS_PLUS *);
  330 (* MINUS_MINUS *);
  332 (* LPAREN *);
  333 (* RBRACE *);
  334 (* LBRACE *);
  339 (* SEMICOLON *);
  343 (* BREAK *);
  344 (* CONTINUE *);
  345 (* GOTO *);
  346 (* RETURN *);
  347 (* SWITCH *);
  348 (* CASE *);
  349 (* DEFAULT *);
  350 (* WHILE *);
  351 (* DO *);
  352 (* FOR *);
  353 (* IF *);
  354 (* TRY *);
  355 (* EXCEPT *);
  356 (* FINALLY *);
  358 (* ATTRIBUTE *);
  359 (* INLINE *);
  360 (* ASM *);
  361 (* TYPEOF *);
  362 (* FUNCTION__ *);
  363 (* PRETTY_FUNCTION__ *);
  365 (* BUILTIN_VA_ARG *);
  367 (* BUILTIN_TYPES_COMPAT *);
  368 (* BUILTIN_OFFSETOF *);
  369 (* DECLSPEC *);
  370 (* MSASM *);
  371 (* MSATTR *);
  372 (* PRAGMA_LINE *);
  373 (* PRAGMA *);
    0|]

let yylhs = "\255\255\
\001\000\002\000\003\000\003\000\003\000\003\000\051\000\051\000\
\051\000\004\000\004\000\004\000\004\000\004\000\004\000\004\000\
\004\000\004\000\004\000\054\000\054\000\055\000\056\000\056\000\
\057\000\057\000\057\000\057\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\058\000\058\000\058\000\058\000\059\000\
\059\000\059\000\061\000\061\000\061\000\061\000\061\000\061\000\
\061\000\061\000\061\000\061\000\061\000\061\000\061\000\061\000\
\062\000\062\000\063\000\063\000\063\000\063\000\064\000\064\000\
\064\000\065\000\065\000\065\000\066\000\066\000\066\000\066\000\
\066\000\067\000\067\000\067\000\068\000\068\000\069\000\069\000\
\070\000\070\000\071\000\071\000\072\000\072\000\073\000\073\000\
\074\000\074\000\074\000\074\000\074\000\074\000\074\000\074\000\
\074\000\074\000\074\000\074\000\010\000\008\000\008\000\008\000\
\008\000\008\000\008\000\009\000\075\000\017\000\017\000\018\000\
\018\000\018\000\076\000\076\000\076\000\012\000\012\000\020\000\
\020\000\060\000\060\000\019\000\019\000\019\000\077\000\077\000\
\021\000\021\000\021\000\022\000\022\000\078\000\015\000\015\000\
\011\000\011\000\013\000\013\000\079\000\079\000\014\000\016\000\
\034\000\080\000\081\000\081\000\035\000\035\000\035\000\035\000\
\035\000\083\000\083\000\085\000\085\000\036\000\036\000\037\000\
\037\000\086\000\086\000\084\000\084\000\084\000\084\000\084\000\
\084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
\084\000\084\000\084\000\084\000\084\000\084\000\084\000\084\000\
\084\000\084\000\084\000\084\000\087\000\087\000\092\000\093\000\
\088\000\088\000\030\000\030\000\030\000\030\000\040\000\040\000\
\039\000\039\000\094\000\094\000\094\000\094\000\094\000\094\000\
\094\000\094\000\023\000\023\000\098\000\098\000\096\000\096\000\
\097\000\097\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\025\000\025\000\025\000\025\000\025\000\043\000\043\000\042\000\
\042\000\042\000\029\000\029\000\028\000\028\000\041\000\100\000\
\100\000\100\000\044\000\044\000\044\000\044\000\044\000\102\000\
\103\000\104\000\104\000\104\000\027\000\027\000\027\000\027\000\
\026\000\105\000\038\000\038\000\053\000\053\000\053\000\106\000\
\106\000\048\000\049\000\049\000\033\000\033\000\047\000\047\000\
\045\000\045\000\045\000\045\000\046\000\046\000\031\000\031\000\
\032\000\032\000\032\000\032\000\032\000\050\000\050\000\050\000\
\050\000\005\000\005\000\006\000\006\000\006\000\095\000\095\000\
\095\000\095\000\089\000\089\000\101\000\101\000\101\000\101\000\
\101\000\108\000\108\000\099\000\099\000\052\000\052\000\052\000\
\052\000\110\000\110\000\110\000\110\000\110\000\110\000\111\000\
\111\000\112\000\112\000\113\000\113\000\113\000\114\000\114\000\
\115\000\115\000\115\000\116\000\116\000\116\000\116\000\116\000\
\116\000\116\000\117\000\117\000\117\000\117\000\117\000\117\000\
\117\000\117\000\117\000\117\000\117\000\118\000\119\000\119\000\
\119\000\119\000\120\000\120\000\120\000\121\000\121\000\121\000\
\122\000\122\000\122\000\122\000\122\000\123\000\123\000\123\000\
\124\000\124\000\125\000\125\000\126\000\126\000\127\000\127\000\
\128\000\128\000\129\000\129\000\130\000\109\000\131\000\131\000\
\132\000\132\000\082\000\107\000\007\000\007\000\007\000\090\000\
\090\000\091\000\091\000\133\000\133\000\135\000\135\000\136\000\
\134\000\134\000\137\000\137\000\138\000\138\000\138\000\140\000\
\140\000\139\000\139\000\000\000\000\000"

let yylen = "\002\000\
\001\000\002\000\000\000\002\000\003\000\002\000\002\000\002\000\
\001\000\001\000\001\000\001\000\001\000\003\000\005\000\005\000\
\001\000\006\000\004\000\001\000\001\000\001\000\000\000\001\000\
\001\000\001\000\001\000\003\000\001\000\002\000\004\000\006\000\
\006\000\006\000\003\000\003\000\002\000\002\000\006\000\001\000\
\003\000\002\000\001\000\002\000\002\000\002\000\004\000\002\000\
\004\000\002\000\002\000\002\000\002\000\002\000\002\000\002\000\
\001\000\004\000\001\000\003\000\003\000\003\000\001\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\003\000\003\000\
\003\000\001\000\003\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\005\000\
\001\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\002\000\001\000\
\002\000\002\000\001\000\001\000\001\000\001\000\003\000\001\000\
\003\000\000\000\001\000\003\000\002\000\001\000\001\000\000\000\
\003\000\004\000\005\000\000\000\001\000\002\000\000\000\001\000\
\000\000\001\000\001\000\003\000\000\000\001\000\003\000\003\000\
\005\000\001\000\000\000\002\000\001\000\003\000\003\000\003\000\
\003\000\000\000\001\000\002\000\004\000\000\000\004\000\001\000\
\003\000\001\000\002\000\001\000\002\000\002\000\001\000\003\000\
\005\000\003\000\004\000\006\000\009\000\004\000\004\000\006\000\
\003\000\002\000\003\000\002\000\002\000\003\000\004\000\008\000\
\007\000\001\000\005\000\004\000\000\000\001\000\001\000\001\000\
\002\000\001\000\003\000\002\000\004\000\003\000\001\000\003\000\
\001\000\003\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\002\000\002\000\002\000\002\000\000\000\001\000\
\000\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\002\000\003\000\005\000\
\004\000\006\000\005\000\002\000\005\000\004\000\006\000\005\000\
\002\000\006\000\005\000\007\000\006\000\001\000\004\000\004\000\
\000\000\003\000\002\000\004\000\002\000\001\000\003\000\001\000\
\004\000\002\000\001\000\003\000\001\000\003\000\003\000\002\000\
\004\000\003\000\001\000\004\000\004\000\003\000\004\000\001\000\
\002\000\000\000\002\000\003\000\002\000\002\000\001\000\003\000\
\002\000\005\000\001\000\003\000\000\000\004\000\004\000\001\000\
\003\000\003\000\000\000\001\000\002\000\001\000\003\000\001\000\
\004\000\004\000\004\000\003\000\001\000\000\000\003\000\002\000\
\002\000\002\000\004\000\005\000\003\000\001\000\001\000\001\000\
\001\000\000\000\002\000\000\000\002\000\005\000\004\000\002\000\
\001\000\001\000\000\000\002\000\001\000\001\000\001\000\001\000\
\001\000\004\000\002\000\001\000\002\000\002\000\003\000\004\000\
\001\000\001\000\001\000\003\000\001\000\001\000\003\000\001\000\
\001\000\001\000\002\000\001\000\002\000\003\000\001\000\001\000\
\001\000\003\000\001\000\001\000\002\000\003\000\002\000\003\000\
\003\000\004\000\001\000\002\000\004\000\002\000\004\000\002\000\
\002\000\002\000\002\000\002\000\002\000\001\000\001\000\003\000\
\003\000\003\000\001\000\003\000\003\000\001\000\003\000\003\000\
\001\000\003\000\003\000\003\000\003\000\001\000\003\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\006\000\000\000\001\000\001\000\003\000\
\000\000\001\000\003\000\003\000\000\000\002\000\002\000\001\000\
\002\000\000\000\003\000\000\000\001\000\001\000\003\000\005\000\
\000\000\003\000\000\000\003\000\000\000\002\000\003\000\001\000\
\003\000\000\000\002\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\010\000\057\001\011\000\000\000\
\246\000\221\000\220\000\223\000\227\000\226\000\219\000\225\000\
\000\000\000\000\203\000\000\000\228\000\229\000\224\000\222\000\
\055\001\000\000\205\000\054\001\056\001\206\000\207\000\066\001\
\000\000\000\000\208\000\000\000\000\000\000\000\065\001\081\001\
\000\000\000\000\180\001\001\000\000\000\000\000\000\000\000\000\
\012\000\013\000\000\000\209\000\017\000\000\000\210\000\181\001\
\000\000\204\000\000\000\000\000\000\000\000\000\020\000\021\000\
\000\000\000\000\000\000\022\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\115\000\116\000\117\000\
\000\000\000\000\110\000\006\000\000\000\000\000\000\000\000\000\
\064\001\000\000\000\000\000\000\086\001\085\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\078\001\099\001\000\000\000\000\089\001\000\000\100\001\000\000\
\118\001\119\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\150\001\009\000\000\000\000\000\
\000\000\002\000\004\000\000\000\196\000\050\001\000\000\000\000\
\000\000\036\001\000\000\000\000\000\000\212\000\218\000\146\000\
\048\001\000\000\216\000\211\000\000\000\198\000\000\000\047\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\003\001\000\000\000\000\075\001\000\000\000\000\000\000\077\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\014\000\111\000\
\000\000\000\000\000\000\025\000\104\000\105\000\102\000\103\000\
\112\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\026\000\106\000\000\000\027\000\000\000\000\000\000\000\029\000\
\000\000\057\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\089\000\101\000\000\000\
\000\000\000\000\000\000\108\001\000\000\110\001\112\001\113\001\
\114\001\117\001\115\001\116\001\000\000\000\000\000\000\101\001\
\000\000\079\001\082\001\083\001\096\001\000\000\000\000\095\001\
\103\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\149\001\007\000\
\008\000\005\000\073\001\072\001\070\001\071\001\000\000\069\001\
\000\000\000\000\195\000\000\000\000\000\000\000\011\001\025\001\
\214\000\213\000\000\000\000\000\053\001\000\000\197\000\000\000\
\019\000\000\000\000\000\021\001\022\001\000\000\000\000\000\000\
\017\001\051\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\251\000\000\000\000\000\000\000\000\000\000\000\000\000\
\233\000\253\000\000\000\000\000\000\000\238\000\000\000\000\000\
\000\000\000\000\000\000\000\000\154\001\000\000\063\001\000\000\
\000\000\046\000\000\000\048\000\050\000\051\000\052\000\055\000\
\053\000\054\000\056\000\000\000\044\000\045\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\247\000\114\000\113\000\
\037\001\000\000\248\000\000\000\000\000\037\000\038\000\000\000\
\000\000\030\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\155\001\087\001\000\000\000\000\098\001\084\001\102\001\
\080\001\091\001\000\000\104\001\105\001\000\000\120\001\121\001\
\122\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\001\059\001\200\000\000\000\118\000\202\000\000\000\
\000\000\000\000\000\000\007\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\028\001\000\000\000\000\024\001\000\000\
\000\000\000\000\000\000\019\001\000\000\006\001\004\001\243\000\
\074\001\000\000\000\000\000\000\002\001\250\000\000\000\000\000\
\000\000\232\000\235\000\000\000\237\000\240\000\000\000\015\000\
\156\001\016\000\000\000\000\000\000\000\000\000\143\000\000\000\
\028\000\000\000\000\000\000\000\000\000\036\000\035\000\136\000\
\000\000\000\000\090\000\091\000\092\000\093\000\094\000\095\000\
\096\000\097\000\098\000\099\000\100\000\060\000\061\000\062\000\
\059\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\138\000\152\001\000\000\000\000\094\001\106\001\000\000\
\000\000\000\000\000\000\126\000\000\000\123\000\000\000\000\000\
\000\000\000\000\000\000\014\001\000\000\000\000\000\000\000\000\
\000\000\000\000\061\001\000\000\000\000\000\000\148\000\000\000\
\000\000\000\000\000\000\155\000\052\001\000\000\000\000\018\000\
\000\000\000\000\000\000\039\001\000\000\000\000\020\001\242\000\
\245\000\000\000\000\000\255\000\252\000\234\000\239\000\000\000\
\000\000\000\000\140\000\000\000\058\000\000\000\000\000\000\000\
\000\000\031\000\144\000\000\000\000\000\000\000\000\000\000\000\
\127\000\000\000\134\000\119\000\125\000\012\001\000\000\000\000\
\142\000\008\001\013\001\000\000\000\000\015\001\159\000\161\000\
\156\000\000\000\145\000\000\000\192\000\000\000\164\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\186\000\000\000\000\000\167\000\000\000\000\000\000\000\
\000\000\190\000\191\000\000\000\000\000\000\000\044\001\000\000\
\000\000\244\000\001\001\000\000\000\000\000\000\040\000\000\000\
\088\000\148\001\133\000\129\000\000\000\000\000\121\000\124\000\
\026\001\010\001\000\000\000\000\000\000\000\000\000\000\162\000\
\000\000\165\000\180\000\181\000\000\000\000\000\178\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\166\000\150\000\152\000\000\000\151\000\000\000\
\000\000\000\000\033\001\030\001\031\001\041\001\043\001\042\001\
\039\000\032\000\033\000\000\000\034\000\042\000\130\000\000\000\
\009\001\062\001\157\000\000\000\163\000\000\000\182\000\179\000\
\170\000\000\000\000\000\177\000\000\000\000\000\000\000\158\001\
\159\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\041\000\131\000\183\000\175\000\000\000\000\000\000\000\188\000\
\000\000\109\000\000\000\000\000\174\000\068\001\171\000\000\000\
\000\000\194\000\000\000\000\000\169\000\187\000\000\000\161\001\
\000\000\000\000\000\000\193\000\000\000\176\000\000\000\000\000\
\000\000\000\000\166\001\000\000\000\000\172\000\000\000\000\000\
\000\000\000\000\163\001\000\000\000\000\185\000\000\000\184\000\
\172\001\000\000\167\001\000\000\000\000\000\000\170\001\000\000\
\173\000\000\000\000\000\174\001\000\000\168\001\179\001\000\000\
\175\001\177\001"

let yydgoto = "\003\000\
\043\000\044\000\045\000\046\000\031\001\196\001\186\002\209\000\
\210\000\103\001\025\002\036\002\131\002\212\000\249\001\122\001\
\082\000\213\000\037\002\038\002\039\002\156\002\170\000\048\000\
\171\000\134\000\158\000\161\000\162\000\049\000\050\000\051\000\
\215\000\133\002\058\002\044\001\199\001\155\000\135\000\136\000\
\084\001\070\001\071\001\209\001\210\001\211\001\142\002\138\000\
\072\001\052\000\129\000\172\000\206\001\107\000\039\001\061\001\
\216\000\217\000\152\002\041\002\218\000\219\000\220\000\221\000\
\222\000\223\000\224\000\225\000\226\000\227\000\228\000\229\000\
\230\000\231\000\243\002\083\000\098\002\042\002\106\002\146\000\
\202\001\089\000\059\002\168\002\169\002\170\002\137\002\251\002\
\228\002\244\002\002\003\138\002\139\002\054\000\055\000\148\000\
\142\000\143\000\070\000\048\002\033\001\062\000\159\000\057\001\
\040\001\063\002\186\000\071\000\232\000\109\000\110\000\255\000\
\000\001\001\001\111\000\112\000\113\000\114\000\115\000\116\000\
\117\000\118\000\119\000\120\000\121\000\122\000\123\000\124\000\
\125\000\185\001\233\000\086\001\009\003\019\003\010\003\011\003\
\012\003\031\003\036\003\037\003"

let yysindex = "\014\001\
\113\006\113\006\000\000\157\015\000\000\000\000\000\000\230\254\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\089\255\016\000\000\000\047\000\000\000\000\000\000\000\000\000\
\000\000\117\255\000\000\000\000\000\000\000\000\000\000\000\000\
\113\006\251\254\000\000\045\255\011\000\046\000\000\000\000\000\
\143\011\244\003\000\000\000\000\066\001\113\006\219\255\125\008\
\000\000\000\000\034\000\000\000\000\000\173\017\000\000\000\000\
\056\000\000\000\036\000\034\000\054\255\003\016\000\000\000\000\
\089\000\068\000\046\000\000\000\058\000\060\000\006\255\098\010\
\086\000\192\000\098\010\105\000\214\000\000\000\000\000\000\000\
\172\008\117\255\000\000\000\000\135\000\117\255\108\012\093\021\
\000\000\000\000\139\000\000\000\000\000\000\000\116\024\191\024\
\093\021\093\021\093\021\093\021\093\021\093\021\093\021\148\000\
\000\000\000\000\180\000\231\254\000\000\033\001\000\000\235\000\
\000\000\000\000\014\002\172\000\036\001\147\001\091\001\206\000\
\197\000\216\000\225\000\143\255\000\000\000\000\244\003\244\003\
\113\006\000\000\000\000\093\000\000\000\000\000\221\000\217\000\
\019\001\000\000\062\255\125\008\125\008\000\000\000\000\000\000\
\000\000\209\000\000\000\000\000\061\255\000\000\237\000\000\000\
\242\000\251\000\007\001\003\016\029\001\031\001\045\001\085\001\
\000\000\047\001\135\000\000\000\089\000\089\000\064\001\000\000\
\098\010\087\255\081\001\098\010\098\010\098\010\075\001\098\001\
\098\010\098\010\084\001\173\017\113\006\219\255\000\000\000\000\
\093\021\097\001\102\001\000\000\000\000\000\000\000\000\000\000\
\000\000\010\025\085\025\160\025\160\025\160\025\160\025\160\025\
\160\025\104\000\235\025\235\025\255\011\110\001\122\001\124\001\
\000\000\000\000\133\001\000\000\104\255\029\001\143\001\000\000\
\038\002\000\000\150\002\025\002\088\001\095\001\183\001\139\001\
\155\001\163\001\156\001\167\001\249\255\000\000\000\000\159\001\
\173\001\243\001\255\011\000\000\255\011\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\186\001\248\001\119\026\000\000\
\165\001\000\000\000\000\000\000\000\000\237\001\117\255\000\000\
\000\000\104\000\104\000\093\021\093\021\093\021\093\021\093\021\
\093\021\093\021\093\021\093\021\093\021\093\021\093\021\093\021\
\093\021\093\021\093\021\093\021\093\021\093\021\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\029\001\000\000\
\093\000\029\001\000\000\176\022\093\000\067\001\000\000\000\000\
\000\000\000\000\104\000\171\001\000\000\190\001\000\000\022\002\
\000\000\173\017\202\001\000\000\000\000\000\000\113\255\124\015\
\000\000\000\000\160\025\089\000\211\001\215\001\047\001\047\001\
\089\000\000\000\160\025\098\010\247\001\210\001\016\002\062\255\
\000\000\000\000\030\002\036\002\098\010\000\000\063\002\065\002\
\098\010\036\000\078\002\019\001\000\000\114\002\000\000\138\002\
\255\011\000\000\255\011\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\255\011\000\000\000\000\140\002\160\002\
\175\002\182\002\160\025\173\017\173\017\000\000\000\000\000\000\
\000\000\192\002\000\000\104\000\104\000\000\000\000\000\160\025\
\160\025\000\000\160\025\160\025\160\025\160\025\160\025\160\025\
\160\025\160\025\160\025\160\025\160\025\160\025\160\025\160\025\
\160\025\160\025\160\025\160\025\160\025\160\025\160\025\160\025\
\160\025\160\025\160\025\160\025\160\025\160\025\160\025\160\025\
\093\021\000\000\000\000\184\002\197\002\000\000\000\000\000\000\
\000\000\000\000\237\001\000\000\000\000\239\002\000\000\000\000\
\000\000\014\002\014\002\172\000\172\000\036\001\036\001\036\001\
\036\001\147\001\147\001\091\001\206\000\197\000\216\000\225\000\
\093\021\000\000\000\000\000\000\206\021\000\000\000\000\029\001\
\068\255\107\255\244\002\000\000\076\000\003\016\240\002\237\002\
\046\000\027\255\173\017\000\000\029\001\241\002\000\000\093\000\
\000\011\020\001\243\002\000\000\031\001\000\000\000\000\000\000\
\000\000\251\002\252\002\047\001\000\000\000\000\160\025\017\255\
\098\010\000\000\000\000\255\002\000\000\000\000\000\003\000\000\
\000\000\000\000\006\003\007\003\012\003\160\025\000\000\251\022\
\000\000\005\003\008\003\011\003\093\000\000\000\000\000\000\000\
\015\003\014\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\025\002\025\002\088\001\088\001\095\001\095\001\095\001\
\095\001\183\001\183\001\139\001\155\001\163\001\156\001\167\001\
\028\003\000\000\000\000\013\003\013\003\000\000\000\000\029\003\
\000\000\104\000\160\025\000\000\026\003\000\000\056\003\037\003\
\043\003\176\022\053\003\000\000\058\003\093\000\160\025\063\003\
\093\000\117\255\000\000\069\003\209\000\104\000\000\000\027\255\
\027\255\068\003\202\007\000\000\000\000\062\003\064\003\000\000\
\029\001\075\003\076\003\000\000\003\016\160\025\000\000\000\000\
\000\000\083\003\093\000\000\000\000\000\000\000\000\000\013\003\
\013\003\013\003\000\000\206\021\000\000\173\017\173\017\104\000\
\029\001\000\000\000\000\160\025\093\021\012\255\073\000\206\021\
\000\000\176\022\000\000\000\000\000\000\000\000\173\017\160\025\
\000\000\000\000\000\000\121\003\086\003\000\000\000\000\000\000\
\000\000\042\003\000\000\023\005\000\000\000\000\000\000\080\003\
\082\003\169\000\070\023\092\003\160\025\093\003\092\003\034\000\
\245\255\000\000\087\003\027\255\000\000\027\255\095\003\027\255\
\008\002\000\000\000\000\029\001\036\016\102\003\000\000\103\003\
\099\003\000\000\000\000\104\003\105\003\107\003\000\000\042\001\
\000\000\000\000\000\000\000\000\012\255\160\025\000\000\000\000\
\000\000\000\000\160\025\093\000\027\255\254\005\109\003\000\000\
\251\009\000\000\000\000\000\000\160\025\100\003\000\000\101\003\
\160\025\254\005\207\255\254\005\254\005\115\001\020\000\020\000\
\020\000\110\003\000\000\000\000\000\000\159\000\000\000\092\003\
\254\005\115\003\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\178\003\000\000\000\000\000\000\114\003\
\000\000\000\000\000\000\159\000\000\000\112\003\000\000\000\000\
\000\000\254\005\160\025\000\000\097\003\092\003\034\000\000\000\
\000\000\123\003\187\003\254\005\159\000\254\005\116\003\063\008\
\000\000\000\000\000\000\000\000\122\003\254\005\034\000\000\000\
\187\003\000\000\187\003\127\003\000\000\000\000\000\000\092\003\
\126\003\000\000\160\025\254\005\000\000\000\000\127\003\000\000\
\133\003\138\003\131\003\000\000\144\003\000\000\153\003\222\003\
\149\003\147\003\000\000\117\255\150\003\000\000\160\025\155\003\
\156\003\133\003\000\000\133\003\165\003\000\000\168\003\000\000\
\000\000\163\003\000\000\160\025\254\005\064\255\000\000\171\003\
\000\000\104\000\166\003\000\000\172\003\000\000\000\000\187\003\
\000\000\000\000"

let yyrindex = "\000\000\
\252\004\252\004\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\215\014\000\000\000\000\000\000\000\000\000\000\000\000\
\009\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\009\000\215\000\148\001\
\000\000\000\000\000\000\000\000\000\000\203\001\000\000\000\000\
\000\000\000\000\215\000\000\000\138\016\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\217\012\000\000\246\000\177\003\
\063\013\000\000\177\003\165\013\000\000\000\000\000\000\000\000\
\000\000\226\006\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\165\010\065\011\243\010\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\051\013\000\000\102\005\
\000\000\000\000\127\016\222\026\204\014\211\027\089\003\084\010\
\109\011\217\009\078\012\254\001\000\000\000\000\000\000\000\000\
\009\000\000\000\000\000\073\003\000\000\000\000\174\003\000\000\
\205\000\000\000\000\000\148\001\148\001\000\000\000\000\000\000\
\000\000\045\004\000\000\000\000\138\016\000\000\000\000\000\000\
\180\003\204\003\000\000\000\000\095\000\183\003\000\000\252\254\
\000\000\206\003\000\000\000\000\000\000\000\000\000\000\000\000\
\177\003\215\000\000\000\177\003\177\003\177\003\011\014\000\000\
\177\003\177\003\000\000\000\000\207\003\215\000\000\000\000\000\
\210\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\249\008\005\001\000\000\000\000\
\122\006\000\000\022\015\201\016\182\017\129\018\182\019\097\020\
\211\020\133\015\182\000\071\000\061\010\000\000\000\000\211\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\205\012\153\013\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\048\001\000\000\
\128\021\215\000\000\000\000\000\055\255\008\001\000\000\000\000\
\000\000\000\000\000\000\162\004\000\000\000\000\000\000\000\000\
\000\000\202\000\000\000\000\000\000\000\158\001\208\003\000\000\
\000\000\000\000\000\000\212\003\000\000\000\000\206\003\206\003\
\000\000\000\000\000\000\177\003\162\001\205\003\000\000\000\000\
\000\000\000\000\000\000\000\000\177\003\000\000\000\000\000\000\
\177\003\215\000\000\000\172\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\076\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\208\003\000\000\000\000\000\000\000\000\000\000\215\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\213\003\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\255\013\000\000\000\000\000\000\000\000\000\000\
\000\000\148\026\185\026\003\027\040\027\077\027\114\027\151\027\
\188\027\234\027\001\028\149\008\124\010\130\011\226\011\150\015\
\000\000\000\000\000\000\000\000\214\003\000\000\000\000\215\000\
\138\016\147\023\000\000\000\000\035\001\000\000\000\000\123\255\
\000\000\085\007\217\003\000\000\215\000\218\003\000\000\063\000\
\188\001\118\000\000\000\000\000\183\003\000\000\000\000\000\000\
\000\000\000\000\000\000\206\003\000\000\000\000\000\000\215\000\
\177\003\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\199\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\008\017\071\017\003\018\066\018\192\018\255\018\062\019\
\125\019\239\019\040\020\154\020\012\021\012\016\032\021\104\001\
\000\000\000\000\000\000\216\005\101\014\000\000\000\000\000\000\
\080\028\000\000\000\000\000\000\216\003\000\000\222\023\000\000\
\000\000\000\000\000\000\000\000\000\000\054\026\219\003\000\000\
\026\022\000\000\000\000\000\000\045\004\000\000\000\000\149\002\
\010\003\000\000\034\001\000\000\000\000\209\003\000\000\000\000\
\102\255\138\016\138\016\000\000\000\000\219\003\000\000\000\000\
\000\000\000\000\191\001\000\000\000\000\000\000\000\000\079\009\
\165\009\000\000\000\000\214\003\000\000\000\000\000\000\000\000\
\134\000\000\000\000\000\000\000\000\000\101\022\000\000\214\003\
\000\000\000\000\000\000\000\000\000\000\000\000\217\003\000\000\
\000\000\000\000\000\000\041\024\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\037\002\000\000\113\014\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\221\003\000\000\000\000\149\002\000\000\149\002\000\000\149\002\
\000\000\000\000\000\000\215\000\202\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\101\022\000\000\000\000\000\000\
\000\000\000\000\000\000\176\001\149\002\037\002\000\000\000\000\
\037\002\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\037\002\000\000\037\002\037\002\000\000\221\003\221\003\
\221\003\000\000\000\000\000\000\000\000\128\003\000\000\000\000\
\037\002\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\140\005\000\000\000\000\000\000\000\000\
\000\000\037\002\000\000\000\000\032\002\000\000\000\000\000\000\
\000\000\000\000\000\000\037\002\140\005\037\002\000\000\220\003\
\000\000\000\000\000\000\000\000\000\000\037\002\000\000\000\000\
\000\000\000\000\099\255\223\003\000\000\000\000\000\000\000\000\
\000\000\000\000\220\003\037\002\000\000\000\000\223\003\000\000\
\014\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\225\003\140\255\000\000\000\000\000\000\000\000\226\003\000\000\
\000\000\014\000\000\000\121\255\000\000\000\000\000\000\000\000\
\000\000\232\003\000\000\000\000\037\002\010\004\000\000\000\000\
\000\000\000\000\246\255\000\000\010\004\000\000\000\000\000\000\
\000\000\000\000"

let yygindex = "\000\000\
\000\000\084\005\033\000\000\000\179\255\146\003\022\001\000\000\
\240\255\234\255\088\254\232\254\103\000\081\254\000\000\193\002\
\000\000\000\000\000\000\000\000\196\253\187\002\109\000\248\255\
\236\255\000\000\126\255\032\004\135\255\218\255\243\000\090\005\
\075\255\216\255\011\255\044\003\229\253\125\255\000\000\230\255\
\214\255\000\000\130\003\212\004\000\000\000\000\141\255\101\255\
\004\000\000\000\212\002\006\000\076\254\239\255\018\000\224\254\
\000\000\000\000\000\000\185\254\031\000\099\000\213\001\072\002\
\060\002\070\002\224\003\228\003\203\003\230\003\231\003\000\000\
\019\003\183\002\200\253\202\255\000\000\000\000\030\003\000\000\
\000\000\195\255\241\253\234\253\067\254\076\008\000\000\000\000\
\126\002\190\254\103\002\000\000\000\000\146\000\139\255\000\000\
\079\003\000\000\029\000\000\000\010\255\239\254\087\254\159\003\
\000\000\223\002\205\004\000\000\229\255\000\000\162\255\119\004\
\237\003\000\000\000\000\000\000\000\000\005\000\225\002\238\002\
\216\002\045\003\107\004\108\004\109\004\110\004\123\004\000\000\
\093\254\000\000\090\255\000\000\112\002\000\000\000\000\133\002\
\000\000\000\000\109\002\128\002"

let yytablesize = 7590
let yytable = "\068\000\
\068\000\054\001\068\000\127\000\137\000\164\000\053\000\053\000\
\003\000\081\000\145\000\191\001\060\002\108\000\032\001\254\000\
\137\000\046\001\085\001\152\000\198\001\032\002\061\002\105\001\
\106\000\051\001\112\002\184\000\052\002\056\002\218\001\219\001\
\151\000\155\002\069\000\073\000\136\002\076\000\053\000\140\000\
\113\002\053\001\183\000\063\001\064\001\248\000\074\000\197\001\
\077\000\061\000\139\000\053\000\068\000\156\001\176\000\157\001\
\068\000\249\000\054\001\068\000\153\000\058\001\139\000\034\002\
\211\000\084\000\058\001\153\000\063\000\187\000\085\000\106\000\
\005\001\064\000\153\000\245\000\242\002\132\000\131\000\005\001\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\167\000\
\127\000\127\000\035\002\175\000\250\000\253\000\179\000\063\000\
\155\002\067\001\113\001\168\000\064\000\239\000\240\000\241\000\
\242\000\243\000\244\000\066\000\035\001\047\000\047\000\027\001\
\059\000\035\001\052\001\058\001\078\000\111\001\067\000\063\000\
\086\000\068\000\060\002\060\002\064\000\236\000\238\000\069\001\
\154\000\078\000\058\001\140\000\140\000\171\001\053\000\045\001\
\028\001\037\001\046\002\029\001\030\001\047\000\044\002\032\000\
\034\003\057\002\213\002\132\000\066\001\211\002\047\000\074\001\
\075\001\076\001\047\000\144\002\079\001\080\001\112\001\254\000\
\055\001\026\001\147\000\235\001\106\001\236\001\065\000\067\001\
\106\000\068\001\157\000\032\001\204\001\160\001\237\001\032\001\
\032\001\035\001\161\002\160\001\035\001\213\001\243\001\244\001\
\099\001\154\002\053\000\074\002\208\001\182\000\066\000\198\001\
\069\002\141\000\106\001\214\000\106\001\160\000\060\002\220\001\
\060\002\067\000\060\002\049\002\178\002\160\000\197\001\181\002\
\034\000\079\000\080\000\187\001\022\001\083\001\165\001\192\001\
\197\002\114\001\197\001\038\000\165\001\039\000\079\000\080\000\
\090\001\092\001\171\001\171\001\023\001\035\003\106\000\060\002\
\166\001\101\001\102\001\047\000\047\000\047\000\163\001\035\003\
\068\000\068\000\027\002\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\106\000\106\000\
\106\000\106\000\106\000\106\000\106\000\106\000\039\003\188\001\
\157\000\167\001\168\001\169\001\148\002\190\001\001\000\002\000\
\230\002\101\002\183\002\164\001\165\001\184\002\063\000\132\000\
\159\002\200\001\171\001\064\000\128\000\141\000\141\000\218\002\
\082\001\047\000\186\001\219\002\214\001\068\000\093\001\094\001\
\095\001\096\001\097\001\098\001\221\001\133\000\239\002\222\001\
\106\001\183\002\106\001\104\001\184\002\063\000\068\000\151\000\
\228\001\214\000\064\000\106\001\231\001\045\002\151\001\249\002\
\176\001\130\000\063\000\114\002\254\000\058\001\176\001\064\000\
\003\003\160\002\058\001\085\000\032\001\185\002\152\001\032\001\
\027\001\104\001\005\003\104\001\242\001\003\000\087\000\214\000\
\164\001\214\000\032\001\032\001\032\001\072\000\164\001\160\000\
\132\000\027\001\068\000\068\000\085\000\035\001\023\003\085\000\
\085\000\028\001\035\001\085\000\029\001\030\001\063\000\144\000\
\032\000\128\000\128\000\064\000\047\002\066\000\150\000\171\001\
\171\001\088\000\028\001\058\001\075\000\029\001\030\001\032\001\
\067\000\032\000\065\002\149\000\068\002\246\001\247\001\165\000\
\106\000\166\000\058\001\055\002\085\000\058\001\188\002\163\000\
\189\002\085\000\191\002\085\000\066\000\043\002\085\000\085\000\
\157\002\085\000\085\000\085\000\085\000\158\002\205\001\067\000\
\149\002\150\002\062\002\173\000\157\000\054\001\190\001\089\002\
\106\000\023\001\035\001\068\000\085\000\035\001\255\002\063\000\
\000\003\034\000\023\001\195\001\064\000\069\001\177\000\085\000\
\032\001\085\000\083\000\032\001\038\000\054\001\039\000\104\001\
\058\001\104\001\034\000\032\000\045\001\214\000\063\000\214\000\
\075\002\058\001\104\001\064\000\077\002\038\000\040\002\039\000\
\214\000\035\001\185\000\083\000\035\001\032\001\083\000\083\000\
\214\000\214\000\083\000\234\000\063\000\035\001\248\001\250\001\
\104\002\064\000\035\001\108\002\246\000\173\002\008\001\009\001\
\006\002\007\002\008\002\009\002\009\002\009\002\009\002\009\002\
\009\002\009\002\009\002\009\002\009\002\009\002\009\002\009\002\
\009\002\009\002\083\000\083\000\076\001\147\002\026\002\247\000\
\083\000\076\001\083\000\058\001\034\000\083\000\083\000\019\001\
\083\000\083\000\083\000\083\000\095\002\174\000\018\001\038\000\
\068\000\039\000\058\001\190\001\132\002\058\001\043\002\029\001\
\027\001\020\001\049\001\083\000\029\001\002\001\003\001\201\000\
\201\000\109\002\035\001\178\000\200\001\021\001\083\000\251\000\
\083\000\135\002\091\000\035\001\252\000\078\000\032\001\060\001\
\034\001\028\001\157\000\094\002\029\001\030\001\035\001\205\001\
\032\000\004\001\036\001\035\001\043\001\190\001\093\000\047\001\
\134\002\094\000\068\000\076\001\055\001\048\001\068\000\027\001\
\229\002\190\001\060\001\190\001\106\000\049\001\068\000\038\001\
\035\001\050\001\085\002\035\001\083\002\060\001\210\002\182\002\
\038\001\132\000\060\001\060\001\114\001\204\002\229\002\067\002\
\028\001\062\002\167\002\029\001\030\001\040\002\179\002\032\000\
\174\002\151\002\010\001\011\001\086\000\060\001\149\000\229\002\
\060\001\040\002\056\001\060\001\205\002\060\001\060\001\058\001\
\121\001\034\000\035\001\035\001\059\001\104\000\035\001\189\000\
\189\000\189\000\060\001\035\001\038\000\086\000\039\000\208\002\
\086\000\086\000\079\000\080\000\086\000\065\001\193\001\016\001\
\017\001\194\001\137\001\138\001\167\002\105\002\139\000\167\002\
\077\001\149\000\217\000\139\000\139\000\073\001\139\000\217\000\
\167\002\081\001\167\002\167\002\036\001\139\001\140\001\182\000\
\034\000\036\001\195\001\087\001\105\002\086\000\078\001\167\002\
\088\001\157\000\086\000\038\000\086\000\039\000\240\002\086\000\
\086\000\107\001\086\000\086\000\086\000\086\000\009\002\145\001\
\146\001\250\002\214\000\214\000\237\002\108\001\254\002\109\001\
\167\002\012\001\013\001\014\001\015\001\086\000\162\002\110\001\
\217\000\215\000\167\002\205\001\167\002\222\002\223\002\058\001\
\086\000\115\001\086\000\147\001\167\002\149\001\217\000\217\000\
\082\001\176\002\217\000\060\001\217\000\148\001\217\000\217\000\
\040\001\036\001\167\002\150\001\036\001\141\001\142\001\143\001\
\144\001\040\001\153\001\251\000\000\001\000\001\091\000\154\001\
\252\000\205\001\058\001\021\003\155\001\058\001\201\000\201\000\
\058\001\159\001\058\001\058\001\158\001\032\003\060\001\215\000\
\203\001\209\002\093\000\167\002\060\001\094\000\060\001\060\001\
\200\001\058\001\058\001\214\002\207\001\215\000\215\000\104\001\
\201\001\215\000\161\001\215\000\153\000\215\000\215\000\216\001\
\168\000\217\001\168\000\168\000\168\000\224\001\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\223\001\
\147\001\104\000\005\001\006\001\007\001\147\001\026\002\147\001\
\147\001\147\001\024\001\025\001\182\000\134\001\135\001\136\001\
\116\001\117\001\168\000\168\000\168\000\010\002\011\002\168\000\
\168\000\026\002\225\001\168\000\168\000\192\002\193\002\194\002\
\168\000\168\000\226\001\168\000\168\000\168\000\118\001\119\001\
\227\001\120\001\168\000\147\001\121\001\026\002\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\168\000\168\000\168\000\
\168\000\168\000\189\000\189\000\189\000\168\000\168\000\168\000\
\168\000\168\000\168\000\229\001\168\000\230\001\168\000\168\000\
\168\000\168\000\168\000\168\000\168\000\154\000\168\000\168\000\
\154\000\154\000\232\001\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\233\001\123\001\124\001\125\001\
\126\001\127\001\128\001\129\001\130\001\131\001\132\001\133\001\
\014\002\015\002\016\002\017\002\224\002\225\002\226\002\154\000\
\154\000\154\000\012\002\013\002\154\000\154\000\018\002\019\002\
\154\000\154\000\041\001\042\001\234\001\154\000\154\000\238\001\
\154\000\154\000\154\000\174\001\175\001\176\001\177\001\154\000\
\170\001\171\001\239\001\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\172\001\
\173\001\240\001\154\000\154\000\154\000\154\000\154\000\154\000\
\241\001\154\000\028\002\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\245\001\154\000\154\000\154\000\029\002\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\251\001\252\001\253\001\254\001\255\001\000\002\001\002\
\002\002\003\002\004\002\005\002\178\001\179\001\031\002\050\002\
\054\002\070\002\053\002\064\002\154\000\154\000\154\000\072\002\
\073\002\154\000\154\000\078\002\079\002\154\000\154\000\058\001\
\080\002\081\002\154\000\154\000\058\001\154\000\082\002\154\000\
\086\002\090\002\084\002\087\002\154\000\091\002\088\002\097\002\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\092\002\096\002\093\002\154\000\
\154\000\154\000\154\000\154\000\154\000\099\002\154\000\100\002\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\102\002\
\067\001\154\000\067\001\067\001\103\002\058\001\067\001\067\001\
\067\001\067\001\067\001\067\001\067\001\067\001\107\002\110\002\
\115\002\140\002\141\002\058\001\058\001\044\002\143\002\058\001\
\163\002\137\001\137\001\137\001\058\001\137\001\137\001\146\002\
\164\002\165\002\171\002\137\001\172\002\067\001\067\001\177\002\
\137\001\187\002\137\001\137\001\137\001\180\002\137\001\190\002\
\198\002\199\002\200\002\202\002\201\002\203\002\215\002\216\002\
\233\002\227\002\067\001\067\001\067\001\212\002\232\002\067\001\
\067\001\234\002\235\002\067\001\067\001\238\002\241\002\242\002\
\067\001\067\001\252\002\067\001\153\000\067\001\137\001\001\003\
\004\003\248\002\067\001\008\003\013\003\014\003\067\001\067\001\
\067\001\067\001\067\001\067\001\067\001\067\001\067\001\067\001\
\067\001\067\001\015\003\016\003\017\003\018\003\020\003\067\001\
\022\003\067\001\067\001\025\003\067\001\024\003\067\001\067\001\
\028\003\067\001\029\003\030\003\004\000\038\003\067\001\153\000\
\006\000\040\003\057\000\003\000\034\003\249\000\027\001\009\000\
\199\000\018\001\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\053\001\023\000\003\000\153\001\151\001\046\001\254\000\
\024\000\135\000\122\000\032\001\120\000\137\000\029\001\052\001\
\157\001\162\001\141\000\169\001\137\000\158\000\137\000\158\000\
\158\000\158\000\173\001\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\178\001\056\000\051\002\207\002\
\206\002\034\000\035\000\215\001\037\000\060\000\038\001\022\002\
\111\002\076\002\246\002\145\002\038\000\007\003\039\000\158\000\
\158\000\158\000\195\002\126\000\158\000\158\000\153\002\062\001\
\158\000\158\000\020\002\071\002\162\001\158\000\158\000\021\002\
\158\000\158\000\158\000\023\002\180\001\024\002\181\001\158\000\
\182\001\026\003\183\001\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\158\000\158\000\158\000\158\000\158\000\030\002\
\184\001\041\003\158\000\158\000\158\000\158\000\158\000\158\000\
\027\003\158\000\158\000\158\000\158\000\158\000\158\000\158\000\
\158\000\158\000\147\000\158\000\147\000\147\000\147\000\042\003\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\147\000\147\000\147\000\000\000\
\000\000\147\000\147\000\000\000\000\000\147\000\147\000\000\000\
\000\000\000\000\147\000\147\000\000\000\147\000\147\000\147\000\
\000\000\000\000\000\000\000\000\147\000\000\000\000\000\000\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\147\000\
\147\000\147\000\147\000\147\000\000\000\000\000\000\000\147\000\
\147\000\147\000\147\000\147\000\147\000\000\000\147\000\000\000\
\147\000\147\000\147\000\147\000\147\000\147\000\147\000\166\002\
\147\000\056\002\117\002\006\000\000\000\033\002\189\000\190\000\
\191\000\192\000\118\002\078\000\193\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\058\000\027\000\028\000\
\029\000\030\000\031\000\032\000\194\000\195\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\196\000\197\000\198\000\000\000\000\000\199\000\200\000\
\000\000\000\000\201\000\202\000\000\000\000\000\000\000\203\000\
\204\000\000\000\205\000\000\000\144\000\000\000\000\000\000\000\
\000\000\119\002\000\000\000\000\000\000\120\002\121\002\122\002\
\123\002\124\002\125\002\126\002\000\000\000\000\000\000\127\002\
\128\002\000\000\000\000\000\000\034\000\035\000\129\002\037\000\
\079\000\080\000\000\000\206\000\000\000\207\000\208\000\038\000\
\130\002\039\000\000\000\000\000\067\001\057\002\067\001\067\001\
\000\000\000\000\067\001\067\001\067\001\067\001\067\001\067\001\
\067\001\067\001\107\001\107\001\107\001\107\001\107\001\107\001\
\107\001\107\001\107\001\107\001\107\001\000\000\107\001\107\001\
\107\001\000\000\107\001\107\001\107\001\107\001\000\000\000\000\
\107\001\067\001\067\001\000\000\000\000\107\001\000\000\107\001\
\107\001\107\001\000\000\107\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\067\001\067\001\
\067\001\000\000\000\000\067\001\067\001\000\000\000\000\067\001\
\067\001\000\000\000\000\000\000\067\001\067\001\000\000\067\001\
\000\000\067\001\000\000\107\001\000\000\000\000\067\001\000\000\
\000\000\000\000\067\001\067\001\067\001\067\001\067\001\067\001\
\067\001\067\001\067\001\067\001\067\001\067\001\000\000\000\000\
\000\000\000\000\000\000\067\001\000\000\067\001\067\001\000\000\
\067\001\000\000\067\001\067\001\000\000\067\001\166\002\000\000\
\056\002\117\002\067\001\000\000\033\002\189\000\190\000\191\000\
\192\000\064\000\078\000\193\000\109\001\109\001\109\001\109\001\
\109\001\109\001\109\001\109\001\109\001\109\001\109\001\000\000\
\109\001\109\001\109\001\000\000\109\001\109\001\109\001\109\001\
\000\000\000\000\109\001\194\000\195\000\000\000\000\000\109\001\
\000\000\109\001\109\001\109\001\000\000\109\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\196\000\197\000\198\000\000\000\000\000\199\000\200\000\000\000\
\000\000\201\000\202\000\000\000\000\000\000\000\203\000\204\000\
\000\000\205\000\000\000\144\000\000\000\109\001\000\000\000\000\
\119\002\000\000\000\000\000\000\120\002\121\002\122\002\123\002\
\124\002\125\002\126\002\000\000\000\000\000\000\127\002\128\002\
\000\000\000\000\000\000\000\000\000\000\129\002\000\000\079\000\
\080\000\000\000\206\000\000\000\207\000\208\000\000\000\130\002\
\000\000\004\000\005\000\000\000\057\002\006\000\007\000\008\000\
\000\000\000\000\000\000\000\000\009\000\000\000\043\000\010\000\
\011\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\025\000\026\000\
\027\000\028\000\029\000\030\000\031\000\032\000\000\000\043\000\
\000\000\000\000\043\000\043\000\000\000\000\000\043\000\000\000\
\000\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\043\000\043\000\043\000\000\000\000\000\043\000\043\000\
\043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\043\000\000\000\043\000\043\000\043\000\000\000\043\000\043\000\
\043\000\043\000\000\000\033\000\043\000\000\000\043\000\000\000\
\000\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
\000\000\000\000\000\000\000\000\000\000\000\000\034\000\035\000\
\036\000\037\000\000\000\000\000\000\000\000\000\000\000\043\000\
\000\000\038\000\108\000\039\000\040\000\041\000\108\000\042\000\
\108\000\000\000\043\000\108\000\043\000\108\000\000\000\043\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\000\000\
\000\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\000\000\108\000\108\000\108\000\000\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\108\000\108\000\108\000\108\000\108\000\108\000\108\000\108\000\
\000\000\000\000\000\000\000\000\000\000\000\000\108\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\108\000\
\108\000\000\000\108\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\108\000\000\000\108\000\154\000\000\000\108\000\
\154\000\154\000\000\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\154\000\
\154\000\154\000\000\000\000\000\154\000\154\000\000\000\000\000\
\154\000\154\000\000\000\000\000\000\000\154\000\154\000\000\000\
\154\000\154\000\154\000\000\000\000\000\000\000\000\000\154\000\
\000\000\000\000\000\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\154\000\154\000\154\000\154\000\154\000\000\000\
\000\000\000\000\154\000\154\000\154\000\154\000\154\000\154\000\
\000\000\154\000\000\000\154\000\154\000\154\000\154\000\154\000\
\154\000\154\000\116\002\000\000\000\000\117\002\006\000\000\000\
\033\002\189\000\190\000\191\000\192\000\118\002\078\000\193\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\058\000\027\000\028\000\029\000\030\000\031\000\032\000\194\000\
\195\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\196\000\197\000\198\000\000\000\
\000\000\199\000\200\000\000\000\000\000\201\000\202\000\000\000\
\000\000\000\000\203\000\204\000\000\000\205\000\000\000\144\000\
\000\000\000\000\000\000\000\000\119\002\000\000\000\000\000\000\
\120\002\121\002\122\002\123\002\124\002\125\002\126\002\000\000\
\000\000\000\000\127\002\128\002\000\000\000\000\000\000\034\000\
\035\000\129\002\037\000\079\000\080\000\000\000\206\000\000\000\
\207\000\208\000\038\000\130\002\039\000\040\000\041\000\180\000\
\000\000\000\000\000\000\006\000\000\000\188\000\189\000\190\000\
\191\000\192\000\009\000\078\000\193\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\058\000\027\000\028\000\
\029\000\030\000\031\000\032\000\194\000\195\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\196\000\197\000\198\000\000\000\000\000\199\000\200\000\
\000\000\006\000\201\000\202\000\000\000\000\000\000\000\203\000\
\204\000\000\000\205\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\058\000\027\000\028\000\029\000\030\000\
\031\000\032\000\000\000\000\000\034\000\035\000\000\000\037\000\
\079\000\080\000\000\000\206\000\180\000\207\000\208\000\038\000\
\006\000\039\000\000\000\000\000\000\000\000\000\000\000\009\000\
\000\000\000\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\000\000\000\000\000\000\000\000\138\001\138\001\138\001\
\000\000\138\001\138\001\000\000\000\000\000\000\000\000\138\001\
\000\000\000\000\034\000\035\000\138\001\037\000\138\001\138\001\
\138\001\000\000\138\001\000\000\000\000\038\000\000\000\039\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\181\000\000\000\000\000\000\000\107\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\138\001\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\000\000\107\000\000\000\
\000\000\107\000\107\000\000\000\038\000\107\000\039\000\000\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\107\000\
\000\000\107\000\107\000\107\000\000\000\107\000\107\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\000\000\107\000\
\107\000\107\000\107\000\107\000\107\000\107\000\107\000\000\000\
\000\000\000\000\000\000\047\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\107\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\107\000\000\000\107\000\047\000\000\000\107\000\047\000\
\047\000\000\000\000\000\047\000\000\000\000\000\047\000\047\000\
\047\000\047\000\047\000\047\000\047\000\047\000\047\000\047\000\
\047\000\000\000\000\000\047\000\047\000\047\000\047\000\047\000\
\047\000\047\000\047\000\047\000\047\000\047\000\000\000\047\000\
\047\000\047\000\000\000\047\000\047\000\047\000\047\000\000\000\
\000\000\047\000\000\000\047\000\000\000\000\000\047\000\047\000\
\047\000\047\000\047\000\047\000\047\000\000\000\000\000\000\000\
\000\000\049\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\047\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\047\000\
\000\000\047\000\049\000\000\000\047\000\049\000\049\000\000\000\
\000\000\049\000\000\000\000\000\049\000\049\000\049\000\049\000\
\049\000\049\000\049\000\049\000\049\000\049\000\049\000\000\000\
\000\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
\049\000\049\000\049\000\049\000\000\000\049\000\049\000\049\000\
\000\000\049\000\049\000\049\000\049\000\000\000\000\000\049\000\
\000\000\049\000\000\000\000\000\049\000\049\000\049\000\049\000\
\049\000\049\000\049\000\166\002\000\000\217\002\117\002\220\002\
\221\002\033\002\189\000\190\000\191\000\192\000\064\000\078\000\
\193\000\000\000\049\000\000\000\231\002\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\049\000\000\000\049\000\
\000\000\000\000\049\000\000\000\000\000\143\001\143\001\000\000\
\194\000\195\000\000\000\143\001\000\000\236\002\000\000\000\000\
\143\001\000\000\143\001\143\001\143\001\000\000\143\001\245\002\
\000\000\247\002\000\000\000\000\000\000\196\000\197\000\198\000\
\000\000\253\002\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\087\000\000\000\203\000\204\000\000\000\205\000\006\003\
\144\000\000\000\000\000\000\000\000\000\119\002\143\001\000\000\
\000\000\120\002\121\002\122\002\123\002\124\002\125\002\126\002\
\000\000\000\000\087\000\127\002\128\002\087\000\087\000\000\000\
\000\000\087\000\129\002\000\000\079\000\080\000\006\000\206\000\
\033\003\207\000\208\000\000\000\130\002\009\000\000\000\000\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\058\000\027\000\028\000\029\000\030\000\031\000\032\000\087\000\
\000\000\087\000\000\000\000\000\087\000\087\000\000\000\087\000\
\087\000\087\000\000\000\000\000\000\000\139\001\139\001\000\000\
\139\001\139\001\000\000\000\000\000\000\000\000\139\001\000\000\
\000\000\000\000\087\000\139\001\000\000\139\001\139\001\139\001\
\000\000\139\001\000\000\082\001\000\000\087\000\082\001\087\000\
\082\001\082\001\000\000\000\000\169\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\140\001\140\001\000\000\
\140\001\140\001\082\001\000\000\000\000\082\001\140\001\034\000\
\035\000\139\001\037\000\140\001\000\000\140\001\140\001\140\001\
\000\000\140\001\038\000\000\000\039\000\040\000\041\000\082\001\
\082\001\082\001\082\001\082\001\082\001\082\001\082\001\082\001\
\082\001\082\001\082\001\082\001\000\000\082\001\082\001\082\001\
\000\000\082\001\082\001\082\001\082\001\000\000\000\000\082\001\
\020\000\140\001\000\000\082\001\082\001\000\000\082\001\082\001\
\082\001\083\001\082\001\000\000\083\001\000\000\083\001\083\001\
\000\000\082\001\000\000\000\000\027\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\082\001\082\001\
\083\001\000\000\000\000\083\001\000\000\000\000\000\000\000\000\
\000\000\000\000\082\001\000\000\000\000\028\001\000\000\000\000\
\029\001\030\001\000\000\000\000\032\000\083\001\083\001\083\001\
\083\001\083\001\083\001\083\001\083\001\083\001\083\001\083\001\
\083\001\083\001\000\000\083\001\083\001\083\001\000\000\083\001\
\083\001\083\001\083\001\000\000\000\000\083\001\021\000\000\000\
\000\000\083\001\083\001\000\000\083\001\083\001\083\001\088\001\
\083\001\000\000\088\001\066\002\088\001\088\001\194\001\083\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\083\001\083\001\088\001\000\000\
\000\000\088\001\000\000\000\000\000\000\034\000\000\000\195\001\
\083\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\038\000\000\000\039\000\088\001\088\001\088\001\088\001\088\001\
\088\001\088\001\088\001\088\001\088\001\088\001\088\001\088\001\
\000\000\088\001\088\001\088\001\000\000\088\001\088\001\088\001\
\088\001\000\000\000\000\088\001\000\000\000\000\000\000\088\001\
\088\001\000\000\088\001\088\001\088\001\090\000\088\001\000\000\
\091\000\000\000\092\000\078\000\000\000\088\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\088\001\088\001\093\000\000\000\141\001\094\000\
\000\000\141\001\141\001\000\000\095\000\096\000\088\001\141\001\
\000\000\000\000\000\000\000\000\141\001\000\000\141\001\141\001\
\141\001\000\000\141\001\142\001\000\000\000\000\142\001\142\001\
\000\000\097\000\098\000\099\000\142\001\000\000\100\000\101\000\
\000\000\142\001\102\000\142\001\142\001\142\001\000\000\142\001\
\000\000\000\000\103\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\141\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\104\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\142\001\
\079\000\080\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\006\000\105\000\188\000\189\000\190\000\
\191\000\192\000\009\000\078\000\193\000\010\000\011\000\012\000\
\013\000\014\000\015\000\016\000\017\000\018\000\019\000\020\000\
\021\000\022\000\023\000\024\000\025\000\058\000\027\000\028\000\
\029\000\030\000\031\000\032\000\194\000\195\000\144\001\144\001\
\000\000\000\000\000\000\000\000\144\001\000\000\000\000\000\000\
\000\000\144\001\000\000\144\001\144\001\144\001\000\000\144\001\
\000\000\196\000\197\000\198\000\000\000\000\000\199\000\200\000\
\000\000\000\000\201\000\202\000\000\000\000\000\000\000\203\000\
\204\000\000\000\205\000\000\000\144\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\144\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\034\000\035\000\000\000\037\000\
\079\000\080\000\000\000\206\000\000\000\207\000\208\000\038\000\
\006\000\039\000\188\000\189\000\190\000\191\000\192\000\009\000\
\078\000\193\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\194\000\195\000\145\001\000\000\000\000\000\000\000\000\
\145\001\000\000\000\000\000\000\000\000\145\001\000\000\145\001\
\145\001\145\001\000\000\145\001\000\000\000\000\196\000\197\000\
\198\000\000\000\000\000\199\000\200\000\000\000\000\000\201\000\
\202\000\000\000\000\000\000\000\203\000\204\000\000\000\205\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\145\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\079\000\080\000\000\000\
\206\000\090\001\207\000\208\000\038\000\241\000\039\000\241\000\
\000\000\000\000\000\000\000\000\241\000\000\000\000\000\241\000\
\241\000\241\000\241\000\241\000\241\000\241\000\241\000\241\000\
\241\000\241\000\241\000\241\000\241\000\241\000\241\000\241\000\
\241\000\241\000\241\000\241\000\241\000\241\000\000\000\090\001\
\090\001\090\001\090\001\090\001\090\001\090\001\090\001\090\001\
\090\001\090\001\090\001\090\001\000\000\090\001\090\001\090\001\
\000\000\090\001\090\001\090\001\090\001\241\000\000\000\090\001\
\000\000\000\000\000\000\090\001\090\001\000\000\090\001\090\001\
\090\001\000\000\090\001\241\000\241\000\000\000\000\000\241\000\
\000\000\241\000\000\000\241\000\241\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\090\001\090\001\
\000\000\000\000\000\000\000\000\000\000\000\000\241\000\241\000\
\000\000\241\000\090\001\230\000\000\000\230\000\000\000\000\000\
\000\000\241\000\230\000\241\000\000\000\230\000\230\000\230\000\
\230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
\230\000\230\000\230\000\230\000\230\000\230\000\230\000\230\000\
\230\000\230\000\230\000\230\000\000\000\097\001\097\001\097\001\
\097\001\097\001\097\001\097\001\097\001\097\001\097\001\097\001\
\097\001\097\001\000\000\097\001\097\001\097\001\000\000\097\001\
\097\001\097\001\097\001\230\000\000\000\097\001\000\000\000\000\
\000\000\097\001\097\001\000\000\097\001\097\001\097\001\000\000\
\097\001\230\000\230\000\000\000\000\000\230\000\000\000\230\000\
\000\000\230\000\230\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\230\000\230\000\000\000\230\000\
\097\001\236\000\000\000\236\000\000\000\000\000\000\000\230\000\
\236\000\230\000\000\000\236\000\236\000\236\000\236\000\236\000\
\236\000\236\000\236\000\236\000\236\000\236\000\236\000\236\000\
\236\000\236\000\236\000\236\000\236\000\236\000\236\000\236\000\
\236\000\236\000\000\000\092\001\092\001\092\001\092\001\092\001\
\092\001\092\001\092\001\092\001\092\001\092\001\092\001\092\001\
\000\000\092\001\092\001\092\001\000\000\092\001\092\001\092\001\
\092\001\236\000\000\000\092\001\000\000\000\000\000\000\092\001\
\092\001\000\000\092\001\092\001\092\001\000\000\092\001\236\000\
\236\000\000\000\000\000\236\000\000\000\236\000\000\000\236\000\
\236\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\236\000\236\000\000\000\236\000\092\001\231\000\
\000\000\231\000\000\000\000\000\000\000\236\000\231\000\236\000\
\000\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
\231\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
\231\000\231\000\231\000\231\000\231\000\231\000\231\000\231\000\
\000\000\093\001\093\001\093\001\093\001\093\001\093\001\093\001\
\093\001\093\001\093\001\093\001\093\001\093\001\000\000\093\001\
\093\001\093\001\000\000\093\001\093\001\093\001\093\001\231\000\
\000\000\093\001\000\000\000\000\000\000\093\001\093\001\000\000\
\093\001\093\001\093\001\000\000\093\001\231\000\231\000\000\000\
\000\000\231\000\000\000\231\000\000\000\231\000\231\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\231\000\231\000\000\000\231\000\093\001\246\000\000\000\246\000\
\000\000\000\000\000\000\231\000\246\000\231\000\000\000\246\000\
\246\000\246\000\246\000\246\000\246\000\246\000\246\000\246\000\
\246\000\246\000\246\000\246\000\246\000\246\000\246\000\246\000\
\246\000\246\000\246\000\246\000\246\000\246\000\000\000\000\000\
\000\000\111\001\111\001\111\001\111\001\111\001\111\001\111\001\
\111\001\111\001\111\001\111\001\000\000\111\001\111\001\111\001\
\000\000\111\001\111\001\111\001\111\001\246\000\000\000\111\001\
\000\000\000\000\000\000\000\000\111\001\000\000\111\001\111\001\
\111\001\000\000\111\001\000\000\246\000\000\000\000\000\000\000\
\000\000\021\000\000\000\246\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\246\000\246\000\
\000\000\246\000\111\001\204\000\000\000\204\000\000\000\000\000\
\000\000\246\000\204\000\246\000\000\000\204\000\204\000\204\000\
\204\000\204\000\204\000\204\000\204\000\204\000\204\000\204\000\
\204\000\204\000\204\000\204\000\204\000\204\000\204\000\204\000\
\204\000\204\000\204\000\204\000\000\000\000\000\000\000\000\000\
\129\001\129\001\129\001\129\001\129\001\129\001\000\000\000\000\
\000\000\000\000\000\000\000\000\129\001\129\001\129\001\000\000\
\129\001\129\001\000\000\204\000\000\000\000\000\129\001\000\000\
\000\000\000\000\059\000\129\001\000\000\129\001\129\001\129\001\
\000\000\129\001\204\000\000\000\000\000\000\000\000\000\000\000\
\000\000\204\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\059\000\000\000\000\000\059\000\059\000\
\000\000\000\000\059\000\000\000\204\000\204\000\000\000\204\000\
\000\000\129\001\000\000\000\000\000\000\000\000\000\000\204\000\
\000\000\204\000\059\000\059\000\059\000\059\000\059\000\059\000\
\059\000\059\000\059\000\059\000\059\000\000\000\059\000\059\000\
\059\000\000\000\059\000\059\000\059\000\059\000\000\000\000\000\
\059\000\000\000\059\000\000\000\000\000\059\000\059\000\000\000\
\059\000\059\000\059\000\059\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\059\000\000\000\000\000\000\000\000\000\
\006\000\000\000\000\000\000\000\000\000\000\000\059\000\009\000\
\059\000\081\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\006\000\081\000\057\000\000\000\081\000\081\000\000\000\
\009\000\081\000\000\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\058\000\027\000\028\000\029\000\030\000\
\031\000\032\000\000\000\000\000\000\000\000\000\081\000\156\000\
\000\000\081\000\081\000\000\000\000\000\000\000\000\000\081\000\
\212\001\081\000\000\000\000\000\081\000\081\000\000\000\081\000\
\081\000\081\000\081\000\146\001\000\000\000\000\000\000\000\000\
\146\001\034\000\035\000\000\000\037\000\146\001\000\000\146\001\
\146\001\146\001\081\000\146\001\038\000\000\000\039\000\000\000\
\000\000\000\000\000\000\000\000\000\000\081\000\000\000\081\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\034\000\035\000\000\000\037\000\000\000\006\000\
\000\000\000\000\000\000\146\001\000\000\038\000\009\000\039\000\
\082\000\010\000\011\000\012\000\013\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\021\000\022\000\023\000\024\000\
\025\000\058\000\027\000\028\000\029\000\030\000\031\000\032\000\
\006\000\082\000\000\000\000\000\082\000\082\000\000\000\009\000\
\082\000\000\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\058\000\027\000\028\000\029\000\030\000\031\000\
\032\000\000\000\000\000\000\000\000\000\082\000\156\000\000\000\
\082\000\082\000\000\000\000\000\000\000\000\000\082\000\000\000\
\082\000\000\000\000\000\082\000\082\000\000\000\082\000\082\000\
\082\000\082\000\000\000\000\000\000\000\000\000\000\000\000\000\
\034\000\035\000\000\000\037\000\000\000\000\000\000\000\000\000\
\000\000\082\000\000\000\038\000\000\000\039\000\000\000\000\000\
\196\002\000\000\000\000\000\000\082\000\000\000\082\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\000\035\000\000\000\037\000\000\000\016\001\000\000\
\000\000\000\000\000\000\000\000\038\000\016\001\039\000\000\000\
\016\001\016\001\016\001\016\001\016\001\016\001\016\001\016\001\
\016\001\016\001\016\001\016\001\016\001\016\001\016\001\016\001\
\016\001\016\001\016\001\016\001\016\001\016\001\016\001\000\000\
\000\000\000\000\000\000\123\001\123\001\123\001\123\001\123\001\
\123\001\123\001\123\001\000\000\000\000\000\000\000\000\123\001\
\123\001\123\001\000\000\123\001\123\001\123\001\123\001\000\000\
\000\000\123\001\000\000\000\000\000\000\063\000\123\001\000\000\
\123\001\123\001\123\001\000\000\123\001\016\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\063\000\000\000\
\000\000\063\000\063\000\000\000\000\000\063\000\000\000\016\001\
\016\001\000\000\016\001\000\000\123\001\000\000\000\000\000\000\
\000\000\000\000\016\001\000\000\016\001\063\000\063\000\063\000\
\063\000\063\000\063\000\063\000\063\000\000\000\000\000\000\000\
\000\000\063\000\063\000\063\000\064\000\063\000\063\000\063\000\
\063\000\000\000\000\000\063\000\000\000\063\000\000\000\000\000\
\063\000\063\000\000\000\063\000\063\000\063\000\063\000\000\000\
\000\000\000\000\000\000\000\000\000\000\064\000\000\000\000\000\
\064\000\064\000\000\000\000\000\064\000\000\000\063\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\063\000\000\000\063\000\064\000\064\000\064\000\064\000\
\064\000\064\000\064\000\064\000\000\000\000\000\000\000\000\000\
\064\000\064\000\064\000\065\000\064\000\064\000\064\000\064\000\
\000\000\000\000\064\000\000\000\064\000\000\000\000\000\064\000\
\064\000\000\000\064\000\064\000\064\000\064\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\000\000\000\000\065\000\
\065\000\000\000\000\000\065\000\000\000\064\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\064\000\000\000\064\000\065\000\065\000\065\000\065\000\065\000\
\065\000\065\000\065\000\000\000\000\000\000\000\000\000\065\000\
\065\000\065\000\000\000\065\000\065\000\065\000\065\000\000\000\
\000\000\065\000\000\000\065\000\000\000\000\000\065\000\065\000\
\000\000\065\000\065\000\065\000\065\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\065\000\000\000\000\000\000\000\
\000\000\006\000\000\000\000\000\000\000\000\000\000\000\065\000\
\009\000\065\000\066\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\058\000\027\000\028\000\029\000\030\000\
\031\000\032\000\000\000\066\000\000\000\000\000\066\000\066\000\
\000\000\000\000\066\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\066\000\066\000\066\000\066\000\066\000\066\000\
\000\000\000\000\000\000\000\000\000\000\000\000\066\000\066\000\
\066\000\000\000\066\000\066\000\066\000\066\000\000\000\000\000\
\066\000\000\000\066\000\000\000\000\000\066\000\066\000\067\000\
\066\000\066\000\066\000\066\000\000\000\000\000\000\000\000\000\
\000\000\000\000\034\000\035\000\000\000\037\000\000\000\000\000\
\000\000\000\000\000\000\066\000\000\000\038\000\000\000\039\000\
\067\000\000\000\000\000\067\000\067\000\000\000\066\000\067\000\
\066\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\067\000\
\067\000\067\000\067\000\067\000\067\000\000\000\000\000\000\000\
\000\000\000\000\000\000\067\000\067\000\067\000\068\000\067\000\
\067\000\067\000\067\000\000\000\000\000\067\000\000\000\067\000\
\000\000\000\000\067\000\067\000\000\000\067\000\067\000\067\000\
\067\000\000\000\000\000\000\000\000\000\000\000\000\000\068\000\
\000\000\000\000\068\000\068\000\000\000\000\000\068\000\000\000\
\067\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\067\000\000\000\067\000\068\000\068\000\
\068\000\068\000\068\000\068\000\000\000\000\000\000\000\000\000\
\000\000\000\000\068\000\068\000\068\000\069\000\068\000\068\000\
\068\000\068\000\000\000\000\000\068\000\000\000\068\000\000\000\
\000\000\068\000\068\000\000\000\068\000\068\000\068\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\069\000\000\000\
\000\000\069\000\069\000\000\000\000\000\069\000\000\000\068\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\068\000\000\000\068\000\069\000\069\000\069\000\
\069\000\069\000\069\000\000\000\000\000\000\000\000\000\000\000\
\000\000\069\000\069\000\069\000\070\000\069\000\069\000\000\000\
\000\000\000\000\000\000\069\000\000\000\069\000\000\000\000\000\
\069\000\069\000\000\000\069\000\069\000\069\000\069\000\000\000\
\000\000\000\000\000\000\000\000\000\000\070\000\000\000\000\000\
\070\000\070\000\000\000\000\000\070\000\000\000\069\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\069\000\000\000\069\000\070\000\070\000\070\000\070\000\
\070\000\070\000\000\000\000\000\000\000\000\000\000\000\000\000\
\070\000\070\000\070\000\071\000\070\000\070\000\000\000\000\000\
\000\000\000\000\070\000\000\000\070\000\000\000\000\000\070\000\
\070\000\000\000\070\000\070\000\070\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\071\000\000\000\000\000\071\000\
\071\000\000\000\000\000\071\000\000\000\070\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\070\000\000\000\070\000\071\000\071\000\071\000\071\000\071\000\
\071\000\000\000\000\000\000\000\000\000\000\000\000\000\071\000\
\071\000\071\000\072\000\071\000\071\000\000\000\000\000\000\000\
\000\000\071\000\000\000\071\000\000\000\000\000\071\000\071\000\
\000\000\071\000\071\000\071\000\071\000\000\000\000\000\000\000\
\000\000\000\000\000\000\072\000\000\000\000\000\072\000\072\000\
\000\000\000\000\072\000\000\000\071\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\071\000\
\000\000\071\000\072\000\072\000\072\000\072\000\072\000\072\000\
\000\000\000\000\000\000\000\000\000\000\000\000\072\000\072\000\
\072\000\073\000\072\000\072\000\000\000\000\000\000\000\000\000\
\072\000\000\000\072\000\000\000\000\000\072\000\072\000\000\000\
\072\000\072\000\072\000\072\000\000\000\000\000\000\000\000\000\
\000\000\000\000\073\000\000\000\000\000\073\000\073\000\000\000\
\000\000\073\000\000\000\072\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\072\000\000\000\
\072\000\073\000\073\000\073\000\073\000\073\000\073\000\000\000\
\000\000\000\000\074\000\000\000\000\000\073\000\073\000\073\000\
\000\000\073\000\073\000\000\000\000\000\000\000\000\000\073\000\
\000\000\073\000\000\000\000\000\073\000\073\000\000\000\073\000\
\073\000\073\000\073\000\074\000\000\000\000\000\074\000\074\000\
\000\000\000\000\074\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\073\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\074\000\074\000\000\000\073\000\000\000\073\000\
\000\000\000\000\000\000\075\000\000\000\000\000\074\000\074\000\
\074\000\000\000\074\000\074\000\000\000\000\000\000\000\000\000\
\074\000\000\000\074\000\000\000\000\000\074\000\074\000\000\000\
\074\000\074\000\074\000\074\000\075\000\000\000\000\000\075\000\
\075\000\000\000\000\000\075\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\074\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\075\000\075\000\000\000\074\000\000\000\
\074\000\000\000\000\000\000\000\076\000\000\000\000\000\075\000\
\075\000\075\000\000\000\075\000\075\000\000\000\000\000\000\000\
\000\000\075\000\000\000\075\000\000\000\000\000\075\000\075\000\
\000\000\075\000\075\000\075\000\075\000\076\000\000\000\000\000\
\076\000\076\000\000\000\000\000\076\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\075\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\076\000\076\000\000\000\075\000\
\000\000\075\000\000\000\000\000\000\000\077\000\000\000\000\000\
\076\000\076\000\076\000\000\000\076\000\076\000\000\000\000\000\
\000\000\000\000\076\000\000\000\076\000\000\000\000\000\076\000\
\076\000\000\000\076\000\076\000\076\000\076\000\077\000\000\000\
\000\000\077\000\077\000\000\000\000\000\077\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\076\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\076\000\000\000\076\000\000\000\000\000\000\000\078\000\000\000\
\000\000\077\000\077\000\077\000\000\000\077\000\077\000\000\000\
\000\000\000\000\000\000\077\000\000\000\077\000\000\000\000\000\
\077\000\077\000\000\000\077\000\077\000\077\000\077\000\078\000\
\000\000\000\000\078\000\078\000\000\000\000\000\078\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\077\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\077\000\000\000\077\000\000\000\000\000\000\000\079\000\
\000\000\000\000\078\000\078\000\078\000\000\000\078\000\078\000\
\000\000\000\000\000\000\000\000\078\000\000\000\078\000\000\000\
\000\000\078\000\078\000\000\000\078\000\078\000\078\000\078\000\
\079\000\000\000\000\000\079\000\079\000\000\000\000\000\079\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\078\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\078\000\000\000\078\000\000\000\000\000\000\000\
\080\000\000\000\000\000\000\000\079\000\079\000\000\000\079\000\
\079\000\000\000\000\000\000\000\000\000\079\000\000\000\079\000\
\000\000\000\000\079\000\079\000\084\000\079\000\079\000\079\000\
\079\000\080\000\000\000\000\000\080\000\080\000\000\000\000\000\
\080\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\079\000\000\000\000\000\000\000\000\000\084\000\000\000\000\000\
\084\000\084\000\000\000\079\000\084\000\079\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\080\000\080\000\000\000\
\080\000\080\000\000\000\000\000\000\000\000\000\080\000\000\000\
\080\000\000\000\000\000\080\000\080\000\000\000\080\000\080\000\
\080\000\080\000\000\000\090\000\084\000\084\000\091\000\000\000\
\092\000\078\000\084\000\000\000\084\000\000\000\000\000\084\000\
\084\000\080\000\084\000\084\000\084\000\084\000\000\000\000\000\
\000\000\000\000\093\000\000\000\080\000\094\000\080\000\000\000\
\000\000\000\000\095\000\096\000\000\000\084\000\058\001\058\001\
\058\001\058\001\058\001\058\001\058\001\058\001\000\000\000\000\
\084\000\000\000\084\000\000\000\000\000\000\000\000\000\097\000\
\098\000\099\000\000\000\000\000\100\000\101\000\000\000\058\001\
\102\000\000\000\000\000\000\000\000\000\058\001\058\001\058\001\
\103\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\104\000\058\001\058\001\058\001\000\000\000\000\058\001\
\058\001\000\000\000\000\058\001\058\001\000\000\079\000\080\000\
\058\001\058\001\058\001\058\001\000\000\058\001\058\001\058\001\
\058\001\000\000\058\001\058\001\033\002\189\000\190\000\191\000\
\192\000\064\000\078\000\193\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\058\001\058\001\000\000\058\001\000\000\058\001\058\001\
\000\000\000\000\000\000\194\000\195\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\034\002\000\000\000\000\000\000\000\000\000\000\000\000\
\196\000\197\000\198\000\000\000\000\000\199\000\200\000\000\000\
\000\000\201\000\202\000\000\000\000\000\000\000\203\000\204\000\
\000\000\205\000\000\000\189\001\035\002\000\000\000\000\000\000\
\058\001\058\001\058\001\058\001\058\001\000\000\058\001\058\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\079\000\
\080\000\058\001\206\000\000\000\207\000\208\000\000\000\058\001\
\058\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\058\001\058\001\058\001\000\000\
\000\000\058\001\058\001\000\000\000\000\058\001\058\001\000\000\
\000\000\000\000\058\001\058\001\000\000\058\001\000\000\000\000\
\000\000\058\001\000\000\132\000\132\000\132\000\132\000\132\000\
\000\000\132\000\132\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\058\001\058\001\000\000\058\001\000\000\
\058\001\058\001\132\000\132\000\132\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\132\000\
\132\000\132\000\000\000\000\000\132\000\132\000\000\000\000\000\
\132\000\132\000\000\000\000\000\000\000\132\000\132\000\000\000\
\132\000\000\000\132\000\000\000\000\000\000\000\188\000\189\000\
\190\000\191\000\192\000\000\000\078\000\193\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\132\000\132\000\
\000\000\132\000\000\000\132\000\132\000\194\000\195\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\196\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\201\000\202\000\000\000\000\000\000\000\
\203\000\204\000\000\000\205\000\000\000\189\001\000\000\000\000\
\000\000\188\000\189\000\190\000\191\000\192\000\000\000\078\000\
\193\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\079\000\080\000\000\000\206\000\000\000\207\000\208\000\
\194\000\195\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\196\000\197\000\198\000\
\000\000\000\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\000\000\000\000\203\000\204\000\000\000\205\000\000\000\
\084\002\000\000\000\000\000\000\188\000\189\000\190\000\191\000\
\192\000\000\000\078\000\193\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\079\000\080\000\000\000\206\000\
\000\000\207\000\208\000\194\000\195\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\196\000\197\000\198\000\000\000\000\000\199\000\200\000\000\000\
\000\000\201\000\202\000\000\000\000\000\000\000\203\000\204\000\
\000\000\205\000\000\000\000\000\000\000\000\000\000\000\000\000\
\175\002\058\001\058\001\058\001\058\001\058\001\000\000\058\001\
\058\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\079\000\
\080\000\000\000\206\000\000\000\207\000\208\000\000\000\000\000\
\058\001\058\001\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\058\001\058\001\058\001\
\000\000\000\000\058\001\058\001\000\000\000\000\058\001\058\001\
\000\000\000\000\000\000\058\001\058\001\000\000\058\001\000\000\
\000\000\000\000\058\001\000\000\128\000\128\000\128\000\128\000\
\128\000\000\000\128\000\128\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\058\001\058\001\000\000\058\001\
\000\000\058\001\058\001\128\000\128\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\128\000\128\000\128\000\000\000\000\000\128\000\128\000\000\000\
\000\000\128\000\128\000\000\000\000\000\000\000\128\000\128\000\
\000\000\128\000\000\000\128\000\000\000\000\000\000\000\059\001\
\059\001\059\001\059\001\059\001\000\000\059\001\059\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\128\000\
\128\000\000\000\128\000\000\000\128\000\128\000\059\001\059\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\059\001\059\001\059\001\000\000\000\000\
\059\001\059\001\000\000\000\000\059\001\059\001\000\000\000\000\
\000\000\059\001\059\001\000\000\059\001\000\000\000\000\000\000\
\059\001\000\000\188\000\189\000\190\000\191\000\192\000\000\000\
\078\000\193\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\059\001\059\001\000\000\059\001\000\000\059\001\
\059\001\194\000\195\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\196\000\197\000\
\198\000\000\000\000\000\199\000\200\000\000\000\000\000\201\000\
\202\000\000\000\000\000\000\000\203\000\204\000\000\000\235\000\
\000\000\000\000\000\000\000\000\000\000\188\000\189\000\190\000\
\191\000\192\000\000\000\078\000\193\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\079\000\080\000\000\000\
\206\000\000\000\207\000\208\000\194\000\195\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\196\000\197\000\198\000\000\000\000\000\199\000\200\000\
\000\000\000\000\201\000\202\000\000\000\000\000\000\000\203\000\
\204\000\000\000\237\000\000\000\000\000\000\000\000\000\000\000\
\188\000\189\000\190\000\191\000\192\000\000\000\078\000\193\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\079\000\080\000\000\000\206\000\000\000\207\000\208\000\194\000\
\195\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\196\000\197\000\198\000\000\000\
\000\000\199\000\200\000\000\000\000\000\201\000\202\000\000\000\
\000\000\000\000\203\000\204\000\000\000\089\001\000\000\000\000\
\000\000\000\000\000\000\188\000\189\000\190\000\191\000\192\000\
\000\000\078\000\193\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\079\000\080\000\000\000\206\000\000\000\
\207\000\208\000\194\000\195\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\196\000\
\197\000\198\000\000\000\000\000\199\000\200\000\000\000\000\000\
\201\000\202\000\000\000\000\000\000\000\203\000\204\000\000\000\
\091\001\000\000\000\000\000\000\000\000\000\000\188\000\189\000\
\190\000\191\000\192\000\000\000\078\000\193\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\079\000\080\000\
\000\000\206\000\000\000\207\000\208\000\194\000\195\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\196\000\197\000\198\000\000\000\000\000\199\000\
\200\000\000\000\000\000\201\000\202\000\000\000\000\000\000\000\
\203\000\204\000\000\000\205\000\000\000\000\000\000\000\000\000\
\000\000\188\000\189\000\190\000\191\000\192\000\000\000\078\000\
\193\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\079\000\080\000\000\000\206\000\000\000\207\000\208\000\
\194\000\195\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\196\000\197\000\198\000\
\000\000\000\000\199\000\200\000\000\000\000\000\201\000\202\000\
\000\000\000\000\000\000\203\000\204\000\000\000\100\001\000\000\
\000\000\000\000\000\000\000\000\058\001\058\001\058\001\058\001\
\058\001\000\000\058\001\058\001\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\079\000\080\000\000\000\206\000\
\000\000\207\000\208\000\058\001\058\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\058\001\058\001\058\001\000\000\000\000\058\001\058\001\000\000\
\000\000\058\001\058\001\000\000\000\000\090\000\058\001\058\001\
\091\000\058\001\092\000\078\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\093\000\000\000\000\000\094\000\
\000\000\000\000\000\000\000\000\095\000\096\000\000\000\058\001\
\058\001\000\000\058\001\000\000\058\001\058\001\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\097\000\098\000\099\000\000\000\000\000\100\000\101\000\
\000\000\000\000\102\000\000\000\000\000\000\000\000\000\000\000\
\000\000\160\001\103\000\000\000\000\000\000\000\000\000\000\000\
\124\001\124\001\124\001\124\001\124\001\124\001\124\001\124\001\
\000\000\000\000\000\000\104\000\124\001\124\001\124\001\000\000\
\124\001\124\001\124\001\124\001\000\000\000\000\124\001\000\000\
\079\000\080\000\000\000\124\001\000\000\124\001\124\001\124\001\
\000\000\124\001\000\000\000\000\000\000\125\001\125\001\125\001\
\125\001\125\001\125\001\125\001\125\001\000\000\000\000\000\000\
\000\000\125\001\125\001\125\001\000\000\125\001\125\001\125\001\
\125\001\000\000\000\000\125\001\000\000\000\000\000\000\000\000\
\125\001\124\001\125\001\125\001\125\001\000\000\125\001\000\000\
\000\000\000\000\126\001\126\001\126\001\126\001\126\001\126\001\
\000\000\000\000\000\000\000\000\000\000\000\000\126\001\126\001\
\126\001\000\000\126\001\126\001\126\001\126\001\000\000\000\000\
\126\001\000\000\000\000\000\000\000\000\126\001\125\001\126\001\
\126\001\126\001\000\000\126\001\000\000\000\000\000\000\127\001\
\127\001\127\001\127\001\127\001\127\001\000\000\000\000\000\000\
\000\000\000\000\000\000\127\001\127\001\127\001\000\000\127\001\
\127\001\127\001\127\001\000\000\000\000\127\001\000\000\000\000\
\000\000\000\000\127\001\126\001\127\001\127\001\127\001\000\000\
\127\001\000\000\000\000\000\000\128\001\128\001\128\001\128\001\
\128\001\128\001\000\000\000\000\000\000\000\000\000\000\000\000\
\128\001\128\001\128\001\000\000\128\001\128\001\128\001\128\001\
\000\000\000\000\128\001\000\000\000\000\000\000\000\000\128\001\
\127\001\128\001\128\001\128\001\000\000\128\001\000\000\000\000\
\000\000\130\001\130\001\130\001\130\001\130\001\130\001\000\000\
\000\000\000\000\000\000\000\000\000\000\130\001\130\001\130\001\
\000\000\130\001\130\001\000\000\000\000\000\000\000\000\130\001\
\000\000\000\000\000\000\000\000\130\001\128\001\130\001\130\001\
\130\001\000\000\130\001\000\000\000\000\000\000\131\001\131\001\
\131\001\131\001\131\001\131\001\000\000\000\000\000\000\000\000\
\000\000\000\000\131\001\131\001\131\001\000\000\131\001\131\001\
\000\000\000\000\000\000\000\000\131\001\000\000\000\000\000\000\
\000\000\131\001\130\001\131\001\131\001\131\001\000\000\131\001\
\000\000\000\000\000\000\132\001\132\001\132\001\132\001\132\001\
\132\001\000\000\000\000\000\000\000\000\000\000\000\000\132\001\
\132\001\132\001\000\000\132\001\132\001\000\000\000\000\000\000\
\000\000\132\001\000\000\000\000\000\000\000\000\132\001\131\001\
\132\001\132\001\132\001\000\000\132\001\000\000\000\000\000\000\
\133\001\133\001\133\001\133\001\133\001\133\001\000\000\000\000\
\000\000\000\000\000\000\000\000\133\001\133\001\133\001\000\000\
\133\001\133\001\000\000\000\000\000\000\000\000\133\001\134\001\
\134\001\000\000\000\000\133\001\132\001\133\001\133\001\133\001\
\000\000\133\001\000\000\134\001\134\001\134\001\000\000\134\001\
\134\001\000\000\000\000\000\000\000\000\134\001\135\001\135\001\
\000\000\000\000\134\001\000\000\134\001\134\001\134\001\000\000\
\134\001\000\000\135\001\135\001\135\001\000\000\135\001\135\001\
\000\000\133\001\000\000\000\000\135\001\136\001\136\001\000\000\
\000\000\135\001\000\000\135\001\135\001\135\001\000\000\135\001\
\000\000\136\001\136\001\136\001\000\000\136\001\136\001\000\000\
\134\001\000\000\000\000\136\001\000\000\000\000\000\000\000\000\
\136\001\000\000\136\001\136\001\136\001\000\000\136\001\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\135\001\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\136\001\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\025\000\
\025\000\025\000\025\000\025\000\025\000\025\000\025\000\000\000\
\025\000\025\000\025\000\000\000\025\000\025\000\025\000\025\000\
\025\000\025\000\000\000\025\000\025\000\000\000\025\000\000\000\
\020\000\000\000\025\000\025\000\000\000\025\000"

let yycheck = "\017\000\
\018\000\157\000\020\000\042\000\047\000\067\000\001\000\002\000\
\000\000\026\000\051\000\036\001\202\001\041\000\132\000\110\000\
\059\000\149\000\185\000\060\000\038\001\185\001\203\001\205\000\
\041\000\156\000\054\002\082\000\198\001\003\001\063\001\064\001\
\059\000\094\002\017\000\018\000\059\002\020\000\033\000\048\000\
\056\002\157\000\081\000\165\000\166\000\107\000\018\000\038\001\
\020\000\076\001\047\000\046\000\070\000\235\000\075\000\237\000\
\074\000\083\001\214\000\077\000\007\001\007\001\059\000\052\001\
\087\000\033\000\012\001\007\001\007\001\086\000\076\001\088\000\
\077\001\012\001\007\001\103\000\013\001\061\001\046\000\084\001\
\097\000\098\000\099\000\100\000\101\000\102\000\103\000\070\000\
\127\000\128\000\079\001\074\000\118\001\110\000\077\000\007\001\
\157\002\081\001\214\000\071\000\012\001\097\000\098\000\099\000\
\100\000\101\000\102\000\102\001\007\001\001\000\002\000\005\001\
\004\000\012\001\157\000\061\001\013\001\014\001\113\001\007\001\
\076\001\139\000\056\002\057\002\012\001\095\000\096\000\170\000\
\075\001\013\001\076\001\140\000\141\000\013\001\129\000\075\001\
\030\001\076\001\032\001\033\001\034\001\033\000\075\001\037\001\
\081\001\119\001\169\002\061\001\169\000\165\002\042\000\172\000\
\173\000\174\000\046\000\069\002\177\000\178\000\213\000\254\000\
\157\000\129\000\054\000\089\001\205\000\091\001\078\001\081\001\
\185\000\083\001\062\000\033\001\048\001\075\001\100\001\037\001\
\038\001\076\001\103\002\081\001\079\001\056\001\108\001\109\001\
\202\000\093\002\181\000\220\001\076\001\081\000\102\001\209\001\
\210\001\048\000\235\000\087\000\237\000\075\001\132\002\065\001\
\134\002\113\001\136\002\194\001\124\002\083\001\197\001\127\002\
\102\001\106\001\107\001\033\001\070\001\181\000\075\001\037\001\
\141\002\214\000\209\001\113\001\081\001\115\001\106\001\107\001\
\194\000\195\000\106\001\107\001\086\001\030\003\247\000\165\002\
\004\001\203\000\204\000\127\000\128\000\129\000\255\000\040\003\
\002\001\003\001\153\001\004\001\005\001\006\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\034\003\034\001\
\156\000\005\001\006\001\007\001\084\002\036\001\001\000\002\000\
\192\002\042\002\030\001\002\001\003\001\033\001\007\001\061\001\
\096\002\043\001\013\001\012\001\042\000\140\000\141\000\081\001\
\180\000\181\000\031\001\085\001\059\001\055\001\196\000\197\000\
\198\000\199\000\200\000\201\000\067\001\083\001\222\002\068\001\
\089\001\030\001\091\001\205\000\033\001\007\001\072\001\082\001\
\077\001\205\000\012\001\100\001\081\001\193\001\070\001\232\002\
\075\001\000\000\007\001\057\002\163\001\007\001\081\001\012\001\
\248\002\098\002\012\001\005\001\194\001\089\001\086\001\197\001\
\005\001\235\000\251\002\237\000\107\001\077\001\076\001\235\000\
\075\001\237\000\208\001\209\001\210\001\078\001\081\001\007\001\
\061\001\005\001\116\001\117\001\030\001\007\001\015\003\033\001\
\034\001\030\001\012\001\037\001\033\001\034\001\007\001\078\001\
\037\001\127\000\128\000\012\001\194\001\102\001\083\001\106\001\
\107\001\076\001\030\001\061\001\078\001\033\001\034\001\245\001\
\113\001\037\001\208\001\076\001\210\001\116\001\117\001\078\001\
\153\001\078\001\076\001\201\001\070\001\079\001\132\002\076\001\
\134\002\075\001\136\002\077\001\102\001\192\001\080\001\081\001\
\080\001\083\001\084\001\085\001\086\001\085\001\050\001\113\001\
\086\002\087\002\205\001\078\001\056\001\065\002\189\001\245\001\
\185\001\075\001\076\001\189\001\102\001\079\001\241\002\007\001\
\243\002\102\001\084\001\104\001\012\001\224\001\078\001\113\001\
\046\002\115\001\005\001\049\002\113\001\089\002\115\001\089\001\
\075\001\091\001\102\001\037\001\079\001\089\001\007\001\091\001\
\223\001\084\001\100\001\012\001\225\001\113\001\189\001\115\001\
\100\001\076\001\076\001\030\001\079\001\075\002\033\001\034\001\
\108\001\109\001\037\001\081\001\007\001\007\001\120\001\121\001\
\046\002\012\001\012\001\049\002\081\001\061\001\059\001\060\001\
\134\001\135\001\136\001\137\001\138\001\139\001\140\001\141\001\
\142\001\143\001\144\001\145\001\146\001\147\001\148\001\149\001\
\150\001\151\001\069\001\070\001\007\001\075\002\152\001\076\001\
\075\001\012\001\077\001\061\001\102\001\080\001\081\001\067\001\
\083\001\084\001\085\001\086\001\035\002\078\001\065\001\113\001\
\034\002\115\001\076\001\042\002\059\002\079\001\065\002\078\001\
\005\001\066\001\078\001\102\001\083\001\051\001\052\001\083\001\
\084\001\050\002\076\001\078\001\054\002\069\001\113\001\007\001\
\115\001\059\002\010\001\083\001\012\001\013\001\164\002\040\001\
\084\001\030\001\198\001\034\002\033\001\034\001\007\001\203\001\
\037\001\079\001\040\001\012\001\108\001\084\002\030\001\083\001\
\059\002\033\001\084\002\078\001\065\002\084\001\088\002\005\001\
\190\002\096\002\040\001\098\002\093\002\083\001\096\002\075\001\
\076\001\075\001\240\001\079\001\238\001\078\001\164\002\128\002\
\084\001\061\001\083\001\084\001\089\002\052\001\212\002\076\001\
\030\001\140\002\116\002\033\001\034\001\084\002\125\002\037\001\
\122\002\088\002\071\001\072\001\005\001\075\001\077\001\229\002\
\078\001\096\002\084\001\081\001\075\001\083\001\084\001\075\001\
\079\001\102\001\075\001\076\001\040\001\093\001\079\001\094\001\
\095\001\096\001\084\001\084\001\113\001\030\001\115\001\158\002\
\033\001\034\001\106\001\107\001\037\001\078\001\076\001\053\001\
\054\001\079\001\059\001\060\001\166\002\047\002\075\001\169\002\
\078\001\120\001\007\001\080\001\081\001\077\001\083\001\012\001\
\178\002\078\001\180\002\181\002\007\001\071\001\072\001\059\002\
\102\001\012\001\104\001\075\001\070\002\070\001\077\001\193\002\
\075\001\069\002\075\001\113\001\077\001\115\001\223\002\080\001\
\081\001\076\001\083\001\084\001\085\001\086\001\092\002\053\001\
\054\001\232\002\086\002\087\002\219\002\076\001\239\002\076\001\
\218\002\055\001\056\001\057\001\058\001\102\001\104\002\075\001\
\061\001\007\001\228\002\103\002\230\002\099\001\100\001\040\001\
\113\001\075\001\115\001\065\001\238\002\066\001\075\001\076\001\
\116\002\123\002\079\001\040\001\081\001\067\001\083\001\084\001\
\075\001\076\001\252\002\069\001\079\001\055\001\056\001\057\001\
\058\001\084\001\084\001\007\001\083\001\084\001\010\001\075\001\
\012\001\141\002\075\001\012\003\010\001\078\001\083\001\084\001\
\081\001\010\001\083\001\084\001\075\001\028\003\075\001\061\001\
\075\001\163\002\030\001\029\003\081\001\033\001\083\001\084\001\
\034\003\083\001\084\001\173\002\075\001\075\001\076\001\177\002\
\110\001\079\001\118\001\081\001\007\001\083\001\084\001\077\001\
\001\001\075\001\003\001\004\001\005\001\084\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\015\001\016\001\
\017\001\018\001\019\001\020\001\021\001\022\001\023\001\024\001\
\025\001\026\001\027\001\028\001\029\001\030\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\081\001\
\075\001\093\001\061\001\062\001\063\001\080\001\232\002\082\001\
\083\001\084\001\127\000\128\000\232\002\061\001\062\001\063\001\
\051\001\052\001\059\001\060\001\061\001\137\001\138\001\064\001\
\065\001\251\002\083\001\068\001\069\001\094\001\095\001\096\001\
\073\001\074\001\077\001\076\001\077\001\078\001\073\001\074\001\
\077\001\076\001\083\001\118\001\079\001\015\003\087\001\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\094\001\095\001\096\001\102\001\103\001\104\001\
\105\001\106\001\107\001\077\001\109\001\077\001\111\001\112\001\
\113\001\114\001\115\001\116\001\117\001\001\001\119\001\120\001\
\004\001\005\001\077\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\075\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\050\001\
\141\001\142\001\143\001\144\001\183\002\184\002\185\002\059\001\
\060\001\061\001\139\001\140\001\064\001\065\001\145\001\146\001\
\068\001\069\001\140\000\141\000\083\001\073\001\074\001\084\001\
\076\001\077\001\078\001\012\001\013\001\014\001\015\001\083\001\
\008\001\009\001\075\001\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\010\001\
\011\001\075\001\102\001\103\001\104\001\105\001\106\001\107\001\
\075\001\109\001\075\001\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\001\001\076\001\120\001\004\001\005\001\075\001\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\123\001\124\001\125\001\126\001\127\001\128\001\129\001\
\130\001\131\001\132\001\133\001\016\001\017\001\080\001\076\001\
\084\001\079\001\083\001\083\001\059\001\060\001\061\001\077\001\
\077\001\064\001\065\001\077\001\077\001\068\001\069\001\007\001\
\075\001\075\001\073\001\074\001\012\001\076\001\075\001\078\001\
\084\001\075\001\078\001\084\001\083\001\080\001\084\001\040\001\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\081\001\084\001\082\001\102\001\
\103\001\104\001\105\001\106\001\107\001\081\001\109\001\077\001\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\075\001\
\001\001\120\001\003\001\004\001\075\001\061\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\080\001\075\001\
\077\001\084\001\083\001\075\001\076\001\075\001\075\001\079\001\
\032\001\065\001\066\001\067\001\084\001\069\001\070\001\077\001\
\075\001\120\001\083\001\075\001\083\001\038\001\039\001\076\001\
\080\001\083\001\082\001\083\001\084\001\081\001\086\001\081\001\
\075\001\075\001\080\001\075\001\077\001\075\001\083\001\083\001\
\007\001\076\001\059\001\060\001\061\001\081\001\076\001\064\001\
\065\001\080\001\083\001\068\001\069\001\101\001\076\001\013\001\
\073\001\074\001\081\001\076\001\077\001\078\001\118\001\081\001\
\083\001\094\001\083\001\079\001\075\001\083\001\087\001\088\001\
\089\001\090\001\091\001\092\001\093\001\094\001\095\001\096\001\
\097\001\098\001\083\001\075\001\007\001\081\001\084\001\104\001\
\083\001\106\001\107\001\080\001\109\001\083\001\111\001\112\001\
\076\001\114\001\075\001\081\001\001\001\075\001\119\001\120\001\
\005\001\084\001\007\001\000\000\081\001\077\001\075\001\012\001\
\083\001\075\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\078\001\077\001\077\001\075\001\075\001\079\001\083\001\
\077\001\075\001\077\001\083\001\077\001\081\001\078\001\078\001\
\076\001\075\001\080\001\075\001\075\001\001\001\083\001\003\001\
\004\001\005\001\075\001\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\075\001\002\000\197\001\157\002\
\152\002\102\001\103\001\060\001\105\001\004\000\139\000\149\001\
\053\002\224\001\229\002\070\002\113\001\255\002\115\001\059\001\
\060\001\061\001\140\002\120\001\064\001\065\001\092\002\163\000\
\068\001\069\001\147\001\213\001\254\000\073\001\074\001\148\001\
\076\001\077\001\078\001\150\001\018\001\151\001\019\001\083\001\
\020\001\018\003\021\001\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\163\001\
\022\001\037\003\102\001\103\001\104\001\105\001\106\001\107\001\
\020\003\109\001\110\001\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\001\001\119\001\003\001\004\001\005\001\040\003\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\077\001\078\001\
\255\255\255\255\255\255\255\255\083\001\255\255\255\255\255\255\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\094\001\
\095\001\096\001\097\001\098\001\255\255\255\255\255\255\102\001\
\103\001\104\001\105\001\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\001\001\
\119\001\003\001\004\001\005\001\255\255\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\078\001\255\255\255\255\255\255\
\255\255\083\001\255\255\255\255\255\255\087\001\088\001\089\001\
\090\001\091\001\092\001\093\001\255\255\255\255\255\255\097\001\
\098\001\255\255\255\255\255\255\102\001\103\001\104\001\105\001\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\113\001\
\114\001\115\001\255\255\255\255\001\001\119\001\003\001\004\001\
\255\255\255\255\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\014\001\053\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\062\001\063\001\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\038\001\039\001\255\255\255\255\080\001\255\255\082\001\
\083\001\084\001\255\255\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\078\001\255\255\118\001\255\255\255\255\083\001\255\255\
\255\255\255\255\087\001\088\001\089\001\090\001\091\001\092\001\
\093\001\094\001\095\001\096\001\097\001\098\001\255\255\255\255\
\255\255\255\255\255\255\104\001\255\255\106\001\107\001\255\255\
\109\001\255\255\111\001\112\001\255\255\114\001\001\001\255\255\
\003\001\004\001\119\001\255\255\007\001\008\001\009\001\010\001\
\011\001\012\001\013\001\014\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\038\001\039\001\255\255\255\255\080\001\
\255\255\082\001\083\001\084\001\255\255\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\255\255\073\001\074\001\
\255\255\076\001\255\255\078\001\255\255\118\001\255\255\255\255\
\083\001\255\255\255\255\255\255\087\001\088\001\089\001\090\001\
\091\001\092\001\093\001\255\255\255\255\255\255\097\001\098\001\
\255\255\255\255\255\255\255\255\255\255\104\001\255\255\106\001\
\107\001\255\255\109\001\255\255\111\001\112\001\255\255\114\001\
\255\255\001\001\002\001\255\255\119\001\005\001\006\001\007\001\
\255\255\255\255\255\255\255\255\012\001\255\255\005\001\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\255\255\030\001\
\255\255\255\255\033\001\034\001\255\255\255\255\037\001\255\255\
\255\255\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\050\001\255\255\255\255\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\071\001\072\001\255\255\083\001\075\001\255\255\077\001\255\255\
\255\255\080\001\081\001\082\001\083\001\084\001\085\001\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\103\001\
\104\001\105\001\255\255\255\255\255\255\255\255\255\255\102\001\
\255\255\113\001\001\001\115\001\116\001\117\001\005\001\119\001\
\007\001\255\255\113\001\010\001\115\001\012\001\255\255\118\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\255\255\
\255\255\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\050\001\051\001\052\001\053\001\054\001\
\055\001\056\001\057\001\058\001\059\001\060\001\061\001\062\001\
\063\001\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\071\001\072\001\073\001\074\001\075\001\076\001\077\001\078\001\
\079\001\080\001\081\001\082\001\083\001\084\001\085\001\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\093\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\102\001\
\103\001\255\255\105\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\001\001\255\255\118\001\
\004\001\005\001\255\255\007\001\008\001\009\001\010\001\011\001\
\012\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\077\001\078\001\255\255\255\255\255\255\255\255\083\001\
\255\255\255\255\255\255\087\001\088\001\089\001\090\001\091\001\
\092\001\093\001\094\001\095\001\096\001\097\001\098\001\255\255\
\255\255\255\255\102\001\103\001\104\001\105\001\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\113\001\114\001\115\001\
\116\001\117\001\001\001\255\255\255\255\004\001\005\001\255\255\
\007\001\008\001\009\001\010\001\011\001\012\001\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\255\255\078\001\
\255\255\255\255\255\255\255\255\083\001\255\255\255\255\255\255\
\087\001\088\001\089\001\090\001\091\001\092\001\093\001\255\255\
\255\255\255\255\097\001\098\001\255\255\255\255\255\255\102\001\
\103\001\104\001\105\001\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\113\001\114\001\115\001\116\001\117\001\001\001\
\255\255\255\255\255\255\005\001\255\255\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\005\001\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\255\255\102\001\103\001\255\255\105\001\
\106\001\107\001\255\255\109\001\001\001\111\001\112\001\113\001\
\005\001\115\001\255\255\255\255\255\255\255\255\255\255\012\001\
\255\255\255\255\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\255\255\255\255\255\255\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\255\255\255\255\102\001\103\001\080\001\105\001\082\001\083\001\
\084\001\255\255\086\001\255\255\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\078\001\255\255\255\255\255\255\005\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\118\001\255\255\255\255\255\255\255\255\255\255\
\255\255\102\001\103\001\255\255\105\001\255\255\030\001\255\255\
\255\255\033\001\034\001\255\255\113\001\037\001\115\001\255\255\
\040\001\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\050\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\073\001\074\001\075\001\076\001\077\001\255\255\079\001\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\255\255\
\255\255\255\255\255\255\005\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\030\001\255\255\118\001\033\001\
\034\001\255\255\255\255\037\001\255\255\255\255\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\050\001\255\255\255\255\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\082\001\083\001\084\001\085\001\086\001\255\255\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\030\001\255\255\118\001\033\001\034\001\255\255\
\255\255\037\001\255\255\255\255\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\050\001\255\255\
\255\255\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\255\255\255\255\075\001\
\255\255\077\001\255\255\255\255\080\001\081\001\082\001\083\001\
\084\001\085\001\086\001\001\001\255\255\178\002\004\001\180\002\
\181\002\007\001\008\001\009\001\010\001\011\001\012\001\013\001\
\014\001\255\255\102\001\255\255\193\002\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\255\255\255\255\118\001\255\255\255\255\069\001\070\001\255\255\
\038\001\039\001\255\255\075\001\255\255\218\002\255\255\255\255\
\080\001\255\255\082\001\083\001\084\001\255\255\086\001\228\002\
\255\255\230\002\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\238\002\064\001\065\001\255\255\255\255\068\001\069\001\
\255\255\005\001\255\255\073\001\074\001\255\255\076\001\252\002\
\078\001\255\255\255\255\255\255\255\255\083\001\118\001\255\255\
\255\255\087\001\088\001\089\001\090\001\091\001\092\001\093\001\
\255\255\255\255\030\001\097\001\098\001\033\001\034\001\255\255\
\255\255\037\001\104\001\255\255\106\001\107\001\005\001\109\001\
\029\003\111\001\112\001\255\255\114\001\012\001\255\255\255\255\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\075\001\
\255\255\077\001\255\255\255\255\080\001\081\001\255\255\083\001\
\084\001\085\001\255\255\255\255\255\255\066\001\067\001\255\255\
\069\001\070\001\255\255\255\255\255\255\255\255\075\001\255\255\
\255\255\255\255\102\001\080\001\255\255\082\001\083\001\084\001\
\255\255\086\001\255\255\007\001\255\255\113\001\010\001\115\001\
\012\001\013\001\255\255\255\255\083\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\066\001\067\001\255\255\
\069\001\070\001\030\001\255\255\255\255\033\001\075\001\102\001\
\103\001\118\001\105\001\080\001\255\255\082\001\083\001\084\001\
\255\255\086\001\113\001\255\255\115\001\116\001\117\001\051\001\
\052\001\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\255\255\255\255\075\001\
\076\001\118\001\255\255\079\001\080\001\255\255\082\001\083\001\
\084\001\007\001\086\001\255\255\010\001\255\255\012\001\013\001\
\255\255\093\001\255\255\255\255\005\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\030\001\255\255\255\255\033\001\255\255\255\255\255\255\255\255\
\255\255\255\255\118\001\255\255\255\255\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\062\001\063\001\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\071\001\072\001\255\255\255\255\075\001\076\001\255\255\
\255\255\079\001\080\001\255\255\082\001\083\001\084\001\007\001\
\086\001\255\255\010\001\076\001\012\001\013\001\079\001\093\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\106\001\107\001\030\001\255\255\
\255\255\033\001\255\255\255\255\255\255\102\001\255\255\104\001\
\118\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\255\255\255\255\079\001\
\080\001\255\255\082\001\083\001\084\001\007\001\086\001\255\255\
\010\001\255\255\012\001\013\001\255\255\093\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\106\001\107\001\030\001\255\255\066\001\033\001\
\255\255\069\001\070\001\255\255\038\001\039\001\118\001\075\001\
\255\255\255\255\255\255\255\255\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\066\001\255\255\255\255\069\001\070\001\
\255\255\059\001\060\001\061\001\075\001\255\255\064\001\065\001\
\255\255\080\001\068\001\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\076\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\118\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\093\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\118\001\
\106\001\107\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\005\001\118\001\007\001\008\001\009\001\
\010\001\011\001\012\001\013\001\014\001\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\069\001\070\001\
\255\255\255\255\255\255\255\255\075\001\255\255\255\255\255\255\
\255\255\080\001\255\255\082\001\083\001\084\001\255\255\086\001\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\078\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\118\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\103\001\255\255\105\001\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\113\001\
\005\001\115\001\007\001\008\001\009\001\010\001\011\001\012\001\
\013\001\014\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\039\001\070\001\255\255\255\255\255\255\255\255\
\075\001\255\255\255\255\255\255\255\255\080\001\255\255\082\001\
\083\001\084\001\255\255\086\001\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\118\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\102\001\103\001\255\255\105\001\106\001\107\001\255\255\
\109\001\013\001\111\001\112\001\113\001\005\001\115\001\007\001\
\255\255\255\255\255\255\255\255\012\001\255\255\255\255\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\255\255\051\001\
\052\001\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\061\001\255\255\075\001\
\255\255\255\255\255\255\079\001\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\075\001\076\001\255\255\255\255\079\001\
\255\255\081\001\255\255\083\001\084\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\103\001\
\255\255\105\001\118\001\005\001\255\255\007\001\255\255\255\255\
\255\255\113\001\012\001\115\001\255\255\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\255\255\051\001\052\001\053\001\
\054\001\055\001\056\001\057\001\058\001\059\001\060\001\061\001\
\062\001\063\001\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\071\001\072\001\061\001\255\255\075\001\255\255\255\255\
\255\255\079\001\080\001\255\255\082\001\083\001\084\001\255\255\
\086\001\075\001\076\001\255\255\255\255\079\001\255\255\081\001\
\255\255\083\001\084\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\103\001\255\255\105\001\
\118\001\005\001\255\255\007\001\255\255\255\255\255\255\113\001\
\012\001\115\001\255\255\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\051\001\052\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\061\001\062\001\063\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\061\001\255\255\075\001\255\255\255\255\255\255\079\001\
\080\001\255\255\082\001\083\001\084\001\255\255\086\001\075\001\
\076\001\255\255\255\255\079\001\255\255\081\001\255\255\083\001\
\084\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\118\001\005\001\
\255\255\007\001\255\255\255\255\255\255\113\001\012\001\115\001\
\255\255\015\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\255\255\051\001\052\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\061\001\
\255\255\075\001\255\255\255\255\255\255\079\001\080\001\255\255\
\082\001\083\001\084\001\255\255\086\001\075\001\076\001\255\255\
\255\255\079\001\255\255\081\001\255\255\083\001\084\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\102\001\103\001\255\255\105\001\118\001\005\001\255\255\007\001\
\255\255\255\255\255\255\113\001\012\001\115\001\255\255\015\001\
\016\001\017\001\018\001\019\001\020\001\021\001\022\001\023\001\
\024\001\025\001\026\001\027\001\028\001\029\001\030\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\255\255\255\255\
\255\255\053\001\054\001\055\001\056\001\057\001\058\001\059\001\
\060\001\061\001\062\001\063\001\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\071\001\072\001\061\001\255\255\075\001\
\255\255\255\255\255\255\255\255\080\001\255\255\082\001\083\001\
\084\001\255\255\086\001\255\255\076\001\255\255\255\255\255\255\
\255\255\081\001\255\255\083\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\103\001\
\255\255\105\001\118\001\005\001\255\255\007\001\255\255\255\255\
\255\255\113\001\012\001\115\001\255\255\015\001\016\001\017\001\
\018\001\019\001\020\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\255\255\255\255\255\255\255\255\
\053\001\054\001\055\001\056\001\057\001\058\001\255\255\255\255\
\255\255\255\255\255\255\255\255\065\001\066\001\067\001\255\255\
\069\001\070\001\255\255\061\001\255\255\255\255\075\001\255\255\
\255\255\255\255\005\001\080\001\255\255\082\001\083\001\084\001\
\255\255\086\001\076\001\255\255\255\255\255\255\255\255\255\255\
\255\255\083\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\102\001\103\001\255\255\105\001\
\255\255\118\001\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\053\001\054\001\055\001\056\001\057\001\058\001\
\059\001\060\001\061\001\062\001\063\001\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\255\255\
\083\001\084\001\085\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\102\001\255\255\255\255\255\255\255\255\
\005\001\255\255\255\255\255\255\255\255\255\255\113\001\012\001\
\115\001\005\001\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\005\001\030\001\007\001\255\255\033\001\034\001\255\255\
\012\001\037\001\255\255\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\255\255\255\255\255\255\066\001\076\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\085\001\077\001\255\255\255\255\080\001\081\001\255\255\083\001\
\084\001\085\001\086\001\070\001\255\255\255\255\255\255\255\255\
\075\001\102\001\103\001\255\255\105\001\080\001\255\255\082\001\
\083\001\084\001\102\001\086\001\113\001\255\255\115\001\255\255\
\255\255\255\255\255\255\255\255\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\255\255\005\001\
\255\255\255\255\255\255\118\001\255\255\113\001\012\001\115\001\
\005\001\015\001\016\001\017\001\018\001\019\001\020\001\021\001\
\022\001\023\001\024\001\025\001\026\001\027\001\028\001\029\001\
\030\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\005\001\030\001\255\255\255\255\033\001\034\001\255\255\012\001\
\037\001\255\255\015\001\016\001\017\001\018\001\019\001\020\001\
\021\001\022\001\023\001\024\001\025\001\026\001\027\001\028\001\
\029\001\030\001\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\255\255\255\255\255\255\255\255\066\001\076\001\255\255\
\069\001\070\001\255\255\255\255\255\255\255\255\075\001\255\255\
\077\001\255\255\255\255\080\001\081\001\255\255\083\001\084\001\
\085\001\086\001\255\255\255\255\255\255\255\255\255\255\255\255\
\102\001\103\001\255\255\105\001\255\255\255\255\255\255\255\255\
\255\255\102\001\255\255\113\001\255\255\115\001\255\255\255\255\
\085\001\255\255\255\255\255\255\113\001\255\255\115\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\102\001\103\001\255\255\105\001\255\255\005\001\255\255\
\255\255\255\255\255\255\255\255\113\001\012\001\115\001\255\255\
\015\001\016\001\017\001\018\001\019\001\020\001\021\001\022\001\
\023\001\024\001\025\001\026\001\027\001\028\001\029\001\030\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\255\255\
\255\255\255\255\255\255\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\255\255\
\255\255\075\001\255\255\255\255\255\255\005\001\080\001\255\255\
\082\001\083\001\084\001\255\255\086\001\076\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\030\001\255\255\
\255\255\033\001\034\001\255\255\255\255\037\001\255\255\102\001\
\103\001\255\255\105\001\255\255\118\001\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\255\255\255\255\255\255\
\255\255\065\001\066\001\067\001\005\001\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\255\255\255\255\255\255\255\255\
\065\001\066\001\067\001\005\001\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\255\255\255\255\033\001\
\034\001\255\255\255\255\037\001\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\053\001\054\001\055\001\056\001\057\001\
\058\001\059\001\060\001\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\071\001\072\001\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\005\001\255\255\255\255\255\255\255\255\255\255\113\001\
\012\001\115\001\005\001\015\001\016\001\017\001\018\001\019\001\
\020\001\021\001\022\001\023\001\024\001\025\001\026\001\027\001\
\028\001\029\001\030\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\255\255\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\053\001\054\001\055\001\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\005\001\
\083\001\084\001\085\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\103\001\255\255\105\001\255\255\255\255\
\255\255\255\255\255\255\102\001\255\255\113\001\255\255\115\001\
\030\001\255\255\255\255\033\001\034\001\255\255\113\001\037\001\
\115\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\053\001\
\054\001\055\001\056\001\057\001\058\001\255\255\255\255\255\255\
\255\255\255\255\255\255\065\001\066\001\067\001\005\001\069\001\
\070\001\071\001\072\001\255\255\255\255\075\001\255\255\077\001\
\255\255\255\255\080\001\081\001\255\255\083\001\084\001\085\001\
\086\001\255\255\255\255\255\255\255\255\255\255\255\255\030\001\
\255\255\255\255\033\001\034\001\255\255\255\255\037\001\255\255\
\102\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\113\001\255\255\115\001\053\001\054\001\
\055\001\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\005\001\069\001\070\001\
\071\001\072\001\255\255\255\255\075\001\255\255\077\001\255\255\
\255\255\080\001\081\001\255\255\083\001\084\001\085\001\086\001\
\255\255\255\255\255\255\255\255\255\255\255\255\030\001\255\255\
\255\255\033\001\034\001\255\255\255\255\037\001\255\255\102\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\053\001\054\001\055\001\
\056\001\057\001\058\001\255\255\255\255\255\255\255\255\255\255\
\255\255\065\001\066\001\067\001\005\001\069\001\070\001\255\255\
\255\255\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\053\001\054\001\055\001\056\001\
\057\001\058\001\255\255\255\255\255\255\255\255\255\255\255\255\
\065\001\066\001\067\001\005\001\069\001\070\001\255\255\255\255\
\255\255\255\255\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\255\255\255\255\033\001\
\034\001\255\255\255\255\037\001\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\053\001\054\001\055\001\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\005\001\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\255\255\255\255\255\255\
\255\255\255\255\255\255\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\113\001\
\255\255\115\001\053\001\054\001\055\001\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\255\255\065\001\066\001\
\067\001\005\001\069\001\070\001\255\255\255\255\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\255\255\
\083\001\084\001\085\001\086\001\255\255\255\255\255\255\255\255\
\255\255\255\255\030\001\255\255\255\255\033\001\034\001\255\255\
\255\255\037\001\255\255\102\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\113\001\255\255\
\115\001\053\001\054\001\055\001\056\001\057\001\058\001\255\255\
\255\255\255\255\005\001\255\255\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\255\255\077\001\255\255\255\255\080\001\081\001\255\255\083\001\
\084\001\085\001\086\001\030\001\255\255\255\255\033\001\034\001\
\255\255\255\255\037\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\102\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\053\001\054\001\255\255\113\001\255\255\115\001\
\255\255\255\255\255\255\005\001\255\255\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\255\255\255\255\255\255\255\255\
\075\001\255\255\077\001\255\255\255\255\080\001\081\001\255\255\
\083\001\084\001\085\001\086\001\030\001\255\255\255\255\033\001\
\034\001\255\255\255\255\037\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\102\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\053\001\054\001\255\255\113\001\255\255\
\115\001\255\255\255\255\255\255\005\001\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\077\001\255\255\255\255\080\001\081\001\
\255\255\083\001\084\001\085\001\086\001\030\001\255\255\255\255\
\033\001\034\001\255\255\255\255\037\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\102\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\053\001\054\001\255\255\113\001\
\255\255\115\001\255\255\255\255\255\255\005\001\255\255\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\255\255\255\255\
\255\255\255\255\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\255\255\083\001\084\001\085\001\086\001\030\001\255\255\
\255\255\033\001\034\001\255\255\255\255\037\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\102\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\113\001\255\255\115\001\255\255\255\255\255\255\005\001\255\255\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\255\255\
\255\255\255\255\255\255\075\001\255\255\077\001\255\255\255\255\
\080\001\081\001\255\255\083\001\084\001\085\001\086\001\030\001\
\255\255\255\255\033\001\034\001\255\255\255\255\037\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\102\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\113\001\255\255\115\001\255\255\255\255\255\255\005\001\
\255\255\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\255\255\255\255\255\255\255\255\075\001\255\255\077\001\255\255\
\255\255\080\001\081\001\255\255\083\001\084\001\085\001\086\001\
\030\001\255\255\255\255\033\001\034\001\255\255\255\255\037\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\102\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\113\001\255\255\115\001\255\255\255\255\255\255\
\005\001\255\255\255\255\255\255\066\001\067\001\255\255\069\001\
\070\001\255\255\255\255\255\255\255\255\075\001\255\255\077\001\
\255\255\255\255\080\001\081\001\005\001\083\001\084\001\085\001\
\086\001\030\001\255\255\255\255\033\001\034\001\255\255\255\255\
\037\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\102\001\255\255\255\255\255\255\255\255\030\001\255\255\255\255\
\033\001\034\001\255\255\113\001\037\001\115\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\066\001\067\001\255\255\
\069\001\070\001\255\255\255\255\255\255\255\255\075\001\255\255\
\077\001\255\255\255\255\080\001\081\001\255\255\083\001\084\001\
\085\001\086\001\255\255\007\001\069\001\070\001\010\001\255\255\
\012\001\013\001\075\001\255\255\077\001\255\255\255\255\080\001\
\081\001\102\001\083\001\084\001\085\001\086\001\255\255\255\255\
\255\255\255\255\030\001\255\255\113\001\033\001\115\001\255\255\
\255\255\255\255\038\001\039\001\255\255\102\001\007\001\008\001\
\009\001\010\001\011\001\012\001\013\001\014\001\255\255\255\255\
\113\001\255\255\115\001\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\032\001\
\068\001\255\255\255\255\255\255\255\255\038\001\039\001\040\001\
\076\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\093\001\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\106\001\107\001\
\073\001\074\001\075\001\076\001\255\255\078\001\079\001\080\001\
\081\001\255\255\083\001\084\001\007\001\008\001\009\001\010\001\
\011\001\012\001\013\001\014\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\106\001\107\001\255\255\109\001\255\255\111\001\112\001\
\255\255\255\255\255\255\038\001\039\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\052\001\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\255\255\073\001\074\001\
\255\255\076\001\255\255\078\001\079\001\255\255\255\255\255\255\
\007\001\008\001\009\001\010\001\011\001\255\255\013\001\014\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\106\001\
\107\001\032\001\109\001\255\255\111\001\112\001\255\255\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\255\255\255\255\
\255\255\080\001\255\255\007\001\008\001\009\001\010\001\011\001\
\255\255\013\001\014\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\038\001\039\001\040\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\255\255\078\001\255\255\255\255\255\255\007\001\008\001\
\009\001\010\001\011\001\255\255\013\001\014\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\038\001\039\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\255\255\255\255\
\073\001\074\001\255\255\076\001\255\255\078\001\255\255\255\255\
\255\255\007\001\008\001\009\001\010\001\011\001\255\255\013\001\
\014\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\106\001\107\001\255\255\109\001\255\255\111\001\112\001\
\038\001\039\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\255\255\064\001\065\001\255\255\255\255\068\001\069\001\
\255\255\255\255\255\255\073\001\074\001\255\255\076\001\255\255\
\078\001\255\255\255\255\255\255\007\001\008\001\009\001\010\001\
\011\001\255\255\013\001\014\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\106\001\107\001\255\255\109\001\
\255\255\111\001\112\001\038\001\039\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\255\255\073\001\074\001\
\255\255\076\001\255\255\255\255\255\255\255\255\255\255\255\255\
\083\001\007\001\008\001\009\001\010\001\011\001\255\255\013\001\
\014\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\106\001\
\107\001\255\255\109\001\255\255\111\001\112\001\255\255\255\255\
\038\001\039\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\255\255\064\001\065\001\255\255\255\255\068\001\069\001\
\255\255\255\255\255\255\073\001\074\001\255\255\076\001\255\255\
\255\255\255\255\080\001\255\255\007\001\008\001\009\001\010\001\
\011\001\255\255\013\001\014\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\106\001\107\001\255\255\109\001\
\255\255\111\001\112\001\038\001\039\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\255\255\073\001\074\001\
\255\255\076\001\255\255\078\001\255\255\255\255\255\255\007\001\
\008\001\009\001\010\001\011\001\255\255\013\001\014\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\106\001\
\107\001\255\255\109\001\255\255\111\001\112\001\038\001\039\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\059\001\060\001\061\001\255\255\255\255\
\064\001\065\001\255\255\255\255\068\001\069\001\255\255\255\255\
\255\255\073\001\074\001\255\255\076\001\255\255\255\255\255\255\
\080\001\255\255\007\001\008\001\009\001\010\001\011\001\255\255\
\013\001\014\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\106\001\107\001\255\255\109\001\255\255\111\001\
\112\001\038\001\039\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\059\001\060\001\
\061\001\255\255\255\255\064\001\065\001\255\255\255\255\068\001\
\069\001\255\255\255\255\255\255\073\001\074\001\255\255\076\001\
\255\255\255\255\255\255\255\255\255\255\007\001\008\001\009\001\
\010\001\011\001\255\255\013\001\014\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\106\001\107\001\255\255\
\109\001\255\255\111\001\112\001\038\001\039\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\069\001\255\255\255\255\255\255\073\001\
\074\001\255\255\076\001\255\255\255\255\255\255\255\255\255\255\
\007\001\008\001\009\001\010\001\011\001\255\255\013\001\014\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\106\001\107\001\255\255\109\001\255\255\111\001\112\001\038\001\
\039\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\059\001\060\001\061\001\255\255\
\255\255\064\001\065\001\255\255\255\255\068\001\069\001\255\255\
\255\255\255\255\073\001\074\001\255\255\076\001\255\255\255\255\
\255\255\255\255\255\255\007\001\008\001\009\001\010\001\011\001\
\255\255\013\001\014\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\106\001\107\001\255\255\109\001\255\255\
\111\001\112\001\038\001\039\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\059\001\
\060\001\061\001\255\255\255\255\064\001\065\001\255\255\255\255\
\068\001\069\001\255\255\255\255\255\255\073\001\074\001\255\255\
\076\001\255\255\255\255\255\255\255\255\255\255\007\001\008\001\
\009\001\010\001\011\001\255\255\013\001\014\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\106\001\107\001\
\255\255\109\001\255\255\111\001\112\001\038\001\039\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\059\001\060\001\061\001\255\255\255\255\064\001\
\065\001\255\255\255\255\068\001\069\001\255\255\255\255\255\255\
\073\001\074\001\255\255\076\001\255\255\255\255\255\255\255\255\
\255\255\007\001\008\001\009\001\010\001\011\001\255\255\013\001\
\014\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\106\001\107\001\255\255\109\001\255\255\111\001\112\001\
\038\001\039\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\059\001\060\001\061\001\
\255\255\255\255\064\001\065\001\255\255\255\255\068\001\069\001\
\255\255\255\255\255\255\073\001\074\001\255\255\076\001\255\255\
\255\255\255\255\255\255\255\255\007\001\008\001\009\001\010\001\
\011\001\255\255\013\001\014\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\106\001\107\001\255\255\109\001\
\255\255\111\001\112\001\038\001\039\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\059\001\060\001\061\001\255\255\255\255\064\001\065\001\255\255\
\255\255\068\001\069\001\255\255\255\255\007\001\073\001\074\001\
\010\001\076\001\012\001\013\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\030\001\255\255\255\255\033\001\
\255\255\255\255\255\255\255\255\038\001\039\001\255\255\106\001\
\107\001\255\255\109\001\255\255\111\001\112\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\059\001\060\001\061\001\255\255\255\255\064\001\065\001\
\255\255\255\255\068\001\255\255\255\255\255\255\255\255\255\255\
\255\255\075\001\076\001\255\255\255\255\255\255\255\255\255\255\
\053\001\054\001\055\001\056\001\057\001\058\001\059\001\060\001\
\255\255\255\255\255\255\093\001\065\001\066\001\067\001\255\255\
\069\001\070\001\071\001\072\001\255\255\255\255\075\001\255\255\
\106\001\107\001\255\255\080\001\255\255\082\001\083\001\084\001\
\255\255\086\001\255\255\255\255\255\255\053\001\054\001\055\001\
\056\001\057\001\058\001\059\001\060\001\255\255\255\255\255\255\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\071\001\
\072\001\255\255\255\255\075\001\255\255\255\255\255\255\255\255\
\080\001\118\001\082\001\083\001\084\001\255\255\086\001\255\255\
\255\255\255\255\053\001\054\001\055\001\056\001\057\001\058\001\
\255\255\255\255\255\255\255\255\255\255\255\255\065\001\066\001\
\067\001\255\255\069\001\070\001\071\001\072\001\255\255\255\255\
\075\001\255\255\255\255\255\255\255\255\080\001\118\001\082\001\
\083\001\084\001\255\255\086\001\255\255\255\255\255\255\053\001\
\054\001\055\001\056\001\057\001\058\001\255\255\255\255\255\255\
\255\255\255\255\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\071\001\072\001\255\255\255\255\075\001\255\255\255\255\
\255\255\255\255\080\001\118\001\082\001\083\001\084\001\255\255\
\086\001\255\255\255\255\255\255\053\001\054\001\055\001\056\001\
\057\001\058\001\255\255\255\255\255\255\255\255\255\255\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\071\001\072\001\
\255\255\255\255\075\001\255\255\255\255\255\255\255\255\080\001\
\118\001\082\001\083\001\084\001\255\255\086\001\255\255\255\255\
\255\255\053\001\054\001\055\001\056\001\057\001\058\001\255\255\
\255\255\255\255\255\255\255\255\255\255\065\001\066\001\067\001\
\255\255\069\001\070\001\255\255\255\255\255\255\255\255\075\001\
\255\255\255\255\255\255\255\255\080\001\118\001\082\001\083\001\
\084\001\255\255\086\001\255\255\255\255\255\255\053\001\054\001\
\055\001\056\001\057\001\058\001\255\255\255\255\255\255\255\255\
\255\255\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\255\255\255\255\255\255\255\255\075\001\255\255\255\255\255\255\
\255\255\080\001\118\001\082\001\083\001\084\001\255\255\086\001\
\255\255\255\255\255\255\053\001\054\001\055\001\056\001\057\001\
\058\001\255\255\255\255\255\255\255\255\255\255\255\255\065\001\
\066\001\067\001\255\255\069\001\070\001\255\255\255\255\255\255\
\255\255\075\001\255\255\255\255\255\255\255\255\080\001\118\001\
\082\001\083\001\084\001\255\255\086\001\255\255\255\255\255\255\
\053\001\054\001\055\001\056\001\057\001\058\001\255\255\255\255\
\255\255\255\255\255\255\255\255\065\001\066\001\067\001\255\255\
\069\001\070\001\255\255\255\255\255\255\255\255\075\001\053\001\
\054\001\255\255\255\255\080\001\118\001\082\001\083\001\084\001\
\255\255\086\001\255\255\065\001\066\001\067\001\255\255\069\001\
\070\001\255\255\255\255\255\255\255\255\075\001\053\001\054\001\
\255\255\255\255\080\001\255\255\082\001\083\001\084\001\255\255\
\086\001\255\255\065\001\066\001\067\001\255\255\069\001\070\001\
\255\255\118\001\255\255\255\255\075\001\053\001\054\001\255\255\
\255\255\080\001\255\255\082\001\083\001\084\001\255\255\086\001\
\255\255\065\001\066\001\067\001\255\255\069\001\070\001\255\255\
\118\001\255\255\255\255\075\001\255\255\255\255\255\255\255\255\
\080\001\255\255\082\001\083\001\084\001\255\255\086\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\118\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\118\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\050\001\051\001\052\001\053\001\054\001\055\001\056\001\
\057\001\058\001\059\001\060\001\061\001\062\001\063\001\255\255\
\065\001\066\001\067\001\255\255\069\001\070\001\071\001\072\001\
\073\001\074\001\255\255\076\001\077\001\255\255\079\001\255\255\
\081\001\255\255\083\001\084\001\255\255\086\001"

let yynames_const = "\
  EOF\000\
  EQ\000\
  PLUS_EQ\000\
  MINUS_EQ\000\
  STAR_EQ\000\
  SLASH_EQ\000\
  PERCENT_EQ\000\
  AND_EQ\000\
  PIPE_EQ\000\
  CIRC_EQ\000\
  INF_INF_EQ\000\
  SUP_SUP_EQ\000\
  ARROW\000\
  DOT\000\
  EQ_EQ\000\
  EXCLAM_EQ\000\
  INF\000\
  SUP\000\
  INF_EQ\000\
  SUP_EQ\000\
  SLASH\000\
  PERCENT\000\
  PIPE\000\
  CIRC\000\
  PIPE_PIPE\000\
  INF_INF\000\
  SUP_SUP\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  COLON\000\
  COLON2\000\
  COMMA\000\
  ELLIPSIS\000\
  QUEST\000\
  ELSE\000\
  LABEL__\000\
  BLOCKATTRIBUTE\000\
  PRAGMA_EOL\000\
  LGHOST\000\
  RGHOST\000\
  "

let yynames_block = "\
  SPEC\000\
  DECL\000\
  CODE_ANNOT\000\
  LOOP_ANNOT\000\
  ATTRIBUTE_ANNOT\000\
  CUSTOM_ANNOT\000\
  IDENT\000\
  CST_CHAR\000\
  CST_WCHAR\000\
  CST_INT\000\
  CST_FLOAT\000\
  NAMED_TYPE\000\
  CST_STRING\000\
  CST_WSTRING\000\
  BOOL\000\
  CHAR\000\
  INT\000\
  DOUBLE\000\
  FLOAT\000\
  VOID\000\
  INT64\000\
  ENUM\000\
  STRUCT\000\
  TYPEDEF\000\
  UNION\000\
  SIGNED\000\
  UNSIGNED\000\
  LONG\000\
  SHORT\000\
  VOLATILE\000\
  EXTERN\000\
  STATIC\000\
  CONST\000\
  RESTRICT\000\
  AUTO\000\
  REGISTER\000\
  THREAD\000\
  SIZEOF\000\
  ALIGNOF\000\
  PLUS\000\
  MINUS\000\
  STAR\000\
  TILDE\000\
  AND\000\
  EXCLAM\000\
  AND_AND\000\
  PLUS_PLUS\000\
  MINUS_MINUS\000\
  LPAREN\000\
  RBRACE\000\
  LBRACE\000\
  SEMICOLON\000\
  BREAK\000\
  CONTINUE\000\
  GOTO\000\
  RETURN\000\
  SWITCH\000\
  CASE\000\
  DEFAULT\000\
  WHILE\000\
  DO\000\
  FOR\000\
  IF\000\
  TRY\000\
  EXCEPT\000\
  FINALLY\000\
  ATTRIBUTE\000\
  INLINE\000\
  ASM\000\
  TYPEOF\000\
  FUNCTION__\000\
  PRETTY_FUNCTION__\000\
  BUILTIN_VA_ARG\000\
  BUILTIN_TYPES_COMPAT\000\
  BUILTIN_OFFSETOF\000\
  DECLSPEC\000\
  MSASM\000\
  MSATTR\000\
  PRAGMA_LINE\000\
  PRAGMA\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 436 "src/kernel_internals/parsing/cparser.mly"
                ( _1 )
# 3011 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : (bool*Cabs.definition) list) in
    Obj.repr(
# 438 "src/kernel_internals/parsing/cparser.mly"
                    (_1)
# 3018 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 441 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 3024 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 442 "src/kernel_internals/parsing/cparser.mly"
                                        ( (false,_1) :: _2 )
# 3032 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'ghost_globals) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 443 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2 @ _3 )
# 3040 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : (bool*Cabs.definition) list) in
    Obj.repr(
# 444 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2 )
# 3048 "src/kernel_internals/parsing/cparser.ml"
               : (bool*Cabs.definition) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_globals) in
    Obj.repr(
# 449 "src/kernel_internals/parsing/cparser.mly"
                                                      ( (true,_1)::_2 )
# 3056 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'ghost_globals) in
    Obj.repr(
# 450 "src/kernel_internals/parsing/cparser.mly"
                                                      ( (true,_1)::_2 )
# 3064 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    Obj.repr(
# 451 "src/kernel_internals/parsing/cparser.mly"
                                                      ( [] )
# 3070 "src/kernel_internals/parsing/cparser.ml"
               : 'ghost_globals))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.decl list) in
    Obj.repr(
# 456 "src/kernel_internals/parsing/cparser.mly"
                   ( GLOBANNOT _1 )
# 3077 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.custom_tree  * string * Cabs.cabsloc) in
    Obj.repr(
# 457 "src/kernel_internals/parsing/cparser.mly"
                   ( let (x,y,z) = _1 in CUSTOM(x,y,z) )
# 3084 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 458 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3091 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 459 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3098 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 464 "src/kernel_internals/parsing/cparser.mly"
    ( LINKAGE (fst _2, (*handleLoc*) (snd _2), [ _3 ]) )
# 3107 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : (bool*Cabs.definition) list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 466 "src/kernel_internals/parsing/cparser.mly"
    ( LINKAGE (fst _2, (*handleLoc*) (snd _2),
                 List.map
                   (fun (x,y) ->
                      if x then
                        Errorloc.parse_error "invalid ghost in extern linkage \
                                              specification"
		      else y)
                   _4)  )
# 3125 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 475 "src/kernel_internals/parsing/cparser.mly"
                                        ( GLOBASM (fst _3, (*handleLoc*) _1) )
# 3135 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'pragma) in
    Obj.repr(
# 476 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 3142 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'old_pardef_list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 481 "src/kernel_internals/parsing/cparser.mly"
    (
      let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
      (* Convert pardecl to new style *)
      let pardecl, isva = doOldParDecl _3 _5 in
      (* Make the function declarator *)
      doDeclaration None loc []
        [((_1, PROTO(JUSTBASE, pardecl,isva), 
           ["FC_OLDSTYLEPROTO",[]], loc), NO_INIT)]
    )
# 3161 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 490 "src/kernel_internals/parsing/cparser.mly"
                                (
  let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
  doDeclaration None loc []
    [((_1, PROTO(JUSTBASE,[],false),
       ["FC_OLDSTYLEPROTO",[]], loc), NO_INIT)]
)
# 3175 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 499 "src/kernel_internals/parsing/cparser.mly"
             ( _1 )
# 3182 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename_as_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 500 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 3189 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename_as_id))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 504 "src/kernel_internals/parsing/cparser.mly"
                          ( _1 )
# 3196 "src/kernel_internals/parsing/cparser.ml"
               : 'id_or_typename))
; (fun __caml_parser_env ->
    Obj.repr(
# 508 "src/kernel_internals/parsing/cparser.mly"
                                        ( () )
# 3202 "src/kernel_internals/parsing/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    Obj.repr(
# 509 "src/kernel_internals/parsing/cparser.mly"
                                        ( () )
# 3208 "src/kernel_internals/parsing/cparser.ml"
               : 'maybecomma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 515 "src/kernel_internals/parsing/cparser.mly"
         ( make_expr (VARIABLE _1) )
# 3215 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.constant * cabsloc) in
    Obj.repr(
# 516 "src/kernel_internals/parsing/cparser.mly"
                   ( make_expr (CONSTANT (fst _1)) )
# 3222 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 518 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (PAREN (smooth_expression _1)) )
# 3229 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 519 "src/kernel_internals/parsing/cparser.mly"
                       ( make_expr (GNU_BODY (fst3 _2)) )
# 3237 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_expression) in
    Obj.repr(
# 523 "src/kernel_internals/parsing/cparser.mly"
                     ( _1 )
# 3244 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 525 "src/kernel_internals/parsing/cparser.mly"
      (make_expr (INDEX (_1, smooth_expression _2)))
# 3252 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 526 "src/kernel_internals/parsing/cparser.mly"
                                             (make_expr (CALL (_1, _3)))
# 3261 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 528 "src/kernel_internals/parsing/cparser.mly"
      ( let b, d = _5 in
        let loc = Parsing.rhs_start_pos 5, Parsing.rhs_end_pos 5 in
        let loc_f = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
        make_expr
          (CALL
             ({ expr_loc = loc_f;
                expr_node = VARIABLE "__builtin_va_arg"},
              [_3; { expr_loc = loc;
                     expr_node = TYPE_SIZEOF (b, d)}]))
      )
# 3280 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 539 "src/kernel_internals/parsing/cparser.mly"
      ( let b1,d1 = _3 in
        let b2,d2 = _5 in
        let loc_f = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
        let loc1 = Parsing.rhs_start_pos 3, Parsing.rhs_end_pos 3 in
        let loc2 = Parsing.rhs_start_pos 5, Parsing.rhs_end_pos 5 in
        make_expr
          (CALL
             ({expr_loc = loc_f;
               expr_node = VARIABLE "__builtin_types_compatible_p"},
              [ { expr_loc = loc1; expr_node = TYPE_SIZEOF(b1,d1)};
                { expr_loc = loc2; expr_node = TYPE_SIZEOF(b2,d2)}]))
      )
# 3301 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.spec_elem list * Cabs.decl_type) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    Obj.repr(
# 552 "src/kernel_internals/parsing/cparser.mly"
      ( transformOffsetOf _3 _5 )
# 3311 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 553 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROF (_1, _3)))
# 3319 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 554 "src/kernel_internals/parsing/cparser.mly"
                                          ( make_expr (MEMBEROFPTR (_1, _3)) )
# 3327 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 555 "src/kernel_internals/parsing/cparser.mly"
                               ( make_expr (UNARY (POSINCR, _1)) )
# 3335 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'postfix_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 556 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (POSDECR, _1)) )
# 3343 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 559 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (CAST(_2, COMPOUND_INIT _5)) )
# 3354 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 563 "src/kernel_internals/parsing/cparser.mly"
                  ( make_expr (VARIABLE _1) )
# 3361 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'offsetof_member_designator) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 565 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (MEMBEROF (_1, _3)) )
# 3369 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'offsetof_member_designator) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 567 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (INDEX (_1, smooth_expression _2)) )
# 3377 "src/kernel_internals/parsing/cparser.ml"
               : 'offsetof_member_designator))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 572 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3384 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 574 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (PREINCR, _2)))
# 3392 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 576 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (PREDECR, _2)))
# 3400 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 578 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (EXPR_SIZEOF _2))
# 3408 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 580 "src/kernel_internals/parsing/cparser.mly"
          (let b, d = _3 in make_expr (TYPE_SIZEOF (b, d)) )
# 3417 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 582 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (EXPR_ALIGNOF _2) )
# 3425 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 584 "src/kernel_internals/parsing/cparser.mly"
          (let b, d = _3 in make_expr (TYPE_ALIGNOF (b, d)) )
# 3434 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 586 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (PLUS, _2)) )
# 3442 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 588 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (MINUS, _2)) )
# 3450 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 590 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (MEMOF, _2)) )
# 3458 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 592 "src/kernel_internals/parsing/cparser.mly"
          (make_expr (UNARY (ADDROF, _2)))
# 3466 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 594 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (NOT, _2)) )
# 3474 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 596 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (UNARY (BNOT, _2)) )
# 3482 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 598 "src/kernel_internals/parsing/cparser.mly"
                                             ( make_expr (LABELADDR _2) )
# 3490 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 602 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 3497 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.spec_elem list * Cabs.decl_type) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 604 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (CAST(_2, SINGLE_INIT _4)) )
# 3506 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 608 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 3513 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 610 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(MUL, _1, _3)) )
# 3522 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 612 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(DIV, _1, _3)) )
# 3530 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_expression) in
    Obj.repr(
# 614 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(MOD, _1, _3)) )
# 3538 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 618 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 3545 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 620 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ADD, _1, _3)) )
# 3554 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 622 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SUB, _1, _3)) )
# 3563 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 626 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 3570 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 628 "src/kernel_internals/parsing/cparser.mly"
   (make_expr (BINARY(SHL, _1, _3)) )
# 3578 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_expression) in
    Obj.repr(
# 630 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHR, _1, _3)) )
# 3586 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 635 "src/kernel_internals/parsing/cparser.mly"
                                 ( _1 )
# 3593 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 637 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(LT, _1, _3)) )
# 3601 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 639 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(GT, _1, _3)) )
# 3609 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 641 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(LE, _1, _3)) )
# 3617 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_expression) in
    Obj.repr(
# 643 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(GE, _1, _3)) )
# 3625 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 647 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3632 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 649 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(EQ, _1, _3)) )
# 3640 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_expression) in
    Obj.repr(
# 651 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (BINARY(NE, _1, _3)) )
# 3648 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 655 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 3655 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_expression) in
    Obj.repr(
# 657 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BAND, _1, _3)) )
# 3664 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 661 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3671 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_expression) in
    Obj.repr(
# 663 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(XOR, _1, _3)) )
# 3679 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 667 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3686 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_expression) in
    Obj.repr(
# 669 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BOR, _1, _3)) )
# 3694 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 673 "src/kernel_internals/parsing/cparser.mly"
                                      ( _1 )
# 3701 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_expression) in
    Obj.repr(
# 675 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(AND, _1, _3)) )
# 3710 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 679 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3717 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 681 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(OR, _1, _3)) )
# 3725 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 685 "src/kernel_internals/parsing/cparser.mly"
                        ( _1 )
# 3732 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'logical_or_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 687 "src/kernel_internals/parsing/cparser.mly"
      ( make_expr (QUESTION (_1, _3, _5)) )
# 3741 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 694 "src/kernel_internals/parsing/cparser.mly"
                                       ( _1 )
# 3748 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 696 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ASSIGN, _1, _3)) )
# 3756 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 698 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(ADD_ASSIGN, _1, _3)) )
# 3764 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 700 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SUB_ASSIGN, _1, _3)) )
# 3772 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 702 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(MUL_ASSIGN, _1, _3)) )
# 3780 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 704 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(DIV_ASSIGN, _1, _3)) )
# 3788 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 706 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(MOD_ASSIGN, _1, _3)) )
# 3796 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 708 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BAND_ASSIGN, _1, _3)) )
# 3804 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 710 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(BOR_ASSIGN, _1, _3)) )
# 3812 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 712 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(XOR_ASSIGN, _1, _3)) )
# 3820 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 714 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHL_ASSIGN, _1, _3)) )
# 3828 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'cast_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 716 "src/kernel_internals/parsing/cparser.mly"
   ( make_expr (BINARY(SHR_ASSIGN, _1, _3)))
# 3836 "src/kernel_internals/parsing/cparser.ml"
               : 'assignment_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 720 "src/kernel_internals/parsing/cparser.mly"
                                      ( _1 )
# 3843 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 725 "src/kernel_internals/parsing/cparser.mly"
               (CONST_INT (fst _1), snd _1)
# 3850 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 726 "src/kernel_internals/parsing/cparser.mly"
                 (CONST_FLOAT (fst _1), snd _1)
# 3857 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 727 "src/kernel_internals/parsing/cparser.mly"
                (CONST_CHAR (fst _1), snd _1)
# 3864 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 728 "src/kernel_internals/parsing/cparser.mly"
                 (CONST_WCHAR (fst _1), snd _1)
# 3871 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 729 "src/kernel_internals/parsing/cparser.mly"
                             (CONST_STRING (fst _1), snd _1)
# 3878 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * cabsloc) in
    Obj.repr(
# 730 "src/kernel_internals/parsing/cparser.mly"
                   (CONST_WSTRING (fst _1), snd _1)
# 3885 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.constant * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list Queue.t * cabsloc) in
    Obj.repr(
# 736 "src/kernel_internals/parsing/cparser.mly"
                                        (
     let queue, location = _1 in
     let buffer = Buffer.create (Queue.length queue) in
     Queue.iter
       (List.iter
	  (fun value ->
	    let char = int64_to_char value in
	    Buffer.add_char buffer char))
       queue;
     Buffer.contents buffer, location
   )
# 3902 "src/kernel_internals/parsing/cparser.ml"
               : string * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 750 "src/kernel_internals/parsing/cparser.mly"
                                        (intlist_to_string (fst _1) )
# 3909 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string_constant))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 753 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let queue = Queue.create () in
      Queue.add (fst _1) queue;
      queue, snd _1
    )
# 3920 "src/kernel_internals/parsing/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list Queue.t * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 758 "src/kernel_internals/parsing/cparser.mly"
                                        (
      Queue.add (fst _2) (fst _1);
      _1
    )
# 3931 "src/kernel_internals/parsing/cparser.ml"
               : int64 list Queue.t * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 765 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 3938 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'one_string) in
    Obj.repr(
# 766 "src/kernel_internals/parsing/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3946 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : int64 list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 767 "src/kernel_internals/parsing/cparser.mly"
                                        ( (fst _1) @ (fst _2), snd _1 )
# 3954 "src/kernel_internals/parsing/cparser.ml"
               : int64 list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : int64 list * Cabs.cabsloc) in
    Obj.repr(
# 772 "src/kernel_internals/parsing/cparser.mly"
                  (_1)
# 3961 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 773 "src/kernel_internals/parsing/cparser.mly"
                                        ((Cabshelper.explodeStringToInts
					    !currentFunctionName), _1)
# 3969 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 775 "src/kernel_internals/parsing/cparser.mly"
                                        ((Cabshelper.explodeStringToInts
					    !currentFunctionName), _1)
# 3977 "src/kernel_internals/parsing/cparser.ml"
               : 'one_string))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 780 "src/kernel_internals/parsing/cparser.mly"
                        ( SINGLE_INIT _1 )
# 3984 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'initializer_list_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 782 "src/kernel_internals/parsing/cparser.mly"
   ( COMPOUND_INIT _2)
# 3993 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat * Cabs.init_expression) in
    Obj.repr(
# 785 "src/kernel_internals/parsing/cparser.mly"
                                                   ( [_1] )
# 4000 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat * Cabs.init_expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'initializer_list_opt) in
    Obj.repr(
# 786 "src/kernel_internals/parsing/cparser.mly"
                                                   ( _1 :: _3 )
# 4008 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.initwhat * Cabs.init_expression) list))
; (fun __caml_parser_env ->
    Obj.repr(
# 789 "src/kernel_internals/parsing/cparser.mly"
                                            ( [] )
# 4014 "src/kernel_internals/parsing/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.initwhat * Cabs.init_expression) list) in
    Obj.repr(
# 790 "src/kernel_internals/parsing/cparser.mly"
                                            ( _1 )
# 4021 "src/kernel_internals/parsing/cparser.ml"
               : 'initializer_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.initwhat) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'eq_opt) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 793 "src/kernel_internals/parsing/cparser.mly"
                                            ( (_1, _3) )
# 4030 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'gcc_init_designators) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 794 "src/kernel_internals/parsing/cparser.mly"
                                         ( (_1, _2) )
# 4038 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 795 "src/kernel_internals/parsing/cparser.mly"
                                        ( (NEXT_INIT, _1) )
# 4045 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat * Cabs.init_expression))
; (fun __caml_parser_env ->
    Obj.repr(
# 798 "src/kernel_internals/parsing/cparser.mly"
                             ( () )
# 4051 "src/kernel_internals/parsing/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 800 "src/kernel_internals/parsing/cparser.mly"
                                 ( () )
# 4057 "src/kernel_internals/parsing/cparser.ml"
               : 'eq_opt))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 803 "src/kernel_internals/parsing/cparser.mly"
                                                 ( INFIELD_INIT(_2, _3) )
# 4065 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 804 "src/kernel_internals/parsing/cparser.mly"
                                                       ( ATINDEX_INIT(_2, _4) )
# 4073 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 806 "src/kernel_internals/parsing/cparser.mly"
        ( ATINDEXRANGE_INIT(_2, _4) )
# 4081 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    Obj.repr(
# 809 "src/kernel_internals/parsing/cparser.mly"
                                        ( NEXT_INIT )
# 4087 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.initwhat) in
    Obj.repr(
# 810 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 4094 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.initwhat))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename) in
    Obj.repr(
# 814 "src/kernel_internals/parsing/cparser.mly"
                                        ( INFIELD_INIT(_1, NEXT_INIT) )
# 4101 "src/kernel_internals/parsing/cparser.ml"
               : 'gcc_init_designators))
; (fun __caml_parser_env ->
    Obj.repr(
# 818 "src/kernel_internals/parsing/cparser.mly"
                                    ( [] )
# 4107 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 819 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 4114 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 823 "src/kernel_internals/parsing/cparser.mly"
                     (make_expr NOTHING)
# 4120 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 824 "src/kernel_internals/parsing/cparser.mly"
                           (smooth_expression _1 )
# 4127 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 828 "src/kernel_internals/parsing/cparser.mly"
                                           ( [_1] )
# 4134 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 829 "src/kernel_internals/parsing/cparser.mly"
                                                  ( _1 :: _3 )
# 4142 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    Obj.repr(
# 833 "src/kernel_internals/parsing/cparser.mly"
                                    ( make_expr NOTHING )
# 4148 "src/kernel_internals/parsing/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 834 "src/kernel_internals/parsing/cparser.mly"
                                    ( smooth_expression _1 )
# 4155 "src/kernel_internals/parsing/cparser.ml"
               : 'comma_expression_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 838 "src/kernel_internals/parsing/cparser.mly"
                                                   ( _2 )
# 4163 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    Obj.repr(
# 842 "src/kernel_internals/parsing/cparser.mly"
                                                       ( _2 )
# 4170 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.expression list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'block_begin) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'block_attrs) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.statement list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 849 "src/kernel_internals/parsing/cparser.mly"
      (!Lexerhack.pop_context();
       { blabels = _2;
         battrs = _3;
         bstmts = _4 },
       _1, _5
      )
# 4186 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.block * cabsloc * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 857 "src/kernel_internals/parsing/cparser.mly"
            ( !Lexerhack.push_context (); _1 )
# 4193 "src/kernel_internals/parsing/cparser.ml"
               : 'block_begin))
; (fun __caml_parser_env ->
    Obj.repr(
# 861 "src/kernel_internals/parsing/cparser.mly"
                                                            ( [] )
# 4199 "src/kernel_internals/parsing/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 863 "src/kernel_internals/parsing/cparser.mly"
                                        ( [("__blockattribute__", _2)] )
# 4206 "src/kernel_internals/parsing/cparser.ml"
               : 'block_attrs))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 868 "src/kernel_internals/parsing/cparser.mly"
                                                        ( _1 )
# 4213 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.definition) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 870 "src/kernel_internals/parsing/cparser.mly"
        ( _1 @ no_ghost_stmt (DEFINITION(_2)) :: _3 )
# 4222 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'statement) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 872 "src/kernel_internals/parsing/cparser.mly"
            ( _1 @ _2 @ _3 )
# 4231 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.statement list) in
    Obj.repr(
# 873 "src/kernel_internals/parsing/cparser.mly"
                                                        ( _1 @ _3 )
# 4240 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'annot_list_opt) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    Obj.repr(
# 876 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Parsing.rhs_start_pos 2, Parsing.rhs_end_pos 3 in
      _1 @ no_ghost [LABEL (_2, no_ghost_stmt (NOP loc), loc)] )
# 4249 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.statement list))
; (fun __caml_parser_env ->
    Obj.repr(
# 881 "src/kernel_internals/parsing/cparser.mly"
                    ( [] )
# 4255 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list) in
    Obj.repr(
# 882 "src/kernel_internals/parsing/cparser.mly"
                    ( _1 )
# 4262 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Logic_ptree.code_annot * Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 886 "src/kernel_internals/parsing/cparser.mly"
                             ( no_ghost [Cabs.CODE_ANNOT _1] @ _2)
# 4270 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.statement list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annot_list_opt) in
    Obj.repr(
# 888 "src/kernel_internals/parsing/cparser.mly"
       ( (in_ghost _2) @ _4 )
# 4278 "src/kernel_internals/parsing/cparser.ml"
               : 'annot_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 892 "src/kernel_internals/parsing/cparser.mly"
                                                     ( [] )
# 4284 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 893 "src/kernel_internals/parsing/cparser.mly"
                                                     ( _2 @ _4 )
# 4293 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename_as_id) in
    Obj.repr(
# 896 "src/kernel_internals/parsing/cparser.mly"
                                                     ( [ _1 ] )
# 4300 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 897 "src/kernel_internals/parsing/cparser.mly"
                                                     ( _1 :: _3 )
# 4308 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 902 "src/kernel_internals/parsing/cparser.mly"
              ( _1 )
# 4315 "src/kernel_internals/parsing/cparser.ml"
               : 'annotated_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'annot_list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'statement) in
    Obj.repr(
# 903 "src/kernel_internals/parsing/cparser.mly"
                         ( _1 @ _2 )
# 4323 "src/kernel_internals/parsing/cparser.ml"
               : 'annotated_statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 907 "src/kernel_internals/parsing/cparser.mly"
               ( no_ghost [NOP _1] )
# 4330 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Lexing.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 909 "src/kernel_internals/parsing/cparser.mly"
      (
        let bs = _2 in
        try
          let (loc',spec) = Logic_lexer.spec _1 in
          let spec = no_ghost [Cabs.CODE_SPEC (spec, (fst _1, loc'))] in
          spec @ _2
        with exn when Kernel.ContinueOnAnnotError.get () ->
          Kernel.debug ~source:(fst _1) "skipping annotation: %s"
            (Printexc.to_string exn);
          bs
      )
# 4348 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 921 "src/kernel_internals/parsing/cparser.mly"
   ( let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
            no_ghost [COMPUTATION (smooth_expression _1,loc)])
# 4357 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 923 "src/kernel_internals/parsing/cparser.mly"
          ( let (x,y,z) = _1 in no_ghost [BLOCK (x, y, z)])
# 4364 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 925 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
          no_ghost [IF (smooth_expression _2,
                       in_block _3, no_ghost_stmt (NOP loc), loc)])
# 4375 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : 'annotated_statement) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 929 "src/kernel_internals/parsing/cparser.mly"
 ( let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
          no_ghost
            [IF (smooth_expression _2, in_block _3, in_block _5, loc)])
# 4387 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 933 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
          no_ghost [SWITCH (smooth_expression _2, in_block _3, loc)])
# 4397 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 937 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Parsing.rhs_start_pos 2, Parsing.symbol_end_pos () in
      no_ghost [WHILE (_1, smooth_expression _3, in_block _4, loc)] )
# 4408 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'annotated_statement) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 941 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Parsing.rhs_start_pos 2, Parsing.symbol_end_pos () in
      no_ghost [DOWHILE (_1, smooth_expression _5, in_block _3, loc)])
# 4421 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 8 : 'opt_loop_annotations) in
    let _2 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 5 : 'for_clause) in
    let _5 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _7 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _9 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 946 "src/kernel_internals/parsing/cparser.mly"
    ( let loc = Parsing.rhs_start_pos 2, Parsing.symbol_end_pos () in
      no_ghost [FOR (_1, _4, _5, _7, in_block _9, loc)])
# 4436 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv_list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 949 "src/kernel_internals/parsing/cparser.mly"
 ((* The only attribute that should appear here
            is "unused". For now, we drop this on the
            floor, since unused labels are usually
            removed anyways by Rmtmps. *)
          let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 2 in
          no_ghost [LABEL (_1, in_block _4, loc)])
# 4450 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 956 "src/kernel_internals/parsing/cparser.mly"
     ( let loc = Parsing.symbol_start_pos (), Parsing.rhs_end_pos 3 in
              no_ghost [CASE (_2, in_block _4, loc)])
# 4460 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.expression) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 959 "src/kernel_internals/parsing/cparser.mly"
     ( let loc = Parsing.symbol_start_pos (), Parsing.rhs_end_pos 5 in
              no_ghost [CASERANGE (_2, _4, in_block _6, loc)])
# 4471 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'annotated_statement) in
    Obj.repr(
# 962 "src/kernel_internals/parsing/cparser.mly"
        ( let loc = Parsing.symbol_start_pos(), Parsing.symbol_end_pos () in
              no_ghost [DEFAULT (in_block _3, loc)])
# 4480 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 964 "src/kernel_internals/parsing/cparser.mly"
                     (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [RETURN ({ expr_loc = loc; expr_node = NOTHING}, loc)]
    )
# 4491 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 968 "src/kernel_internals/parsing/cparser.mly"
                                      (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [RETURN (smooth_expression _2, loc)]
    )
# 4503 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 972 "src/kernel_internals/parsing/cparser.mly"
                        (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [BREAK loc]
    )
# 4514 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 976 "src/kernel_internals/parsing/cparser.mly"
                        (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [CONTINUE loc]
    )
# 4525 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 980 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [GOTO (_2, loc)]
    )
# 4537 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 984 "src/kernel_internals/parsing/cparser.mly"
                                         (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [COMPGOTO (smooth_expression _3, loc) ]
    )
# 4550 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 7 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _4 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _6 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _8 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 988 "src/kernel_internals/parsing/cparser.mly"
                                                                    (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [ASM (_3, _5, _6, loc)]
    )
# 4566 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : 'asmtemplate) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : 'asmoutputs) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 992 "src/kernel_internals/parsing/cparser.mly"
                                                               (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      no_ghost [ASM (_2, _4, _5, loc)]
    )
# 4581 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 996 "src/kernel_internals/parsing/cparser.mly"
            ( no_ghost [ASM ([], [fst _1], None, snd _1)])
# 4588 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 997 "src/kernel_internals/parsing/cparser.mly"
                                                  (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      let loc_e = Parsing.rhs_start_pos 4, Parsing.rhs_end_pos 4 in
      let b, _, _ = _2 in
      let h, _, _ = _5 in
      if not !Cprint.msvcMode then
        Errorloc.parse_error "try/except in GCC code";
      no_ghost
        [TRY_EXCEPT (b, {expr_loc = loc_e; expr_node = COMMA _4}, h, loc)]
    )
# 4608 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.block * cabsloc * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1007 "src/kernel_internals/parsing/cparser.mly"
                            (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos () in
      let b, _, _ = _2 in
      let h, _, _ = _4 in
      if not !Cprint.msvcMode then
        Errorloc.parse_error "try/finally in GCC code";
      no_ghost [TRY_FINALLY (b, h, loc)]
    )
# 4625 "src/kernel_internals/parsing/cparser.ml"
               : 'statement))
; (fun __caml_parser_env ->
    Obj.repr(
# 1018 "src/kernel_internals/parsing/cparser.mly"
                ( [] )
# 4631 "src/kernel_internals/parsing/cparser.ml"
               : 'opt_loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annotations) in
    Obj.repr(
# 1019 "src/kernel_internals/parsing/cparser.mly"
                   ( _1 )
# 4638 "src/kernel_internals/parsing/cparser.ml"
               : 'opt_loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'loop_annotation) in
    Obj.repr(
# 1023 "src/kernel_internals/parsing/cparser.mly"
                  ( _1 )
# 4645 "src/kernel_internals/parsing/cparser.ml"
               : 'loop_annotations))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Logic_ptree.code_annot list * Cabs.cabsloc) in
    Obj.repr(
# 1035 "src/kernel_internals/parsing/cparser.mly"
               ( fst _1 )
# 4652 "src/kernel_internals/parsing/cparser.ml"
               : 'loop_annotation))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1039 "src/kernel_internals/parsing/cparser.mly"
                                 ( FC_EXP _1 )
# 4660 "src/kernel_internals/parsing/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.definition) in
    Obj.repr(
# 1040 "src/kernel_internals/parsing/cparser.mly"
                                 ( FC_DECL _1 )
# 4667 "src/kernel_internals/parsing/cparser.ml"
               : 'for_clause))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1045 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration None ((snd _1)) (fst _1) _2 )
# 4676 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1047 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration None ((snd _1)) (fst _1) [] )
# 4684 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Lexing.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.init_name list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1049 "src/kernel_internals/parsing/cparser.mly"
          ( doDeclaration (Some _1) ((snd _2)) (fst _2) _3 )
# 4694 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexing.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1051 "src/kernel_internals/parsing/cparser.mly"
      ( doDeclaration (Some _1) ((snd _2)) (fst _2) [] )
# 4703 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name) in
    Obj.repr(
# 1055 "src/kernel_internals/parsing/cparser.mly"
                                                 ( [_1] )
# 4710 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.init_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_name list) in
    Obj.repr(
# 1056 "src/kernel_internals/parsing/cparser.mly"
                                                 ( _1 :: _3 )
# 4718 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1060 "src/kernel_internals/parsing/cparser.mly"
                                        ( (_1, NO_INIT) )
# 4725 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.init_expression) in
    Obj.repr(
# 1062 "src/kernel_internals/parsing/cparser.mly"
                                        ( (_1, _3) )
# 4733 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.init_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1067 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecTypedef, _1  )
# 4740 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1068 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage EXTERN, _1 )
# 4747 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1069 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage STATIC, _1 )
# 4754 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1070 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage AUTO, _1 )
# 4761 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1071 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecStorage REGISTER, _1)
# 4768 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1073 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecInline, _1 )
# 4775 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.spec_elem * cabsloc) in
    Obj.repr(
# 1074 "src/kernel_internals/parsing/cparser.mly"
                     ( _1 )
# 4782 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1075 "src/kernel_internals/parsing/cparser.mly"
                     ( SpecAttr (fst _1), snd _1 )
# 4789 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_wo_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl_spec_wo_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt) in
    Obj.repr(
# 1079 "src/kernel_internals/parsing/cparser.mly"
                                       ( fst _1 :: _2, snd _1 )
# 4797 "src/kernel_internals/parsing/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1080 "src/kernel_internals/parsing/cparser.mly"
                                        ( SpecType(fst _1) :: _2, snd _1 )
# 4805 "src/kernel_internals/parsing/cparser.ml"
               : spec_elem list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'decl_spec_wo_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1083 "src/kernel_internals/parsing/cparser.mly"
                                                ( fst _1 :: _2, snd _1 )
# 4813 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : typeSpecifier * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_opt_no_named) in
    Obj.repr(
# 1084 "src/kernel_internals/parsing/cparser.mly"
                                        ( SpecType(fst _1) :: _2, snd _1 )
# 4821 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_no_named))
; (fun __caml_parser_env ->
    Obj.repr(
# 1089 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 4827 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1090 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 )
# 4834 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt))
; (fun __caml_parser_env ->
    Obj.repr(
# 1097 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 4840 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'decl_spec_list_no_named) in
    Obj.repr(
# 1098 "src/kernel_internals/parsing/cparser.mly"
                                                 ( fst _1 )
# 4847 "src/kernel_internals/parsing/cparser.ml"
               : 'decl_spec_list_opt_no_named))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1101 "src/kernel_internals/parsing/cparser.mly"
                    ( Tvoid, _1)
# 4854 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1102 "src/kernel_internals/parsing/cparser.mly"
                    ( Tchar, _1 )
# 4861 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1103 "src/kernel_internals/parsing/cparser.mly"
                    ( Tbool, _1 )
# 4868 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1104 "src/kernel_internals/parsing/cparser.mly"
                    ( Tshort, _1 )
# 4875 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1105 "src/kernel_internals/parsing/cparser.mly"
                    ( Tint, _1 )
# 4882 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1106 "src/kernel_internals/parsing/cparser.mly"
                    ( Tlong, _1 )
# 4889 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1107 "src/kernel_internals/parsing/cparser.mly"
                    ( Tint64, _1 )
# 4896 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1108 "src/kernel_internals/parsing/cparser.mly"
                    ( Tfloat, _1 )
# 4903 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1109 "src/kernel_internals/parsing/cparser.mly"
                    ( Tdouble, _1 )
# 4910 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1110 "src/kernel_internals/parsing/cparser.mly"
                    ( Tsigned, _1 )
# 4917 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1111 "src/kernel_internals/parsing/cparser.mly"
                    ( Tunsigned, _1 )
# 4924 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1113 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_2, None,    []), _1 )
# 4932 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1115 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_3, None,    _2), _1 )
# 4941 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1117 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_2, Some _4, []), _1 )
# 4952 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1119 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct ("", Some _3, []), _1 )
# 4962 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1121 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct (_3, Some _5, _2), _1 )
# 4974 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1123 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tstruct ("", Some _4, _2), _1 )
# 4985 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1125 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_2, None,    []), _1 )
# 4993 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1127 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_2, Some _4, []), _1 )
# 5004 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1129 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  ("", Some _3, []), _1 )
# 5014 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1131 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  (_3, Some _5, _2), _1 )
# 5026 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.field_group list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1133 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tunion  ("", Some _4, _2), _1 )
# 5037 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1135 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_2, None,    []), _1 )
# 5045 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1137 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_2, Some _4, []), _1 )
# 5057 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1139 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   ("", Some _3, []), _1 )
# 5068 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 6 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 5 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 4 : 'id_or_typename) in
    let _4 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _6 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _7 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1141 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   (_3, Some _5, _2), _1 )
# 5081 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 4 : 'just_attributes) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _5 = (Parsing.peek_val __caml_parser_env 1 : 'maybecomma) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1143 "src/kernel_internals/parsing/cparser.mly"
                                                   ( Tenum   ("", Some _4, _2), _1 )
# 5093 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1144 "src/kernel_internals/parsing/cparser.mly"
                    (
      (Tnamed _1, (Parsing.symbol_start_pos (), Parsing.symbol_end_pos()))
      )
# 5102 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1147 "src/kernel_internals/parsing/cparser.mly"
                                        ( TtypeofE _3, _1 )
# 5111 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1148 "src/kernel_internals/parsing/cparser.mly"
                                        ( let s, d = _3 in
                                          TtypeofT (s, d), _1 )
# 5121 "src/kernel_internals/parsing/cparser.ml"
               : typeSpecifier * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1154 "src/kernel_internals/parsing/cparser.mly"
                                         ( [] )
# 5127 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1156 "src/kernel_internals/parsing/cparser.mly"
                                         ( FIELD (fst _1,
                                            [(missingFieldDecl, None)]) :: _3 )
# 5137 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1160 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 5145 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : (Cabs.name * expression option) list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1162 "src/kernel_internals/parsing/cparser.mly"
                                          ( FIELD (fst _1, _2)
                                            :: _4 )
# 5156 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'pragma) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.field_group list) in
    Obj.repr(
# 1165 "src/kernel_internals/parsing/cparser.mly"
                                          ( _2 )
# 5164 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.field_group list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name * expression option) in
    Obj.repr(
# 1169 "src/kernel_internals/parsing/cparser.mly"
                                         ( [_1] )
# 5171 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name * expression option) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : (Cabs.name * expression option) list) in
    Obj.repr(
# 1170 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 :: _3 )
# 5179 "src/kernel_internals/parsing/cparser.ml"
               : (Cabs.name * expression option) list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1173 "src/kernel_internals/parsing/cparser.mly"
                                    ( (_1, None) )
# 5186 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1175 "src/kernel_internals/parsing/cparser.mly"
                                    ( let (n,decl,al,loc) = _1 in
                                      let al' = al @ _4 in
                                     ((n,decl,al',loc), Some _3) )
# 5197 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 1178 "src/kernel_internals/parsing/cparser.mly"
                                    ( (missingFieldDecl, Some _2) )
# 5204 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name * expression option))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1182 "src/kernel_internals/parsing/cparser.mly"
                  ([_1])
# 5211 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.enum_item list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.enum_item) in
    Obj.repr(
# 1183 "src/kernel_internals/parsing/cparser.mly"
                                       (_1 @ [_3])
# 5219 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1186 "src/kernel_internals/parsing/cparser.mly"
            (
      let loc = Parsing.symbol_start_pos (), Parsing.symbol_end_pos() in
      (_1, { expr_node = NOTHING; expr_loc = loc }, loc)
    )
# 5229 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression) in
    Obj.repr(
# 1190 "src/kernel_internals/parsing/cparser.mly"
                         (
      (_1, _3, (Parsing.symbol_start_pos (),Parsing.symbol_end_pos()))
    )
# 5239 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.enum_item))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1197 "src/kernel_internals/parsing/cparser.mly"
                                               (
     let (n, decl) = _2 in (n, applyPointer (fst _1) decl, _3, (snd _1))
   )
# 5250 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'comma_expression_opt) in
    Obj.repr(
# 1204 "src/kernel_internals/parsing/cparser.mly"
                                  ( _1,_2 )
# 5258 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 1205 "src/kernel_internals/parsing/cparser.mly"
                                               (
    fst _1::_2  @ ["static",[]], smooth_expression _4
  )
# 5270 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.expression list) in
    Obj.repr(
# 1208 "src/kernel_internals/parsing/cparser.mly"
                                     (
    ("static",[]) :: _2, smooth_expression _3
  )
# 5281 "src/kernel_internals/parsing/cparser.ml"
               : 'attributes_or_static))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1216 "src/kernel_internals/parsing/cparser.mly"
                                   ( (_1, JUSTBASE) )
# 5288 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.name) in
    Obj.repr(
# 1219 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n,decl,al,_) = _3 in
                                     (n, PARENTYPE(_2,decl,al)) )
# 5298 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attributes_or_static) in
    Obj.repr(
# 1223 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (attrs, size) = _3 in
                                     (n, ARRAY(decl, attrs, size)) )
# 5308 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1226 "src/kernel_internals/parsing/cparser.mly"
                              (
   let (n,decl) = _1 in (n, PROTO(decl,[],false))
  )
# 5318 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1230 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (n, decl) = _1 in
                                     let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     (n, PROTO(decl, params, isva))
                                   )
# 5331 "src/kernel_internals/parsing/cparser.ml"
               : string * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1237 "src/kernel_internals/parsing/cparser.mly"
                                   ( !Lexerhack.push_context () )
# 5338 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_list_startscope))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1240 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (params, isva) = _2 in
                                     (_1 :: params, isva)
                                   )
# 5348 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1245 "src/kernel_internals/parsing/cparser.mly"
                                        ( ([], false) )
# 5354 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    Obj.repr(
# 1246 "src/kernel_internals/parsing/cparser.mly"
                                        ( ([], true) )
# 5360 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'rest_par_list1) in
    Obj.repr(
# 1247 "src/kernel_internals/parsing/cparser.mly"
                                        ( let (params, isva) = _3 in
                                          (_2 :: params, isva)
                                        )
# 5370 "src/kernel_internals/parsing/cparser.ml"
               : 'rest_par_list1))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1254 "src/kernel_internals/parsing/cparser.mly"
                                          ( (fst _1, _2) )
# 5378 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1255 "src/kernel_internals/parsing/cparser.mly"
                                          ( let d, a = _2 in
                                            (fst _1, ("", d, a, (*CEA*) cabslu)) )
# 5387 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1257 "src/kernel_internals/parsing/cparser.mly"
                                          ( (fst _1, ("", JUSTBASE, [], (*CEA*) cabslu)) )
# 5394 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.single_name) in
    Obj.repr(
# 1258 "src/kernel_internals/parsing/cparser.mly"
                                          ( _2 )
# 5402 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.single_name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'direct_old_proto_decl) in
    Obj.repr(
# 1263 "src/kernel_internals/parsing/cparser.mly"
                                      ( let (n, decl, a) = _2 in
                                        (n, applyPointer (fst _1) decl,
                                         a, snd _1)
                                      )
# 5413 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string * Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1271 "src/kernel_internals/parsing/cparser.mly"
                                                                  (
    let par_decl, isva = doOldParDecl _3 _5 in
    let n, decl = _1 in
    (n, PROTO(decl, par_decl, isva), ["FC_OLDSTYLEPROTO",[]])
  )
# 5427 "src/kernel_internals/parsing/cparser.ml"
               : 'direct_old_proto_decl))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1287 "src/kernel_internals/parsing/cparser.mly"
                                               ( [_1] )
# 5434 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1288 "src/kernel_internals/parsing/cparser.mly"
                                               ( _1::_3 )
# 5442 "src/kernel_internals/parsing/cparser.ml"
               : string list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1292 "src/kernel_internals/parsing/cparser.mly"
                                          ( ([], false) )
# 5448 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1294 "src/kernel_internals/parsing/cparser.mly"
                                          ( ([(fst _1, _2)], true) )
# 5457 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'old_pardef) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1296 "src/kernel_internals/parsing/cparser.mly"
                                          ( let rest, isva = _4 in
                                            ((fst _1, _2) :: rest, isva)
                                          )
# 5469 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1302 "src/kernel_internals/parsing/cparser.mly"
                                          ( [_1] )
# 5476 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef) in
    Obj.repr(
# 1303 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 :: _3 )
# 5484 "src/kernel_internals/parsing/cparser.ml"
               : 'old_pardef))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1308 "src/kernel_internals/parsing/cparser.mly"
                                ( _2 :: fst _3, _1 )
# 5493 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1311 "src/kernel_internals/parsing/cparser.mly"
                                 ( let l = Errorloc.currentLoc () in
                                   ([], l) )
# 5500 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1313 "src/kernel_internals/parsing/cparser.mly"
                                 ( _1 )
# 5507 "src/kernel_internals/parsing/cparser.ml"
               : attribute list list * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1317 "src/kernel_internals/parsing/cparser.mly"
                               ( let d, a = _2 in
                                 if a <> [] then
                                   Errorloc.parse_error
                                     "attributes in type name";
                                 (fst _1, d)
                               )
# 5520 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : spec_elem list * cabsloc) in
    Obj.repr(
# 1323 "src/kernel_internals/parsing/cparser.mly"
                               ( (fst _1, JUSTBASE) )
# 5527 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem list * Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : attribute list list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1326 "src/kernel_internals/parsing/cparser.mly"
                                          ( applyPointer (fst _1) _2, _3 )
# 5536 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : attribute list list * cabsloc) in
    Obj.repr(
# 1327 "src/kernel_internals/parsing/cparser.mly"
                                          ( applyPointer (fst _1) JUSTBASE, [] )
# 5543 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type * Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.attribute list) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.decl_type * Cabs.attribute list) in
    Obj.repr(
# 1334 "src/kernel_internals/parsing/cparser.mly"
                                   ( let d, a = _3 in
                                     PARENTYPE (_2, d, a)
                                   )
# 5554 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'comma_expression_opt) in
    Obj.repr(
# 1339 "src/kernel_internals/parsing/cparser.mly"
                                   ( ARRAY(_1, [], _3) )
# 5562 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1342 "src/kernel_internals/parsing/cparser.mly"
                                   ( let (params, isva) = _3 in
                                     !Lexerhack.pop_context ();
                                     PROTO (_1, params, isva)
                                   )
# 5574 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.decl_type) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1346 "src/kernel_internals/parsing/cparser.mly"
                                ( PROTO (_1, [], false) )
# 5582 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.decl_type) in
    Obj.repr(
# 1350 "src/kernel_internals/parsing/cparser.mly"
                                    ( _1 )
# 5589 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    Obj.repr(
# 1351 "src/kernel_internals/parsing/cparser.mly"
                                    ( JUSTBASE )
# 5595 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.decl_type))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Lexing.position * string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1355 "src/kernel_internals/parsing/cparser.mly"
          (
            let (loc, specs, decl) = _2 in
            let spec_loc =
              try
                let loc = fst _1 in
                let loc', spec = Logic_lexer.spec _1 in
                Some (spec, (loc, loc'))
              with exn when Kernel.ContinueOnAnnotError.get () ->
                Kernel.debug ~source:(fst _1)
                  "Ignoring specification of function %s: %s"
                  !currentFunctionName (Printexc.to_string exn);
                None
            in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by
                                    * announceFunctionName *)
            doFunctionDef spec_loc loc (trd3 _3) specs decl (fst3 _3)
          )
# 5621 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : cabsloc * spec_elem list * name) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.block * cabsloc * cabsloc) in
    Obj.repr(
# 1374 "src/kernel_internals/parsing/cparser.mly"
          ( let (loc, specs, decl) = _1 in
            currentFunctionName := "<__FUNCTION__ used outside any functions>";
            !Lexerhack.pop_context (); (* The context pushed by
                                    * announceFunctionName *)
            (*OCAMLYACC BUG??? Format.printf "%a@." d_cabsloc (trd3 $2);*)
            doFunctionDef None ((*handleLoc*) loc) (trd3 _2) specs decl (fst3 _2)
          )
# 5635 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.definition))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1385 "src/kernel_internals/parsing/cparser.mly"
                            ( announceFunctionName _2;
                              (fourth4 _2, fst _1, _2)
                            )
# 5645 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : spec_elem list * cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.name) in
    Obj.repr(
# 1391 "src/kernel_internals/parsing/cparser.mly"
                            ( announceFunctionName _2;
                              (snd _1, fst _1, _2)
                            )
# 5655 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'parameter_list_startscope) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'rest_par_list) in
    Obj.repr(
# 1396 "src/kernel_internals/parsing/cparser.mly"
    ( let (params, isva) = _3 in
      let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
      let fdec =
        (_1, PROTO(JUSTBASE, params, isva), [], loc) in
      announceFunctionName fdec;
      (* Default is int type *)
      let defSpec = [SpecType Tint] in (loc, defSpec, fdec)
    )
# 5671 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string list) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : 'old_pardef_list) in
    Obj.repr(
# 1407 "src/kernel_internals/parsing/cparser.mly"
    ( (* Convert pardecl to new style *)
      let pardecl, isva = doOldParDecl _3 _5 in
      let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
      (* Make the function declarator *)
      let fdec = (_1, PROTO(JUSTBASE, pardecl,isva), [], loc) in
      announceFunctionName fdec;
      (* Default is int type *)
      (loc, [SpecType Tint], fdec)
    )
# 5689 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1417 "src/kernel_internals/parsing/cparser.mly"
  (
    let loc = Parsing.rhs_start_pos 1, Parsing.rhs_start_pos 1 in
    let fdec = (_1, PROTO(JUSTBASE,[],false),[],loc) in
    announceFunctionName fdec;
    (loc, [SpecType Tint], fdec)
  )
# 5702 "src/kernel_internals/parsing/cparser.ml"
               : cabsloc * spec_elem list * name))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1427 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_CONST), _1 )
# 5709 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1428 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_VOLATILE), _1 )
# 5716 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1429 "src/kernel_internals/parsing/cparser.mly"
                             ( SpecCV(CV_RESTRICT), _1 )
# 5723 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1430 "src/kernel_internals/parsing/cparser.mly"
                             ( let annot, loc = _1 in
			       SpecCV(CV_ATTRIBUTE_ANNOT annot), loc )
# 5731 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.spec_elem * cabsloc))
; (fun __caml_parser_env ->
    Obj.repr(
# 1436 "src/kernel_internals/parsing/cparser.mly"
                   ( [])
# 5737 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1437 "src/kernel_internals/parsing/cparser.mly"
                                 ( fst _1 :: _2 )
# 5745 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1443 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 5751 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1444 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 :: _2 )
# 5759 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : string * cabsloc) in
    let _5 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1445 "src/kernel_internals/parsing/cparser.mly"
                                                 (
      let loc = Parsing.rhs_start_pos 3, Parsing.rhs_end_pos 3 in
      ("__asm__",
       [{ expr_node = CONSTANT(CONST_STRING (fst _3)); expr_loc = loc}])
      :: _5
    )
# 5774 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1456 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__attribute__", _3), _1 )
# 5783 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1457 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__declspec", _2), _1 )
# 5791 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1458 "src/kernel_internals/parsing/cparser.mly"
                                        ( (fst _1, []), snd _1 )
# 5798 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1460 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__thread",[]), _1 )
# 5805 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv))
; (fun __caml_parser_env ->
    Obj.repr(
# 1464 "src/kernel_internals/parsing/cparser.mly"
                   ( [])
# 5811 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'attribute_nocv) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv_list) in
    Obj.repr(
# 1465 "src/kernel_internals/parsing/cparser.mly"
                                        ( fst _1 :: _2 )
# 5819 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute_nocv_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attribute_nocv) in
    Obj.repr(
# 1470 "src/kernel_internals/parsing/cparser.mly"
                          ( _1 )
# 5826 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1471 "src/kernel_internals/parsing/cparser.mly"
                          ( ("const", []), _1 )
# 5833 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1472 "src/kernel_internals/parsing/cparser.mly"
                          ( ("restrict",[]), _1 )
# 5840 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1473 "src/kernel_internals/parsing/cparser.mly"
                          ( ("volatile",[]), _1 )
# 5847 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1474 "src/kernel_internals/parsing/cparser.mly"
                          ( let annot, loc = _1 in
			    ("$annot:" ^ annot, []), loc )
# 5855 "src/kernel_internals/parsing/cparser.ml"
               : 'attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'paren_attr_list) in
    Obj.repr(
# 1483 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__attribute__", _3) )
# 5864 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1484 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("__declspec", _2) )
# 5872 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attribute))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'just_attribute) in
    Obj.repr(
# 1490 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 5879 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'just_attribute) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'just_attributes) in
    Obj.repr(
# 1491 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 :: _2 )
# 5887 "src/kernel_internals/parsing/cparser.ml"
               : 'just_attributes))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1496 "src/kernel_internals/parsing/cparser.mly"
                             (
    PRAGMA (make_expr (VARIABLE ("")), _1)
  )
# 5896 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1499 "src/kernel_internals/parsing/cparser.mly"
                          ( PRAGMA (_2, _1) )
# 5904 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1500 "src/kernel_internals/parsing/cparser.mly"
                                   ( PRAGMA (_2, _1) )
# 5913 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1501 "src/kernel_internals/parsing/cparser.mly"
                                        (
    PRAGMA (make_expr (VARIABLE (fst _1)), snd _1)
  )
# 5922 "src/kernel_internals/parsing/cparser.ml"
               : 'pragma))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1509 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (VARIABLE _1) )
# 5929 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string) in
    Obj.repr(
# 1510 "src/kernel_internals/parsing/cparser.mly"
               ( make_expr (VARIABLE _1) )
# 5936 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1511 "src/kernel_internals/parsing/cparser.mly"
                          ( make_expr (VARIABLE ("default:" ^ fst _3)) )
# 5944 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1513 "src/kernel_internals/parsing/cparser.mly"
          ( make_expr (VARIABLE "aconst") )
# 5951 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : Cabs.cabsloc) in
    Obj.repr(
# 1515 "src/kernel_internals/parsing/cparser.mly"
             ( make_expr (VARIABLE ("__noreturn__")) )
# 5958 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : string * Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1516 "src/kernel_internals/parsing/cparser.mly"
                               ( make_expr (VARIABLE (fst _1 ^ ":" ^ fst _3)) )
# 5966 "src/kernel_internals/parsing/cparser.ml"
               : 'var_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * Cabs.cabsloc) in
    Obj.repr(
# 1520 "src/kernel_internals/parsing/cparser.mly"
            ( make_expr (CONSTANT(CONST_INT (fst _1))) )
# 5973 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'var_attr) in
    Obj.repr(
# 1521 "src/kernel_internals/parsing/cparser.mly"
             ( _1 )
# 5980 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr) in
    Obj.repr(
# 1524 "src/kernel_internals/parsing/cparser.mly"
                  ( [_1] )
# 5987 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr_list_ne) in
    Obj.repr(
# 1525 "src/kernel_internals/parsing/cparser.mly"
                                  ( _1::_2 )
# 5995 "src/kernel_internals/parsing/cparser.ml"
               : 'basic_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr_list_ne) in
    Obj.repr(
# 1529 "src/kernel_internals/parsing/cparser.mly"
                         ( _1 )
# 6002 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr_list_ne) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1530 "src/kernel_internals/parsing/cparser.mly"
                                       (
      _1 @ [make_expr (CONSTANT(CONST_STRING (fst _2)))]
    )
# 6012 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'basic_attr_list_ne) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_attr_list_ne) in
    Obj.repr(
# 1533 "src/kernel_internals/parsing/cparser.mly"
                                                              (
      _1 @ ([make_expr (CONSTANT(CONST_STRING (fst _2)))] @ _3)
    )
# 6023 "src/kernel_internals/parsing/cparser.ml"
               : 'parameter_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'parameter_attr_list_ne) in
    Obj.repr(
# 1538 "src/kernel_internals/parsing/cparser.mly"
                           ( _1 )
# 6030 "src/kernel_internals/parsing/cparser.ml"
               : 'param_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1539 "src/kernel_internals/parsing/cparser.mly"
                    ( [make_expr (CONSTANT(CONST_STRING (fst _1)))] )
# 6037 "src/kernel_internals/parsing/cparser.ml"
               : 'param_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'basic_attr) in
    Obj.repr(
# 1542 "src/kernel_internals/parsing/cparser.mly"
               ( _1 )
# 6044 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1543 "src/kernel_internals/parsing/cparser.mly"
                       ( _2 )
# 6052 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : string * cabsloc) in
    Obj.repr(
# 1544 "src/kernel_internals/parsing/cparser.mly"
                    ( make_expr (CONSTANT(CONST_STRING (fst _1))) )
# 6059 "src/kernel_internals/parsing/cparser.ml"
               : 'primary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'primary_attr) in
    Obj.repr(
# 1547 "src/kernel_internals/parsing/cparser.mly"
                 ( _1 )
# 6066 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'id_or_typename_as_id) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'paren_attr_list_ne) in
    Obj.repr(
# 1548 "src/kernel_internals/parsing/cparser.mly"
                                            (
        let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
        make_expr (CALL({ expr_loc = loc; expr_node = VARIABLE _1}, _2)) )
# 6076 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'id_or_typename_as_id) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    Obj.repr(
# 1552 "src/kernel_internals/parsing/cparser.mly"
                                        (
      let loc1 = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
      let loc2 = Parsing.rhs_start_pos 2, Parsing.rhs_end_pos 3 in
      let f = { expr_node = VARIABLE _1; expr_loc = loc1 } in
      let arg = { expr_node = VARIABLE ""; expr_loc = loc2 } in
      make_expr (CALL(f, [arg]))
    )
# 6090 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'basic_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'param_attr_list_ne) in
    Obj.repr(
# 1561 "src/kernel_internals/parsing/cparser.mly"
                                   (
      let loc = Parsing.rhs_start_pos 1, Parsing.rhs_end_pos 1 in
      make_expr (CALL({ expr_node = VARIABLE ""; expr_loc = loc}, _1::_2)) )
# 6100 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1565 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROFPTR (_1, _3)))
# 6108 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'id_or_typename) in
    Obj.repr(
# 1566 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (MEMBEROF (_1, _3)) )
# 6116 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : 'postfix_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : 'attr) in
    Obj.repr(
# 1567 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (INDEX (_1, _3)) )
# 6124 "src/kernel_internals/parsing/cparser.ml"
               : 'postfix_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'postfix_attr) in
    Obj.repr(
# 1574 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6131 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1575 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (EXPR_SIZEOF _2) )
# 6139 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1577 "src/kernel_internals/parsing/cparser.mly"
                          (let b, d = _3 in
                                         make_expr (TYPE_SIZEOF (b, d)) )
# 6149 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'unary_expression) in
    Obj.repr(
# 1580 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (EXPR_ALIGNOF _2) )
# 6157 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 3 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 1 : Cabs.spec_elem list * Cabs.decl_type) in
    Obj.repr(
# 1581 "src/kernel_internals/parsing/cparser.mly"
                                        (let b, d = _3 in
                                         make_expr (TYPE_ALIGNOF (b, d)) )
# 6167 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1583 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (UNARY (PLUS, _2)))
# 6175 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1584 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (UNARY (MINUS, _2)) )
# 6183 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1585 "src/kernel_internals/parsing/cparser.mly"
                            (make_expr (UNARY (MEMOF, _2)) )
# 6191 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1587 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (ADDROF, _2)) )
# 6199 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1588 "src/kernel_internals/parsing/cparser.mly"
                                 ( make_expr (UNARY (NOT, _2)) )
# 6207 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1589 "src/kernel_internals/parsing/cparser.mly"
                                        ( make_expr (UNARY (BNOT, _2)) )
# 6215 "src/kernel_internals/parsing/cparser.ml"
               : 'unary_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'unary_attr) in
    Obj.repr(
# 1593 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6222 "src/kernel_internals/parsing/cparser.ml"
               : 'cast_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1597 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6229 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1598 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (BINARY(MUL ,_1 , _3)))
# 6238 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1599 "src/kernel_internals/parsing/cparser.mly"
                                        (make_expr (BINARY(DIV ,_1 , _3)))
# 6246 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'multiplicative_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'cast_attr) in
    Obj.repr(
# 1600 "src/kernel_internals/parsing/cparser.mly"
                                          (make_expr (BINARY(MOD ,_1 , _3)))
# 6254 "src/kernel_internals/parsing/cparser.ml"
               : 'multiplicative_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1605 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6261 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1606 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(ADD ,_1 , _3)))
# 6270 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'additive_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'multiplicative_attr) in
    Obj.repr(
# 1607 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(SUB ,_1 , _3)))
# 6279 "src/kernel_internals/parsing/cparser.ml"
               : 'additive_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1611 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6286 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1612 "src/kernel_internals/parsing/cparser.mly"
                                     (make_expr (BINARY(SHL ,_1 , _3)))
# 6294 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'shift_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'additive_attr) in
    Obj.repr(
# 1613 "src/kernel_internals/parsing/cparser.mly"
                                     (make_expr (BINARY(SHR ,_1 , _3)))
# 6302 "src/kernel_internals/parsing/cparser.ml"
               : 'shift_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1617 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6309 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1618 "src/kernel_internals/parsing/cparser.mly"
                                   (make_expr (BINARY(LT ,_1 , _3)))
# 6317 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1619 "src/kernel_internals/parsing/cparser.mly"
                                   (make_expr (BINARY(GT ,_1 , _3)))
# 6325 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1620 "src/kernel_internals/parsing/cparser.mly"
                                      (make_expr (BINARY(LE ,_1 , _3)))
# 6333 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'relational_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'shift_attr) in
    Obj.repr(
# 1621 "src/kernel_internals/parsing/cparser.mly"
                                      (make_expr (BINARY(GE ,_1 , _3)))
# 6341 "src/kernel_internals/parsing/cparser.ml"
               : 'relational_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1625 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6348 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1626 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(EQ ,_1 , _3)))
# 6356 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'equality_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'relational_attr) in
    Obj.repr(
# 1627 "src/kernel_internals/parsing/cparser.mly"
                                            (make_expr (BINARY(NE ,_1 , _3)))
# 6364 "src/kernel_internals/parsing/cparser.ml"
               : 'equality_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1632 "src/kernel_internals/parsing/cparser.mly"
                                        ( _1 )
# 6371 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'equality_attr) in
    Obj.repr(
# 1633 "src/kernel_internals/parsing/cparser.mly"
                                       (make_expr (BINARY(BAND ,_1 , _3)))
# 6380 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1637 "src/kernel_internals/parsing/cparser.mly"
                                           ( _1 )
# 6387 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_xor_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_and_attr) in
    Obj.repr(
# 1638 "src/kernel_internals/parsing/cparser.mly"
                                           (make_expr (BINARY(XOR ,_1 , _3)))
# 6395 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_xor_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1642 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 6402 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'bitwise_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_xor_attr) in
    Obj.repr(
# 1643 "src/kernel_internals/parsing/cparser.mly"
                                          (make_expr (BINARY(BOR ,_1 , _3)))
# 6410 "src/kernel_internals/parsing/cparser.ml"
               : 'bitwise_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1647 "src/kernel_internals/parsing/cparser.mly"
                                                ( _1 )
# 6417 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_and_attr) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'bitwise_or_attr) in
    Obj.repr(
# 1649 "src/kernel_internals/parsing/cparser.mly"
        (make_expr (BINARY(AND ,_1 , _3)))
# 6426 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_and_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1653 "src/kernel_internals/parsing/cparser.mly"
                                               ( _1 )
# 6433 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'logical_and_attr) in
    Obj.repr(
# 1655 "src/kernel_internals/parsing/cparser.mly"
        (make_expr (BINARY(OR ,_1 , _3)))
# 6441 "src/kernel_internals/parsing/cparser.ml"
               : 'logical_or_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'logical_or_attr) in
    Obj.repr(
# 1659 "src/kernel_internals/parsing/cparser.mly"
                                           ( _1 )
# 6448 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 5 : 'logical_or_attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 3 : 'attr_test) in
    let _4 = (Parsing.peek_val __caml_parser_env 2 : 'conditional_attr) in
    let _6 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1661 "src/kernel_internals/parsing/cparser.mly"
    ( make_expr (QUESTION(_1, _4, _6)) )
# 6458 "src/kernel_internals/parsing/cparser.ml"
               : 'conditional_attr))
; (fun __caml_parser_env ->
    Obj.repr(
# 1665 "src/kernel_internals/parsing/cparser.mly"
              ( Cabshelper.push_attr_test () )
# 6464 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_test))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'conditional_attr) in
    Obj.repr(
# 1667 "src/kernel_internals/parsing/cparser.mly"
                                          ( _1 )
# 6471 "src/kernel_internals/parsing/cparser.ml"
               : 'attr))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr) in
    Obj.repr(
# 1671 "src/kernel_internals/parsing/cparser.mly"
                                         ( [_1] )
# 6478 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'attr) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1672 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 :: _3 )
# 6486 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1675 "src/kernel_internals/parsing/cparser.mly"
                                         ( [] )
# 6492 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'attr_list_ne) in
    Obj.repr(
# 1676 "src/kernel_internals/parsing/cparser.mly"
                                         ( _1 )
# 6499 "src/kernel_internals/parsing/cparser.ml"
               : 'attr_list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list_ne) in
    Obj.repr(
# 1679 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 6507 "src/kernel_internals/parsing/cparser.ml"
               : 'paren_attr_list_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'attr_list) in
    Obj.repr(
# 1682 "src/kernel_internals/parsing/cparser.mly"
                                         ( _2 )
# 6515 "src/kernel_internals/parsing/cparser.ml"
               : 'paren_attr_list))
; (fun __caml_parser_env ->
    Obj.repr(
# 1686 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 6521 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1687 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("volatile", []) :: _2 )
# 6529 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : Cabs.cabsloc) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : Cabs.attribute list) in
    Obj.repr(
# 1688 "src/kernel_internals/parsing/cparser.mly"
                                        ( ("const", []) :: _2 )
# 6537 "src/kernel_internals/parsing/cparser.ml"
               : Cabs.attribute list))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1691 "src/kernel_internals/parsing/cparser.mly"
                                                 ( [_1] )
# 6544 "src/kernel_internals/parsing/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 1 : 'one_string_constant) in
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmtemplate) in
    Obj.repr(
# 1692 "src/kernel_internals/parsing/cparser.mly"
                                                 ( _1 :: _2 )
# 6552 "src/kernel_internals/parsing/cparser.ml"
               : 'asmtemplate))
; (fun __caml_parser_env ->
    Obj.repr(
# 1695 "src/kernel_internals/parsing/cparser.mly"
                        ( None )
# 6558 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asminputs) in
    Obj.repr(
# 1697 "src/kernel_internals/parsing/cparser.mly"
                        ( let (ins, (clobs,labels)) = _3 in
                          Some {aoutputs = _2; ainputs = ins; aclobbers = clobs;
				alabels = labels } )
# 6568 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoutputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1702 "src/kernel_internals/parsing/cparser.mly"
                                        ( [] )
# 6574 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperandsne) in
    Obj.repr(
# 1703 "src/kernel_internals/parsing/cparser.mly"
                                        ( List.rev _1 )
# 6581 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperands))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1706 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 6588 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'asmoperandsne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmoperand) in
    Obj.repr(
# 1707 "src/kernel_internals/parsing/cparser.mly"
                                        ( _3 :: _1 )
# 6596 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperandsne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 4 : 'asmopname) in
    let _2 = (Parsing.peek_val __caml_parser_env 3 : string * cabsloc) in
    let _3 = (Parsing.peek_val __caml_parser_env 2 : Cabs.cabsloc) in
    let _4 = (Parsing.peek_val __caml_parser_env 1 : Cabs.expression) in
    Obj.repr(
# 1710 "src/kernel_internals/parsing/cparser.mly"
                                                           ( (_1, fst _2, _4) )
# 6606 "src/kernel_internals/parsing/cparser.ml"
               : 'asmoperand))
; (fun __caml_parser_env ->
    Obj.repr(
# 1713 "src/kernel_internals/parsing/cparser.mly"
                        ( ([], ([],[])) )
# 6612 "src/kernel_internals/parsing/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmoperands) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmclobber) in
    Obj.repr(
# 1715 "src/kernel_internals/parsing/cparser.mly"
                        ( (_2, _3) )
# 6620 "src/kernel_internals/parsing/cparser.ml"
               : 'asminputs))
; (fun __caml_parser_env ->
    Obj.repr(
# 1718 "src/kernel_internals/parsing/cparser.mly"
                                        ( None )
# 6626 "src/kernel_internals/parsing/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : string) in
    Obj.repr(
# 1719 "src/kernel_internals/parsing/cparser.mly"
                                        ( Some _2 )
# 6633 "src/kernel_internals/parsing/cparser.ml"
               : 'asmopname))
; (fun __caml_parser_env ->
    Obj.repr(
# 1723 "src/kernel_internals/parsing/cparser.mly"
                                        ( [],[] )
# 6639 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : 'asmlabels) in
    Obj.repr(
# 1724 "src/kernel_internals/parsing/cparser.mly"
                                        ( [],_2 )
# 6646 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 1 : 'asmcloberlst_ne) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmlabels) in
    Obj.repr(
# 1725 "src/kernel_internals/parsing/cparser.mly"
                                        ( _2,_3 )
# 6654 "src/kernel_internals/parsing/cparser.ml"
               : 'asmclobber))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 0 : 'one_string_constant) in
    Obj.repr(
# 1728 "src/kernel_internals/parsing/cparser.mly"
                                        ( [_1] )
# 6661 "src/kernel_internals/parsing/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    let _1 = (Parsing.peek_val __caml_parser_env 2 : 'one_string_constant) in
    let _3 = (Parsing.peek_val __caml_parser_env 0 : 'asmcloberlst_ne) in
    Obj.repr(
# 1729 "src/kernel_internals/parsing/cparser.mly"
                                                 ( _1 :: _3 )
# 6669 "src/kernel_internals/parsing/cparser.ml"
               : 'asmcloberlst_ne))
; (fun __caml_parser_env ->
    Obj.repr(
# 1732 "src/kernel_internals/parsing/cparser.mly"
                                       ( [] )
# 6675 "src/kernel_internals/parsing/cparser.ml"
               : 'asmlabels))
; (fun __caml_parser_env ->
    let _2 = (Parsing.peek_val __caml_parser_env 0 : string list) in
    Obj.repr(
# 1733 "src/kernel_internals/parsing/cparser.mly"
                                       ( _2 )
# 6682 "src/kernel_internals/parsing/cparser.ml"
               : 'asmlabels))
(* Entry interpret *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
(* Entry file *)
; (fun __caml_parser_env -> raise (Parsing.YYexit (Parsing.peek_val __caml_parser_env 0)))
|]
let yytables =
  { Parsing.actions=yyact;
    Parsing.transl_const=yytransl_const;
    Parsing.transl_block=yytransl_block;
    Parsing.lhs=yylhs;
    Parsing.len=yylen;
    Parsing.defred=yydefred;
    Parsing.dgoto=yydgoto;
    Parsing.sindex=yysindex;
    Parsing.rindex=yyrindex;
    Parsing.gindex=yygindex;
    Parsing.tablesize=yytablesize;
    Parsing.table=yytable;
    Parsing.check=yycheck;
    Parsing.error_function=parse_error;
    Parsing.names_const=yynames_const;
    Parsing.names_block=yynames_block }
let interpret (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 1 lexfun lexbuf : (bool*Cabs.definition) list)
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (Parsing.yyparse yytables 2 lexfun lexbuf : (bool*Cabs.definition) list)
;;
